//Database.js

var usersDict = {};
// First, let's create a short helper function to get the database connection
function getDatabase() {
     return openDatabaseSync("WoT_QML", "1.0", "StorageDatabase", 100000);
}

// At the start of the application, we can initialize the tables we need if they haven't been created yet
function initialize() {
    var db = getDatabase();
    db.transaction(
        function(tx) {
            // Create the settings table if it doesn't already exist
            // If the table exists, this is skipped
            tx.executeSql('CREATE TABLE IF NOT EXISTS settings(setting TEXT UNIQUE, value TEXT)');
            tx.executeSql('CREATE TABLE IF NOT EXISTS userInfo(userName TEXT UNIQUE, userId TEXT, clanTag TEXT, clanId TEXT, clanColor TEXT, claster TEXT)');
            tx.executeSql('CREATE TABLE IF NOT EXISTS clanInfo(clanId TEXT UNIQUE, stuffCount TEXT, leader TEXT, clanIcon TEXT, clanName TEXT, claster TEXT)');
      });
}

function resetTable() {
    var db = getDatabase();
    db.transaction(
        function(tx) {
            // Create the settings table if it doesn't already exist
            // If the table exists, this is skipped
            tx.executeSql('DROP TABLE IF EXISTS userInfo');
            tx.executeSql('DROP TABLE IF EXISTS clanInfo');
      });
}

// This function is used to write a setting into the database
function setSetting(setting, value) {
   // setting: string representing the setting name (eg: “username”)
   // value: string representing the value of the setting (eg: “myUsername”)
   var db = getDatabase();
   var res = "";
   db.transaction(function(tx) {
        var rs = tx.executeSql('INSERT OR REPLACE INTO settings VALUES (?,?);', [setting,value]);
              //console.log(rs.rowsAffected)
              if (rs.rowsAffected > 0) {
                res = "OK";
              } else {
                res = "Error";
              }
        }
  );
  // The function returns “OK” if it was successful, or “Error” if it wasn't
  return res;
}
// This function is used to retrieve a setting from the database
function getSetting(setting) {
    var db = getDatabase();
    var res="";
    db.transaction(function(tx) {
                       var rs = tx.executeSql('SELECT value FROM settings WHERE setting=?;', [setting]);
                       if (rs.rows.length > 0) {
                           res = rs.rows.item(0).value;
                       } else {
                           res = "Unknown";
                       }
                   })
    // The function returns “Unknown” if the setting was not found in the database
    // For more advanced projects, this should probably be handled through error codes
    return res
}

// This function is used to add a new user to the database
function addUser(userName, userId, clanTag, clanId, clanColor, claster) {
    var db = getDatabase();
    var res = "";
    if (clanId === undefined) {
        clanId = ""
    }

    db.transaction(function(tx) {
         var rs = tx.executeSql('INSERT OR REPLACE INTO userInfo VALUES (?,?,?,?,?,?);', [userName, userId, clanTag, clanId, clanColor, claster]);
//               console.log(rs.rowsAffected);
//               console.log(userName, userId, clanTag, clanId, clanColor, claster);
               if (rs.rowsAffected > 0) {
                   console.log("OK");
                 res = "OK";
               } else {
                   console.log("ERROR");
                 res = "Error";
               }
         }
   );
}

// This function is used to get all saved users from the database
function getUser() {
    var db = getDatabase();
    var res = "Unknown";
    var users = new Array;
    db.transaction(function(tx) {
                       var rs = tx.executeSql('SELECT * FROM userInfo;');
                       if (rs.rows.length > 0) {
                           for(var i = 0; i < rs.rows.length; i++) {
//                               console.log(rs.rows.item(i).userName);
//                               console.log(rs.rows.item(i).userId);
//                               console.log(rs.rows.item(i).clanId);
                               users.push(rs.rows.item(i));
                           }
                       }
                   });
    if (users.length > 0) {
        return users;
    }
    return res;
}

// This function is used to get all saved users from the database
function getUsersFromClaster(claster) {
    var db = getDatabase();
    var res = "Unknown";
    var users = new Array;
    db.transaction(function(tx) {
                       var request = 'SELECT * FROM userInfo WHERE claster = "' + claster + '";'
                       var rs = tx.executeSql(request);
                       if (rs.rows.length > 0) {
                           for(var i = 0; i < rs.rows.length; i++) {
//                               console.log(rs.rows.item(i).userName);
//                               console.log(rs.rows.item(i).userId);
//                               console.log(rs.rows.item(i).clanId);
                               users.push(rs.rows.item(i));
                           }
                       }
                   });
    if (users.length > 0) {
        return users;
    }
    return res;
}

function getUsersCount() {
    var db = getDatabase();
    var rs = 0
    db.transaction(function(tx) {
                       rs = tx.executeSql('SELECT * FROM userInfo;');
                   });
    return rs.rows.length;
}

// This function is used to find an user from the database
function findUser(userId) {
    var db = getDatabase();
    var users = new Array;
    var res = false;
    db.transaction(function(tx) {
                       var request = 'SELECT * FROM userInfo WHERE userId = ' + userId + ';'
                       var rs = tx.executeSql(request);
                       if (rs.rows.length > 0) {
                           console.log("Presented")
                           res = true;
                       }
                   });
    console.log("Not presented")
    return res;
}

// This function is used to delete an user from the database
function deleteUser(userId) {
    var db = getDatabase();
    var users = new Array;
    var res = false;
    db.transaction(function(tx) {
                       var request = 'DELETE FROM userInfo WHERE userId = ' + userId + ';'
                       var rs = tx.executeSql(request);
                   });
}

// This function is used to add a new clan to the database
function addClan(clanId, stuffCount, leader, clanIcon, clanName, claster) {
    var db = getDatabase();
    var res = "";

    db.transaction(function(tx) {
         var rs = tx.executeSql('INSERT OR REPLACE INTO clanInfo VALUES (?,?,?,?,?,?);', [clanId, stuffCount, leader, clanIcon, clanName, claster]);
               console.log(rs.rowsAffected);
               console.log(clanId, stuffCount, leader);
               if (rs.rowsAffected > 0) {
                   console.log("OK");
                 res = "OK";
               } else {
                   console.log("ERROR");
                 res = "Error";
               }
         }
   );
}

// This function is used to get a clan info from the database
function getClan() {
    var db = getDatabase();
    var res = "Unknown";
    var clans = new Array;
    db.transaction(function(tx) {
                       var rs = tx.executeSql('SELECT * FROM clanInfo;');
                       if (rs.rows.length > 0) {
                           for(var i = 0; i < rs.rows.length; i++) {
                               console.log(rs.rows.item(i).clanId);
                               console.log(rs.rows.item(i).stuffCount);
                               console.log(rs.rows.item(i).leader);
                               clans.push(rs.rows.item(i));
                           }
                       }
                   });
    if (clans.length > 0) {
        return clans;
    }
    return res;
}

function getClansFromClaster(claster) {
    var db = getDatabase();
    var res = "Unknown";
    var clans = new Array;
    db.transaction(function(tx) {
                       var request = 'SELECT * FROM clanInfo WHERE claster = "' + claster + '";'
                       var rs = tx.executeSql(request);
                       if (rs.rows.length > 0) {
                           for(var i = 0; i < rs.rows.length; i++) {
                               clans.push(rs.rows.item(i));
                           }
                       }
                   });
    if (clans.length > 0) {
        return clans;
    }
    return res;
}

function getClansCount() {
    var db = getDatabase();
    var rs = 0
    db.transaction(function(tx) {
                       rs = tx.executeSql('SELECT * FROM clanInfo;');
                   });
    return rs.rows.length;
}

// This function is used to find a clan from the database
function findClan(clanId) {
    var db = getDatabase();
    var res = false;
    db.transaction(function(tx) {
                       var request = 'SELECT * FROM clanInfo WHERE clanId = ' + clanId + ';'
                       var rs = tx.executeSql(request);
                       if (rs.rows.length > 0) {
                           console.log("Presented")
                           res = true;
                       }
                   });
    console.log("Not presented")
    return res;
}

// This function is used to delete a clan from the database
function deleteClan(clanId) {
    var db = getDatabase();
    var res = false;
    db.transaction(function(tx) {
                       var request = 'DELETE FROM clanInfo WHERE clanId = ' + clanId + ';'
                       var rs = tx.executeSql(request);
                   });
}

