import QtQuick 1.1
import com.nokia.meego 1.0
import com.nokia.extras 1.1     // Extras
import Qt.labs.components 1.1
import QtMultimediaKit 1.1

import "HttpRequest.js" as HttpRequest
import "Database.js" as Settings

Page {
    id: mainPage
    orientationLock: PageOrientation.LockPortrait

    property string clasterName: ""

    property string warGagCaption: ""
    property string imageSource: ""

    property string userId_for_delete: ""
    property string clanId_for_delete: ""

    InfoBanner {
        id: infoBanner
        timerShowTime: 4000
        z: 3
    }

    Component.onCompleted: {
        if (PageStatus.Activating) {
            // Initialize the database
            Settings.initialize();
            if (Settings.getSetting("Claster") === "Unknown") {
                Settings.setSetting("Claster", "ru");
                clasterName = "ru"
            } else {
                clasterName = Settings.getSetting("Claster");
            }
            var usersCount = Settings.getUsersCount();
            var clansCount = Settings.getClansCount();

            mainView.append({"icon": "user.png", "title": qsTr("Players"), "refreshCount": 0, "count": "/" + usersCount, "dataSource": usersListModel, "dataFormat": usersListComponent});
            mainView.append({"icon": "clan.png", "title": qsTr("Clans"), "refreshCount": 0, "count": "/" + clansCount, "dataSource": clanListModel, "dataFormat": clanListComponent});
            mainView.append({"icon": "news.png", "title": qsTr("News"), "refreshCount": 0, "count": "/20", "dataSource": feedModel, "dataFormat": newsDelegate});
            mainView.append({"icon": "wotgag.png", "title": "WarGag", "refreshCount": 0, "count": "", "dataSource": warGagListModel, "dataFormat": warGagComponent});
            mainView.append({"icon": "radio.png", "title": "WoT Radio", "refreshCount": "", "count": "", "dataSource": warRadionListModel, "dataFormat": warRadioComponent});

            var warGAGurl = "http://api.worldoftanks.ru/wgn/wargag/content/?application_id=demo";
            HttpRequest.httpRequest(warGAGurl, setWarGagData);
        }

        var clastersList = ["ru", "eu", "com", "kr", "asia"];

        usersListModel.clear();
        for(var i in clastersList) {
            var res = Settings.getUsersFromClaster(clastersList[i]);
            if (res.constructor === Array) {
                var usersId = [];
                for(var j in res) {
//                    console.log(JSON.stringify(res[j]))
                    usersId.push(res[j].userId);
                }
                var _res = usersId.join(',');
                var url = "http://api.worldoftanks." + clastersList[i] + "/wot/account/info/?application_id=" + "demo" + "&account_id=" + _res
                HttpRequest.httpRequest3Args(url, refreshUserData, clastersList[i])
            }
        }

        clanListModel.clear()
        for(var n in clastersList) {
            var clanRes = Settings.getClansFromClaster(clastersList[n]);
            if (clanRes.constructor === Array) {
                var clansId = [];
                for(var m in clanRes) {
                    clansId.push(clanRes[m].clanId);
                }
                var url = "http://api.worldoftanks." + clastersList[n] + "/wot/clan/info/?application_id=demo&clan_id=" + clansId.join(',');
                HttpRequest.httpRequest3Args(url, refreshClanData, clastersList[n])
            }
        }
    }

    function printData(data) {
        console.log(JSON.stringify(data))
    }

    function getNewsDate(newsDate) {
        var d = new Date(newsDate).getDate()
        var currDate = new Date().getDate()
        if(d === currDate) {
            return qsTr("Today")
        } else if((currDate - d) === 1) {
            return qsTr("Yesterday")
        } else {
            var d1 = new Date(newsDate);
            var d2 = new Date();
            var t2 = d2.getTime();
            var t1 = d1.getTime();

            return parseInt((t2-t1)/(24*3600*1000)) + qsTr(" days ago");
        }
    }

    function setWarGagData(data) {
        if(data !== "error") {
            for (var i in data) {
                if(data[i].type !== "video") {
                    warGagListModel.append(data[i]);
                }
            }
        } else {
            infoBanner.text = qsTr("The error occurred during data receiving.\nResult can be incorrect.");
            infoBanner.show()
        }
    }

    function refreshUserData(data, claster) {
        if(data !== "error") {
            console.log("User data\n\n", JSON.stringify(data))
            for (var i in data) {
                if(data[i].clan_id) {
//                    console.log("USER IN THE CLAN\n", JSON.stringify(data[i]))
                    usersListModel.append({"userName": data[i].nickname, "userId": data[i].account_id, "clanRole": "", "clanId": data[i].clan_id, "clanTag": "", "clanColor": "", clanLogo: "", "claster": claster});
                    var listId = usersListModel.count - 1;
                    var url = "http://api.worldoftanks." + claster + "/wot/clan/membersinfo/?application_id=demo&member_id=" + data[i].account_id;
                    HttpRequest.httpRequest3Args(url, getUserClanInfo, listId);
                } else {
                    usersListModel.append({"userName": data[i].nickname, "userId": data[i].account_id, "clanRole": "", "clanId": "", "clanTag": "", "clanColor": "", "claster": claster});
                }
            }
        } else {
            infoBanner.text = qsTr("The error occurred during data receiving.\nResult can be incorrect.");
            infoBanner.show()
        }
    }

    function getUserClanInfo(data, listId) {
        if(data !== "error") {
            for(var i in data)
            usersListModel.set(listId, {"clanRole": data[i].role_i18n, "clanTag": data[i].abbreviation, "clanColor": data[i].color})
        } else {
            infoBanner.text = qsTr("The error occurred during data receiving.\nResult can be incorrect.");
            infoBanner.show()
        }
    }

    function refreshClanData(data, claster) {
        if(data !== "error") {
//            console.log(JSON.stringify(data))
            for (var i in data) {
                var leader = "";
                for (var j in data[i].members) {
                    if (data[i].members[j].role === "leader") {
                        leader = data[i].members[j].account_name;
                        break;
                    }
                }
                clanListModel.append({"clanId": data[i].clan_id, "stuffCount": data[i].members_count, "leader": leader, "clanIcon": data[i].emblems.large, "clanName": data[i].name, "claster": claster, clanModel: data[i]});
            }
        } else {
            infoBanner.text = qsTr("The error occurred during data receiving.\nResult can be incorrect.");
            infoBanner.show()
        }
    }

    ListModel {
        id: mainView
    }

    ListModel {
        id: usersListModel
    }

    ListModel {
        id: clanListModel
    }

    ListModel {
        id: warGagListModel
    }

    ListModel {
        id: warRadionListModel
        ListElement {
            name: "Pryamoy Navodkoy"
            link: "http://live.wotradio.ru:8008/radio"
        }
        ListElement {
            name: "Wargaming.fm"
            link: "http://81.25.32.234:8050/wgfm"
        }

    }
    XmlListModel {
        id: feedModel
        source: "http://worldoftanks." + clasterName + "/rss/news/"
        query: "/rss/channel/item"

        XmlRole { name: "title"; query: "title/string()" }
        XmlRole { name: "link"; query: "link/string()" }
        XmlRole { name: "description"; query: "description/string()" }
        XmlRole { name: "imglink"; query: "source/icon/string()" }
        XmlRole { name: "pubdate"; query: "pubDate/string()" }
        XmlRole { name: "category"; query: "category/string()" }
    }

    Component {
        id: baseItem

        Rectangle {
            id: baseRec
            anchors.fill: baseItem.padding
            anchors.margins: 10
            height: 90
            width: parent.width
            color: "transparent"
            Rectangle {
                id: headerRect
                anchors.fill: baseItem.padding
                height: 90
                width: parent.width
                color: "lightgray"
                Image {
                    id: elementIcon
                    width: 55
                    height: 55
                    anchors.verticalCenter: parent.verticalCenter
                    anchors.left: parent.left
                    anchors.leftMargin: 10
    //                anchors.verticalCenter: parent.verticalCenter
                    source: icon
                }
                Text {
                    id: titleText
                    anchors.verticalCenter: parent.verticalCenter
                    anchors.horizontalCenter: parent.horizontalCenter
                    text: title
                    smooth: false
                    font.pixelSize: 24
                }
                Text {
                    id: subtitleText
                    anchors.verticalCenter: parent.verticalCenter
                    anchors.right: parent.right
                    anchors.rightMargin: 10
                    smooth: false
                    font.pixelSize: 20
                    text: dataSource.count + count
                }
                MouseArea {
                    anchors.fill: parent
                    onClicked: {
                        subList.visible = !subList.visible
                        headerRect.height = subList.visible?90:90
                        baseRec.height = subList.visible?470:90
                    }
                    onPressed: {
                        headerRect.color = "gray"
                    }
                    onReleased: {
                        headerRect.color = "lightgray"
                    }
                    onPositionChanged: {
                        headerRect.color = "lightgray"
                    }
                }
            }
            ListView {
                id: subList
                anchors.top: headerRect.bottom
                anchors.bottom: parent.bottom
                anchors.left: parent.left
                anchors.right: parent.right
                anchors.margins: 10
                spacing: 4
                clip: true
                visible: false
                model: dataSource
                delegate: dataFormat
            }
        }
    }

    Component {
        id: warGagComponent
        Item {
            id: wargagMain
            width: parent.width
            height: descriptionText.height > 100?descriptionText.height + 20:140
            Text {
                id: author
                anchors.top: parent.top
                anchors.topMargin: 5
                anchors.left: parent.left
                anchors.leftMargin: 5
                text: qsTr("Author: <b>") + nickname + "</b>"
//                font.pointSize: 14
            }
            //rating
            Text {
                id: ratingValue
                anchors.top: parent.top
                anchors.topMargin: 5
                anchors.right: parent.right
                anchors.rightMargin: 5
                text: qsTr("Rating: ") + rating
//                font.pointSize: 14
            }
            Text {
                id: descriptionText
                textFormat: Text.AutoText
                anchors.top: author.bottom
                anchors.left: media.right
                anchors.leftMargin: 5
                anchors.right: parent.right
                anchors.rightMargin: 5
//                width: parent.width - media.width - 10
                wrapMode: Text.WordWrap
                text: description !== undefined?description.replace(/&quot;/g, '\"'):""
                font.pointSize: 14
                visible: type === "quote"?true:false
            }
            Image {
                id: media
                source: type === "picture"?media_url:""
                anchors.top: author.bottom
                anchors.topMargin: 5
                anchors.left: parent.left
                anchors.leftMargin: 5
                height: type === "picture"?100:0
                width: type === "picture"?100:0
                fillMode: Image.PreserveAspectFit
                smooth: true
                visible: type === "picture"?true:false
                Text {
                    id: mediaDescription
//                    anchors.top: parent.top
                    anchors.verticalCenter: media.verticalCenter
                    anchors.left: media.right
                    anchors.leftMargin: 10
                    width: wargagMain.width - media.width - 15
                    wrapMode: Text.WordWrap
                    text: description !== undefined?description.replace(/&quot;/g, '\"'):""
//                    font.pointSize: 14
                }
                MouseArea {
                    anchors.fill: parent
                    onClicked: {
                        fullImage.source = media_url;
                        warGagCaption = description !== undefined?description.replace(/&quot;/g, '\"'):""
                        imageSource = media_url
                        warGagDialog.open()
                        fullImage.playing = true;
                    }
                }
            }
            Rectangle {
                id: delimiter
//                color: "lightgray"
                width: parent.width * 0.95
                height: 3
                anchors.horizontalCenter: parent.horizontalCenter
                anchors.bottom: parent.bottom
                anchors.bottomMargin: -10
                radius: 10
                smooth: true
                gradient:  Gradient {
                    GradientStop { position: 0.0; color: "gray" }
                    GradientStop { position: 0.33; color: "white" }
                    GradientStop { position: 1.0; color: "lightgray" }
                }
            }
        }
    }

    Component {
        id: newsDelegate
        Rectangle {
            id: wrapper
            width: parent.width
            height: newsImage.height + newsCategory.height + 15
            color: "transparent"
            radius: 10
            Image {
                id: newsImage
                anchors.top: parent.top
                anchors.topMargin: 10
                anchors.left: parent.left
                width: 100
                height: 72
                source: "http://www.worldoftanks." + clasterName + imglink.replace(/ /g,'')
            }
            Text {
                id: newsHeader
                anchors.top: newsImage.top
                anchors.left: newsImage.right
                anchors.leftMargin: 5
                anchors.right: parent.right
                anchors.rightMargin: 5
                color: "black"
                width: parent.width
                text: title.length > 50?title.substring(0, 50) + "...":title
                verticalAlignment: Text.AlignVCenter
                wrapMode: Text.WordWrap;
                font.pointSize: 16
            }

            Text {
                id: newsCategory
                anchors.left: parent.left
                anchors.bottom: parent.bottom
                anchors.bottomMargin: 5
                text: qsTr("<b>Category: </b>") + category
                font.pointSize: 14
            }

            Text {
                id: newsDate
                anchors.right: parent.right
                anchors.rightMargin: 5
                anchors.bottom: parent.bottom
                anchors.bottomMargin: 5
                text: getNewsDate(pubdate)
                font.pointSize: 12

            }

            Rectangle {
                id: newsDelimeter
//                color: "#000080"
                height: 3
                width: parent.width
                anchors.top: parent.bottom
                anchors.horizontalCenter: parent.horizontalCenter
                radius: 10
                smooth: true
                gradient:  Gradient {
                    GradientStop { position: 0.0; color: "gray" }
                    GradientStop { position: 0.33; color: "white" }
                    GradientStop { position: 1.0; color: "lightgray" }
                }
            }

            MouseArea {
                anchors.fill: parent
                onClicked: {
                    var img = "http://www.worldoftanks." + clasterName + imglink.replace(/ /g,'')
                    pageStack.push(Qt.resolvedUrl("RssNews.qml"), {"title": title, "description": description, "imglink": img});
                }
            }
        }
    }

    Component {
        id: usersListComponent
        Rectangle {
            id: usersItem
            width: parent.width
            height: userHeader.height + server.height
            color: "transparent";
            Text {
                id: userHeader
                anchors.top: usersItem.top
                anchors.topMargin: 1
                anchors.left: parent.left
                anchors.leftMargin: 5
                anchors.right: parent.right
                anchors.rightMargin: 5
                color: "black"
                width: parent.width
                text: clanId === ""?"<b>" + userName + "</b>":"<b>" + userName + "</b> [<font color='" + clanColor + "'>" + clanTag + "</font>]<br>" + qsTr(" Rank: ") + clanRole;
                verticalAlignment: Text.AlignVCenter
                wrapMode: Text.WordWrap;
                font.pointSize: 18
            }
            Text {
                id: server
                anchors.top: userHeader.bottom
                anchors.topMargin: 1
                anchors.left: parent.left
                anchors.leftMargin: 10
                color: "black"
                width: parent.width
                text: qsTr("Region: ") + claster
                verticalAlignment: Text.AlignVCenter
                wrapMode: Text.WordWrap;
                font.pointSize: 14
            }
            Rectangle {
                id: delimeter
                anchors.top: parent.bottom
                anchors.horizontalCenter: parent.horizontalCenter
                width: parent.width * 0.95
                height: 3
                radius: 10
                smooth: true
                gradient:  Gradient {
                    GradientStop { position: 0.0; color: "gray" }
                    GradientStop { position: 0.33; color: "white" }
                    GradientStop { position: 1.0; color: "lightgray" }
                }
            }

            MouseArea {
                anchors.fill: parent
                onClicked: {
                    if (clanId !== "") {
                        pageStack.push(Qt.resolvedUrl("userInfoPage.qml"), {userId: userId, clanId: clanId, claster: claster, needRequest: true, needClanRequest: true, showAddButton: false})
                    } else {
                        pageStack.push(Qt.resolvedUrl("userInfoPage.qml"), {userId: userId, claster: claster, needRequest: true, showAddButton: false})
                    }
                }
                onPressAndHold: {
                    userId_for_delete = userId;
                    deleteUser.open();
                }
            }
        }
    }

    Component {
        id: clanListComponent
        Rectangle {
            id: clanItem
            width: parent.width
            height: clanHeader.height + leaderName.height + server.height
            color: "transparent";
            Image {
                id: clanLogo
                anchors.top: parent.top
                anchors.topMargin: 5
                anchors.left: parent.left
                anchors.leftMargin: 10
//                source: "http://worldoftanks." + claster + "/" + clanIcon;
                source: clanIcon
            }
            Text {
                id: clanHeader
                anchors.top: clanItem.top
                anchors.topMargin: 1
                anchors.left: clanLogo.right
                anchors.leftMargin: 10
                color: "black"
                width: parent.width
                text: clanName
                verticalAlignment: Text.AlignVCenter
                wrapMode: Text.WordWrap;
                font.pointSize: 18
            }
            Text {
                id: leaderName
                anchors.top: clanHeader.bottom
                anchors.topMargin: 1
                anchors.left: clanLogo.right
                anchors.leftMargin: 10
                color: "black"
                width: parent.width
                text: qsTr("Leader: ") + leader
                verticalAlignment: Text.AlignVCenter
                wrapMode: Text.WordWrap;
                font.pointSize: 14
            }
            Text {
                id: stuff_Count
                anchors.top: leaderName.bottom
                anchors.topMargin: 1
                anchors.left: clanLogo.right
                anchors.leftMargin: 10
                color: "black"
//                width: parent.width
                text: qsTr("Staff count: ") + parseInt(stuffCount)
                verticalAlignment: Text.AlignVCenter
                wrapMode: Text.WordWrap;
                font.pointSize: 14
            }
            Text {
                id: server
                anchors.top: leaderName.bottom
                anchors.topMargin: 1
                anchors.right: parent.right
                anchors.rightMargin: 10
                color: "black"
//                width: parent.width
                text: qsTr("Region: ") + claster
                verticalAlignment: Text.AlignVCenter
                wrapMode: Text.WordWrap;
                font.pointSize: 14
            }
            Rectangle {
                id: delimeter
                anchors.top: parent.bottom
                anchors.horizontalCenter: parent.horizontalCenter
                width: parent.width * 0.95
                height: 3
                radius: 10
                smooth: true
                gradient:  Gradient {
                    GradientStop { position: 0.0; color: "gray" }
                    GradientStop { position: 0.33; color: "white" }
                    GradientStop { position: 1.0; color: "lightgray" }
                }
            }

            MouseArea {
                anchors.fill: parent
                onPressAndHold: {
                    //console.log("onPressAndHold");
                    clanId_for_delete = clanId
                    deleteClan.open()
                }
                onClicked: {
//                    pageStack.push(Qt.resolvedUrl("clanInfoPage.qml"), {clanId: clanId, claster: claster, needRequest: true, showAddButton: false})
                    pageStack.push(Qt.resolvedUrl("clanInfoPage.qml"), {clanModel: clanModel, claster: claster, clanLeader: leader})
                }
            }
        }
    }

    Component {
        id: warRadioComponent
        Item {
            width: parent.width
            height: 80
            Audio {
                id: radioPlayer
                source: link
                autoLoad: false
            }
            Label {
                id: radioTitle
                text: name

                anchors.left: parent.left
                anchors.leftMargin: 10
                anchors.verticalCenter: parent.verticalCenter

            }

            ToolIcon {
                id: playButton
//                anchors.centerIn: parent
                anchors.right: parent.right
                anchors.rightMargin: 20
                anchors.verticalCenter: parent.verticalCenter
                iconId: radioPlayer.playing?"toolbar-mediacontrol-stop":"toolbar-mediacontrol-play"
                width: 60
                height: 60
                onClicked: {
                    if (radioPlayer.playing) {
                        radioPlayer.stop()
                    } else {
                        radioPlayer.play()
                    }
                }
            }

            Rectangle {
                anchors.top: parent.bottom
                anchors.horizontalCenter: parent.horizontalCenter
                width: parent.width * 0.95
                height: 3
                radius: 10
                smooth: true
                gradient:  Gradient {
                    GradientStop { position: 0.0; color: "gray" }
                    GradientStop { position: 0.33; color: "white" }
                    GradientStop { position: 1.0; color: "lightgray" }
                }
            }
        }
    }

    /* Dialogs*/
    Dialog {
        id: warGagDialog
        title: Text {
            text: warGagCaption;
            anchors.centerIn: parent;
            width: mainPage.width * 0.9
            color: "white"
            font.pixelSize: 28
            font.bold: true
            wrapMode: Text.WordWrap
            horizontalAlignment: Text.AlignHCenter
        }
        content: AnimatedImage {
            id: fullImage
            source: imageSource
            anchors.centerIn: parent
            fillMode: Image.PreserveAspectFit
            smooth: true
            width: mainPage.width * 0.9
            height: mainPage.height * 0.9
            playing: true
            cache : false
        }
        onClicked: {
            fullImage.playing = false;
            fullImage.source = "";
        }
    }

    Dialog {
        id: aboutDialog
        title: Text {
            text: qsTr("About");
            anchors.centerIn: parent;
            color: "white"
            font.pixelSize: 28
            font.bold: true
        }
        content: Text {
            width: parent.width * 1.5
            anchors.centerIn: parent;
            anchors.margins: 10
            text: qsTr("The author of this application does not affiliated with Wargaming.Net\n\nLegal notice. The images contained within are copyrighted by Wargaming.Net LLP and tank stats are intellectual property of Wargaming.Net : Copyright © 1998 - 2014 Wargaming.net ®, All rights reserved. World of Tanks, WoT are trademarks or registered trademarks of Wargaming.net.");
            color: "white"
            font.pixelSize: 20
            horizontalAlignment: Text.AlignJustify
            wrapMode: Text.Wrap
        }
    }

    QueryDialog {
        id: deleteUser
        title: Text {
            id: header
            text: qsTr("Delete user")
            anchors.centerIn: parent;
            color: "white"
            font.pixelSize: 28
            font.bold: true
        }
        message: qsTr("User will be deleted from the database")
        acceptButtonText: qsTr("Delete")
        rejectButtonText: qsTr("Cancel")
        onAccepted: {
            Settings.deleteUser(userId_for_delete)
            var clastersList = ["ru", "eu", "com", "kr", "asia"];

            usersListModel.clear();
            for(var i in clastersList) {
                var res = Settings.getUsersFromClaster(clastersList[i]);
                if (res.constructor === Array) {
                    var usersId = [];
                    for(var j in res) {
    //                    console.log(JSON.stringify(res[j]))
                        usersId.push(res[j].userId);
                    }
                    var _res = usersId.join(',');
                    var url = "http://api.worldoftanks." + clastersList[i] + "/wot/account/info/?application_id=" + "demo" + "&account_id=" + _res
                    HttpRequest.httpRequest3Args(url, refreshUserData, clastersList[i])
                }
            }
            deleteUser.close()
        }
        onRejected: {
            deleteUser.close()
        }
    }

    QueryDialog {
        id: deleteClan
        title: Text {
            id: clanHeader
            text: qsTr("Delete clan")
            anchors.centerIn: parent;
            color: "white"
            font.pixelSize: 28
            font.bold: true
        }
        message: qsTr("Clan will be deleted from the database")
        acceptButtonText: qsTr("Delete")
        rejectButtonText: qsTr("Cancel")
        onAccepted: {
            Settings.deleteClan(clanId_for_delete)
            var clastersList = ["ru", "eu", "com", "kr", "asia"];

            clanListModel.clear()
            for(var n in clastersList) {
                var clanRes = Settings.getClansFromClaster(clastersList[n]);
                if (clanRes.constructor === Array) {
                    var clansId = [];
                    for(var m in clanRes) {
                        clansId.push(clanRes[m].clanId);
                    }
                    var url = "http://api.worldoftanks." + clastersList[n] + "/wot/clan/info/?application_id=demo&clan_id=" + clansId.join(',');
                    HttpRequest.httpRequest3Args(url, refreshClanData, clastersList[n])
                }
            }
            deleteClan.close()
        }
        onRejected: {
            deleteClan.close()
        }
    }

    /*Main view*/

    ListView {
        id: mainList
        anchors.fill: parent
        spacing: 2
        clip: true
        model: mainView
        delegate: baseItem
    }

    Menu {
        id: myMenu
        MenuLayout {
            MenuItem {
                text: qsTr("Refresh RSS")
//                text: "Обновить новости"
                onClicked: {
                    clasterName = Settings.getSetting("Claster");
                    feedModel.reload();
                }
            }
            MenuItem {
//                text: qsTr("Settings")
                text: qsTr("Settings")
                onClicked: {
                    pageStack.push(Qt.resolvedUrl("Settings.qml"))
                }
            }
            MenuItem {
//                text: qsTr("Settings")
                text: qsTr("About")
                onClicked: {
                    aboutDialog.open()
                }
            }
        }
    }

    tools: ToolBarLayout {
        id: commonTools
        visible: true
        ToolIcon {
            platformIconId: "toolbar-back"
            enabled: false
            opacity: 0.2
        }
        ToolIcon {
            platformIconId: "toolbar-search"
            anchors.centerIn: parent
            onClicked: {
                pageStack.push(Qt.resolvedUrl("SearchPage.qml"))
            }

        }
        ToolIcon {
            platformIconId: "toolbar-view-menu"
            anchors.right: (parent === undefined) ? undefined : parent.right
            onClicked: (myMenu.status === DialogStatus.Closed) ? myMenu.open() : myMenu.close()
        }
    }

    Audio {
        id: radioPlayer
        source: ""
        autoLoad: false
        onStarted: {
            playButton.iconId = "toolbar-mediacontrol-stop"
        }
        onStopped: {
            playButton.iconId = "toolbar-mediacontrol-play"
        }
    }
}
