import QtQuick 1.1
import com.nokia.meego 1.1
import com.nokia.extras 1.1     // Extras
import Qt.labs.components 1.1

import "HttpRequest.js" as HttpRequest
import "Database.js" as Settings

Page {
    id: searchPage
    orientationLock: PageOrientation.LockPortrait

    property string claster: "ru";

    Component.onCompleted: {
        // Initialize the database
        Settings.initialize();
        claster = Settings.getSetting("Claster");
        userModel.clear();
    }

    function findUsersData(data) {
        if(data !== "error") {
            var userIds = [];
            Settings.usersDict = {};
            for (var i in data) {
                userIds.push(data[i].account_id);
                Settings.usersDict[data[i].account_id] = {};
            }
            var url = "http://api.worldoftanks." + claster + "/wot/account/info/?application_id=demo&account_id=" + userIds.join(',');
            HttpRequest.httpRequest(url, fillUserData)
        } else {
            infoBanner.text = qsTr("The error occurred during data receiving.\nResult can be incorrect.")
            infoBanner.show()
        }
    }

    function fillUserData(data) {
        if(data !== "error") {
            var clansArray = [];
            for (var i in data) {
                Settings.usersDict[i] = data[i];
                if(data[i].clan_id) {
                    Settings.usersDict[i]["in_clan"] = true;
                    Settings.usersDict[i]["clan"] = {};
                    clansArray.push(i);
                } else {
                    Settings.usersDict[i]["in_clan"] = false;
                    Settings.usersDict[i]["clan"] = {};
                }
            }
            if(clansArray.length > 0) {
                console.log(clansArray.join(','))
                var url = "http://api.worldoftanks." + claster + "/wot/clan/membersinfo/?application_id=demo&member_id=" + clansArray.join(',');
                HttpRequest.httpRequest(url, fillUserClanData);
            } else {
                for(var j in Settings.usersDict) {
                    userModel.append(Settings.usersDict[j]);
                }
                busyIndicator.running = false;
                busyIndicator.visible = false;
                userListView.delegate = userModelComponent;
            }
        } else {
            infoBanner.text = qsTr("The error occurred during data receiving.\nResult can be incorrect.")
            infoBanner.show()
        }
    }

    function fillUserClanData(data) {
        if(data !== "error") {
            for (var i in data) {
                Settings.usersDict[i]["clan"] = data[i];
            }
            for(var j in Settings.usersDict) {
                userModel.append(Settings.usersDict[j]);
            }
            busyIndicator.running = false;
            busyIndicator.visible = false;
            userListView.delegate = userModelComponent;
        } else {
            infoBanner.text = qsTr("The error occurred during data receiving.\nResult can be incorrect.")
            infoBanner.show()
        }
    }

    function findClanData(data) {
        if(data !== "error") {
            var clans = [];
            for (var i in data) {
                clans.push(data[i].clan_id);
            }
            if(clans.length > 0) {
            var url = "http://api.worldoftanks." + claster + "/wot/clan/info/?application_id=demo&clan_id=" + clans.join(',');
            HttpRequest.httpRequest(url, fillClanData);
            } else {

                infoBanner.text = qsTr("Can not find clan")
                infoBanner.show()
            }
        } else {
            infoBanner.text = qsTr("The error occurred during data receiving.\nResult can be incorrect.")
            infoBanner.show()
        }
    }

    function fillClanData(data) {
        if(data !== "error") {
            for (var i in data) {
                clanModel.append({clan: data[i]});
            }
            busyIndicator.running = false;
            busyIndicator.visible = false;
        } else {
            infoBanner.text = qsTr("The error occurred during data receiving.\nResult can be incorrect.")
            infoBanner.show()
        }
    }

    InfoBanner {
        id: infoBanner
        timerShowTime: 4000
        z: 3
    }

    ListModel {
        id: userModel
    }

    ListModel {
        id: clanModel
    }

    Component {
        id: userModelComponent
        Rectangle {
            id: infoRectangle
            height: infoColumn.height + 6
            width: parent.width
            color: "transparent"
            Column {
                id: infoColumn
                anchors.margins: 2
                spacing: 2
                Text {
                    text: nickname
                    font.bold: true
                    font.pointSize: 18
                }
                Image {
                    id: clanIcon
                    source: in_clan?clan.emblems.large:""
                    visible: in_clan
                    Text {
                        id: clanInfo
                        text: in_clan?"[<font color='" + clan.color + "'>" + clan.clan_name + "</font>]":""
                        visible: in_clan
                        font.bold: true
//                        font.pointSize: 16
                        anchors.left: parent.right
                        anchors.leftMargin: 5
                        anchors.verticalCenter: parent.verticalCenter
                    }
                }
                Label {
                    text: qsTr("Battles: ") + statistics.all.battles + qsTr("(Wins: ") + statistics.all.wins + "/" + getPercent(statistics.all.battles, statistics.all.wins) + ")"
//                    font.pointSize: 14
                }
                Label {
                    text: qsTr("Registered: ") + new Date(Math.round(created_at)* 1000);
//                    font.pointSize: 12
                }
                Label {
                    id: rang
                    visible: in_clan
                    text: in_clan?qsTr("Rank: ") + clan.role_i18n:""
                }
            }
            Rectangle {
                anchors.top: parent.bottom
                anchors.horizontalCenter: parent.horizontalCenter
                width: parent.width
                height: 3
                radius: 10
                smooth: true
                gradient:  Gradient {
                    GradientStop { position: 0.0; color: "gray" }
                    GradientStop { position: 0.33; color: "white" }
                    GradientStop { position: 1.0; color: "lightgray" }
                }
            }

            function getPercent(battle_count, win_count) {
                if (battle_count === 0) {
                    return 0;
                }
                var winPercent = ((win_count/battle_count) * 100 ).toFixed(2);
                var res = 0;
                if (winPercent > 50.50) {
                    res = "<font color='#00ff00'>" + winPercent + "</font>%"
                } else if (winPercent < 50.50 && winPercent > 48.50) {
                    res = "<font color='#aeed00'>" + winPercent + "</font>%"
                } else if (winPercent < 48.50 && winPercent > 46.50) {
                    res = "<font color='#eded00'>" + winPercent + "</font>%"
                } else {
                    res = "<font color='#f52900'>" + winPercent + "</font>%"
                }
                return res;
            }

            MouseArea {
                anchors.fill: parent
                onClicked: {
                    if (clan_id) {
                        pageStack.push(Qt.resolvedUrl("userInfoPage.qml"), {userId: account_id, clanId: clan_id, claster: claster, needRequest: true, needClanRequest: true})
                    } else {
                        pageStack.push(Qt.resolvedUrl("userInfoPage.qml"), {userId: account_id, claster: claster, needRequest: true})
                    }
                }
            }
        }
    }

    Component {
        id: clanModelComponent
        Rectangle {
            id: infoRectangle
            height: infoColumn.height > 64?infoColumn.height:64
            width: parent.width
            color: "transparent"
//            border.color: "black"
//            border.width: 2
//            radius: 10
            Image {
                id: clanIcon
                anchors.top: parent.top
                anchors.topMargin: 5
                anchors.left: parent.left
                anchors.leftMargin: 5

//                source: "http://worldoftanks.ru/" + clan_emblem_url
                source: clan.emblems.large
            }

            Column {
                id: infoColumn
                anchors.left: clanIcon.right
                anchors.leftMargin: 5
                spacing: 2
                Text {
                    text: clan.name + " [" + "<font color='" + clan.clan_color + "'>" + clan.abbreviation + "</font>" + "]"
                    font.bold: true
                    font.pointSize: 18
                }
                Text {
                    id: owner
                    text: getOwner(clan)
                    font.bold: true
                    font.pointSize: 16
                    function getOwner(clan) {
                        for(var i in clan.members) {
                            if(clan.members[i].role === "leader") {
                                return qsTr("Leader: ") + clan.members[i].account_name
                            }
                        }
                    }
                }

                Text {
                    text: qsTr("Staff count: ") + clan.members_count
                    font.pointSize: 12
                }
                Text {
                    text: qsTr("Created: ") + new Date(Math.round(clan.created_at) * 1000);
                    font.pointSize: 12
                }
            }
            Rectangle {
                anchors.top: parent.bottom
                anchors.horizontalCenter: parent.horizontalCenter
                width: parent.width
                height: 3
                radius: 10
                smooth: true
                gradient:  Gradient {
                    GradientStop { position: 0.0; color: "gray" }
                    GradientStop { position: 0.33; color: "white" }
                    GradientStop { position: 1.0; color: "lightgray" }
                }
            }

            MouseArea {
                anchors.fill: parent
                onClicked: {
                    pageStack.push(Qt.resolvedUrl("clanInfoPage.qml"), {clanModel: clan, clanId: clan.clan_id, claster: claster, clanLeader: clan.owner_name, needRequest: true})
                }
            }
        }
    }

    InfoBanner {
        id: searchInfoBanner
        timerShowTime: 4000
        z: 3
    }

    Item {
        id: searchBox
        anchors.top: parent.top
        anchors.left: parent.left
        anchors.right: parent.right
        width: parent.width
        height: searchField.height
        Rectangle {
            id: rectangle1
            color: "lightgray"
//            radius: 10
            border.color: "darkgray"
            border.width: 1
            anchors.fill: parent

            SheetButton {
                id: userButton
                anchors.left: parent.left
                anchors.leftMargin: 5
                anchors.verticalCenter: rectangle1.verticalCenter
                width: parent.width * 0.2
                text: qsTr("User")
                onClicked: {
                    if (searchField.text.length >= 2) {
                        clanModel.clear()
                        userModel.clear()
                        busyIndicator.running = true;
                        busyIndicator.visible = true;
                        clanListViewRectangle.enabled = false;
                        clanListViewRectangle.visible = false;
                        userListViewRectangle.enabled = true;
                        userListViewRectangle.visible = true;
                        var url = "http://api.worldoftanks." + claster + "/wot/account/list/?application_id=demo&search=" + searchField.text
                        HttpRequest.httpRequest(url, findUsersData)
                    } else {
                        searchInfoBanner.text = qsTr("Search text is empty")
                        searchInfoBanner.show()
                    }
                }
            }

            TextField {
                id: searchField
                anchors.left: userButton.right
                anchors.leftMargin: 0
                anchors.right: clanButton.left
                anchors.rightMargin: 0
                anchors.verticalCenter: rectangle1.verticalCenter
                placeholderText: qsTr("Type here...")
                ToolIcon {
                    id: searchIcon
                    anchors.right: parent.right
                    anchors.verticalCenter: parent.verticalCenter
                    platformIconId: "toolbar-search"
                }
            }

            SheetButton {
                id: clanButton
                anchors.right: parent.right
                anchors.rightMargin: 5
                anchors.verticalCenter: rectangle1.verticalCenter
                width: parent.width * 0.2
                text: qsTr("Clan")
                onClicked: {
                    if (searchField.text.length >= 2) {
                        clanModel.clear()
                        userModel.clear()
                        busyIndicator.running = true;
                        busyIndicator.visible = true;
                        userListViewRectangle.enabled = false;
                        userListViewRectangle.visible = false;
                        clanListViewRectangle.enabled = true;
                        clanListViewRectangle.visible = true;
                        var url = "http://api.worldoftanks." + claster + "/wot/clan/list/?application_id=demo&search=" + searchField.text
                        HttpRequest.httpRequest(url, findClanData);
                    } else {
                        searchInfoBanner.text = qsTr("Search text is empty")
                        searchInfoBanner.show()
                    }
                }
            }
        }
    }

    Rectangle {
        id: userListViewRectangle
        anchors.top: searchBox.bottom
        anchors.bottom: parent.bottom
        anchors.left: parent.left
        anchors.right: parent.right
        anchors.margins: 5
        color: "transparent"
        enabled: false
        visible: false
        ListView {
            id: userListView
            anchors.fill: userListViewRectangle
            z: 0
            clip: true
            spacing: 5
            snapMode: ListView.SnapToItem
            keyNavigationWraps: false
            model: userModel
            delegate: Component {Text {
                    id: dummy
                    text: qsTr("Empty")
                }}//userModelComponent
        }
    }

    Rectangle {
        id: clanListViewRectangle
        anchors.top: searchBox.bottom
        anchors.topMargin: 5
        anchors.bottom: parent.bottom
        anchors.bottomMargin: 5
        anchors.left: parent.left
        anchors.leftMargin: 5
        anchors.right: parent.right
        anchors.rightMargin: 5
        color: "transparent"
        enabled: false
        visible: false
        ListView {
            id: clanListView
            anchors.fill: clanListViewRectangle
            z: 0
            clip: true
            spacing: 5
            snapMode: ListView.SnapToItem
            keyNavigationWraps: false
            model: clanModel
            delegate: clanModelComponent
        }
    }

    BusyIndicator {
        id: busyIndicator
        anchors.centerIn: parent
        running: false
        visible: false
        platformStyle: BusyIndicatorStyle { size: "large" }
    }

    tools: ToolBarLayout {
        ToolIcon {
            id: backButton
            platformIconId: "toolbar-back"
            onClicked: window.pageStack.pop()
        }
        Label {
            id: clasterLabel
            anchors.rightMargin: 10
            text: claster
        }
    }
}
