import QtQuick 1.1
import com.nokia.meego 1.1
import com.nokia.extras 1.1     // Extras
import Qt.labs.components 1.1

import "HttpRequest.js" as HttpRequest
import "Database.js" as Settings

Page {
    id: clanInfoPage
    orientationLock: PageOrientation.LockPortrait

    property string clanId
    property string userId
    property string claster
    property string clanLeader: ""
    property bool needRequest: false
    property variant vehicleOwnersArray
    property bool showAddButton: true
    property bool showDescription: true
    property bool requestIsPerformed: false
    property int __item: 0
    property variant clanModel
    property string currentNation: ""
    property string currentLevel: ""


    Component.onCompleted: {
        tabGroup.currentTab = tab1content
        var label = clanModel.name;
        clanId = clanModel.clan_id;
        clanLabel.text = label.substring(0, 20)

        clanLogo.source = clanModel.emblems.large;
        clanCrew.text = qsTr("Staff count: ") + clanModel.members_count;
        mottoText.text = clanModel.motto;
        for (var i in clanModel.members) {
            staffModel.append(clanModel.members[i])
        }

        var usersArray = [];
        var users = "";
        for (var i = 0; i < (staffModel.count); i++) {
            usersArray.push(staffModel.get(i).account_id);
        }
        users = usersArray.join(',');
        var url = "http://api.worldoftanks." + claster + "/wot/account/tanks/?application_id=demo&fields=tank_id&account_id=" + users;
        HttpRequest.httpRequest(url, getClanStaffTanks);

        url = "http://api.worldoftanks." + claster + "/wot/clan/battles/?application_id=demo&clan_id=" + clanId;
        HttpRequest.httpRequest(url, fillBattlesData);

        url = "http://api.worldoftanks." + claster + "/wot/clan/provinces/?application_id=demo&clan_id=" + clanId;
        HttpRequest.httpRequest(url, fillProvinceData);

        url = "http://api.worldoftanks." + claster + "/wot/account/info/?application_id=demo&account_id=" + users;
        HttpRequest.httpRequest(url, getClanAllStaffRateInfo);

//        HttpRequest.getClanStaffTanks(users, claster);
//        HttpRequest.getClanAllStaffRateInfo(users, claster);
//        HttpRequest.getClanBattles(clanModel.clan_id, claster);
//        HttpRequest.getClanProvince(clanModel.clan_id, claster);

        tab1BusyIndicator.running = false;
        tab1BusyIndicator.visible = false;
        tab1.enabled = true;
//        flickableTextRect.contentHeight = descrText.height + 10
//        flickableTextRect.height = descrText.height + 10
    }

    function getClanStaffTanks(data) {
        if(data !== "error") {
            var tanks = [];
            var clan_tanks_list = {}
            var list = {};
//                            console.log("Data", JSON.stringify(b.data));
            for (var key in data) {
                for (var i = 0; i < data[key].length; i++) {
                    if (!clan_tanks_list[data[key][i].tank_id]) {
                        clan_tanks_list[data[key][i].tank_id] = 1;
                        tanks.push(data[key][i].tank_id);
                    }
                    if (typeof(list[data[key][i].tank_id]) === "undefined") {
                        var tmp = [key];
                        list[data[key][i].tank_id] = tmp;
                    } else {
                        var tmp = list[data[key][i].tank_id];
                        tmp.push(key);
                        delete list[data[key][i].tank_id];
                        list[data[key][i].tank_id] = tmp;
                    }
                }
            }
//                            console.log("Clan users tanks", JSON.stringify(list));
            var tanksList = tanks.join(',')
            var url = "http://api.worldoftanks." + claster + "/wot/encyclopedia/tankinfo/?application_id=demo&fields=name_i18n,image,image_small,tank_id,nation_i18n,nation,level,type&tank_id=" + tanksList
            HttpRequest.httpRequest3Args(url, getClanStaffTanksInfo, list);
        } else {
            infoBanner.text = qsTr("The error occurred during data receiving.\nResult can be incorrect.")
            infoBanner.show()
        }
    }

    function getClanStaffTanksInfo(data, list) {
        function sortFromTop(a, b) {
            return b.tank.level - a.tank.level;
        }

        if(data !== "error") {
            var tanks_tmp = [];
            var owners_tmp = {};
            //clanVehicleInfoModel
            var nations = {};
            for(var i in data) {
                var ownersList = list[i];
                owners_tmp[data[i].tank_id] = ownersList;
                tanks_tmp.push({tank: data[i], owners: ownersList, ownersCount: ownersList.length})
                if(!nations.hasOwnProperty(data[i].nation)) {
                    nations[data[i].nation] = 1
                    vehicleNationList.append({nation: data[i].nation})
                }
            }
            tanks_tmp.sort(sortFromTop);
            clanInfoPage.vehicleOwnersArray = owners_tmp;
            for(var id in tanks_tmp) {
                clanVehicleInfoModel.append(tanks_tmp[id]);
            }

            tab2BusyIndicator.running = false;
            tab2BusyIndicator.visible = false;
            tab2.enabled = true;
        } else {
            infoBanner.text = qsTr("The error occurred during data receiving.\nResult can be incorrect.")
            infoBanner.show()
        }
    }

    function fillBattlesData(data) {
        if(data !== "error") {
            //        clanBattles.append({started: "false", battletime: "<b>Время</b>", type: "<b>Тип</b>", provinces: "<b>Провинции</b>", arenas: "<b>Карта</b>"});
            for(var i in data[clanId]) {
                var arr = []
                for(var j in data[clanId][i].arenas) {
                    arr.push(data[clanId][i].arenas[j].name_i18n)
                }
                //            clanBattles.append({started: data[i].started, battletime: new Date(Math.round(data[i].time)* 1000).toLocaleString(), type: data[i].type, provinces: data[i].provinces.join(','), arenas: arr.join(',')});
                clanBattles.append({started: data[clanId][i].started, battletime: data[clanId][i].time, type: data[clanId][i].type, provinces: data[clanId][i].provinces.join(','), arenas: arr.join(',')});
            }
        } else {
            infoBanner.text = qsTr("The error occurred during data receiving.\nResult can be incorrect.")
            infoBanner.show()
        }
    }

    function fillProvinceData(provinceData) {
        for(var i in provinceData) {
            console.log("provinceData", JSON.stringify(provinceData[i]))
            clanProvince.append(provinceData[i]);
        }
        console.log("Items count", clanProvince.count)
    }

    function getClanAllStaffRateInfo(data) {
        if(data !== "error") {
            for (var key in data) {
                clanStatusInfo.append({ratings: data[key]})
            }
            clanStatsList.getMaxValue();
            clanBusyIndicator.running = false;
            clanBusyIndicator.visible = false;
            tab3.enabled = true;
            tab3BusyIndicator.running = false
            tab3BusyIndicator.visible = false
        } else {
            infoBanner.text = qsTr("The error occurred during data receiving.\nResult can be incorrect.")
            infoBanner.show()
        }
    }

    function filterByNation(nation) {
        if (nation !== currentNation) {
            currentNation = nation
            var i = 0;
            filteredVehicleInfoModel.clear();
            while (i < clanVehicleInfoModel.count) {
                if (nation === clanVehicleInfoModel.get(i).tank.nation) {
                    filteredVehicleInfoModel.append(clanVehicleInfoModel.get(i));
                }
                i++;
            }
//            isFiltered = true
            vehicleList.model = filteredVehicleInfoModel
        } else if (nation === currentNation) {
//            isFiltered = false
            currentNation = ""
            vehicleList.model = clanVehicleInfoModel
        }
    }

    function filterByLevel(level) {
        var i = 0;
        clanVehicleInfoModelTmp = filteredVehicleInfoModel;
        filteredVehicleInfoModel.clear();
//        clanVehicleInfoModelTmp.append(vehicleList.model);
        console.log("clanVehicleInfoModelTmp", clanVehicleInfoModelTmp.count)
        while (i < clanVehicleInfoModelTmp.count) {
            if (parseInt(level) <= parseInt(clanVehicleInfoModelTmp.get(i).tank.level)) {
                filteredVehicleInfoModel.append(clanVehicleInfoModelTmp.get(i));
            }
            i++;
        }
        console.log("filteredVehicleInfoModel", filteredVehicleInfoModel.count)
        if (filteredVehicleInfoModel.count > 0) {
            vehicleList.model = filteredVehicleInfoModel
        } else {
            vehicleList.model = clanVehicleInfoModel
        }
    }

    function getBattleType(type) {
        /*
        for_province — бой за провинцию;
        meeting_engagement — встречный бой;
        landing — бой за высадку.
        */
        var battleTypes = {"for_province": qsTr("battle for province"), "meeting_engagement": qsTr("meeting engagement"), "landing": qsTr("landing")};
        if(battleTypes[type] === "undefined") {
            return "undefined";
        }

        return battleTypes[type];
    }

    function getPlannedTime(battleTime) {
        console.log("battleTime", battleTime)
        var parsed = new Date(battleTime)
        console.log(parsed)
        var arr = []
        arr.push(new Date(battleTime).getDate())
        arr.push(new Date(battleTime).getMonth())
        arr.push(new Date(battleTime).getFullYear())
        var t = new Date(battleTime).getTime()
        return arr.join(':') + " " + t
    }

    InfoBanner {
        id: infoBanner
        timerShowTime: 4000
        z: 3
    }

    BusyIndicator {
        id: clanBusyIndicator
        anchors.centerIn: parent
        running: false
        visible: false
        platformStyle: BusyIndicatorStyle { size: "large" }
    }

    ProgressBar {
        id: clanProgressBar
        width: parent.width * 0.5
        anchors.centerIn: parent
        minimumValue: 0
        maximumValue: 100
        value: 0
        visible: false

        Text {
            anchors.bottom: parent.top
            anchors.bottomMargin: 10
            anchors.horizontalCenter: parent.horizontalCenter
            text: qsTr("Get ") + parent.value + qsTr(" from ") + parent.maximumValue
            font.pointSize: 14
        }
    }

//    ListModel {
//        id: clanModel
//    }

    ListModel {
        id: staffModel
    }

    ListModel {
        id: clanVehicleInfoModel
    }

    ListModel {
        id: clanVehicleInfoModelTmp
    }

    ListModel {
        id: filteredVehicleInfoModel
    }

    ListModel {
        id: clanStatusInfo
    }

    ListModel {
        id: vehicleOwners
    }

    ListModel {
        id: vehicleNationList
    }

    ListModel {
        id: clanStatInfo;
    }

    ListModel {
        id: clanBattles
    }

    ListModel {
        id: clanProvince
    }

    Component {
        id: clanProvinceDelegate
        Item {
            id: mainProvinceItem
//            anchors.fill: parent
            width: clanInfoPage.width
            height: _name.height + _arena_name.height + 10
            Text {
                id: _name
                anchors.left: parent.left
                width: parent.width * 0.4
                wrapMode: Text.WordWrap
                text: name
            }
            Text {
                id: _arena_name
                anchors.top: _name.bottom
                anchors.left: parent.left
                width: parent.width * 0.4
                wrapMode: Text.WordWrap
                text: arena_name
            }
            Text {
                id: _revenue
                anchors.left: _arena_name.right
                width: parent.width * 0.3
                text: revenue
            }
            Text {
                id: _occupancy_time
                anchors.left: _revenue.right
                width: parent.width * 0.3
                text: occupancy_time
            }
        }
    }

    Component {
        id: clanProvinceHeaderDelegate
        Item {
            id: mainProvinceItemTitle
            width: clanInfoPage.width
            height: _occupancy_timeTitle.height + 10
            Text {
                id: _nameTitle
                anchors.left: parent.left
                width: parent.width * 0.4
                wrapMode: Text.WordWrap
                font.bold: true
                text: qsTr("Province")
            }
            Text {
                id: _revenueTitle
                anchors.left: _nameTitle.right
                width: parent.width * 0.25
                wrapMode: Text.WordWrap
                font.bold: true
                text: qsTr("Profit (gold)")
            }
            Text {
                id: _occupancy_timeTitle
                anchors.left: _revenueTitle.right
                width: parent.width * 0.35
                wrapMode: Text.WordWrap
                font.bold: true
                text: qsTr("Days")
            }
        }
    }

    Component {
        id: clanBattlesDelegate
        Item {
            //started: data[i].started, time: data[i].time, type: data[i].type, provinces: data[i].provinces.join(','), arenas: arr.join(',
            id: mainItem
            height: battleType.height + 10
            width: clanInfoPage.width
//            anchors.fill: parent
            Text {
                id: battleType
                anchors.left: parent.left
                anchors.leftMargin: 5
                width: parent.width * 0.2
                wrapMode: Text.WordWrap
                text: getBattleType(type)
            }
            Text {
                id: battleDate
                anchors.left: battleType.right
                anchors.leftMargin: 5
                width: parent.width * 0.2
                wrapMode: Text.WrapAnywhere
                text: new Date(Math.round(battletime)* 1000).toLocaleString() //getPlannedTime(battletime)
            }
            Text {
                id: battleArenas
                anchors.left: battleDate.right
                anchors.leftMargin: 5
                width: parent.width * 0.3
                wrapMode: Text.WrapAnywhere
                text: arenas
            }
            Text {
                id: battleProvinces
                anchors.left: battleArenas.right
                anchors.leftMargin: 5
                width: parent.width * 0.3
                wrapMode: Text.WrapAnywhere
                text: provinces
            }
        }
    }

    Component {
        id: clanBattlesHeaderDelegate
        Item {
            //started: "false", battletime: "<b>Время</b>", type: "<b>Тип</b>", provinces: "<b>Провинции</b>", arenas: "<b>Карта</b>"
            id: mainHeaderItem
            height: battleHeaderType.height + 10
            width: clanInfoPage.width
            Text {
                id: battleHeaderType
                anchors.left: parent.left
                anchors.leftMargin: 5
                width: parent.width * 0.24
                font.bold: true
                text: qsTr("Type")
            }
            Text {
                id: battleHeaderDate
                anchors.left: battleHeaderType.right
                anchors.leftMargin: 5
                width: parent.width * 0.23
                font.bold: true
                text: qsTr("Time")
            }
            Text {
                id: battleHeaderArenas
                anchors.left: battleHeaderDate.right
                anchors.leftMargin: 5
                width: parent.width * 0.23
                font.bold: true
                text: qsTr("Map")
            }
            Text {
                id: battleHeaderProvinces
                anchors.left: battleHeaderArenas.right
                anchors.leftMargin: 5
                width: parent.width * 0.2
                font.bold: true
                text: qsTr("Province")
            }
        }
    }

    Component {
        id: staffDelegate
        Rectangle {
            id: userInfoRectangle
            height: staffRole.height + name.height + 10
            width: parent.width
            color: "transparent"
//            border.color: "black"
//            border.width: 1
//            radius: 10
                Text {
                    id: staffRole
                    anchors.top: parent.top
                    anchors.topMargin: 2
                    anchors.left: parent.left
                    anchors.leftMargin: 5
                    text: role_i18n
                    font.pointSize: 16
                    font.bold: role === "leader"?true:false
                }
                Text {
                    id: name
                    anchors.top: staffRole.bottom
                    anchors.topMargin: 5
                    anchors.left: parent.left
                    anchors.leftMargin: 5
                    text: account_name
                    font.bold: true
                    font.pointSize: 18
                }
                Rectangle {
                    anchors.top: parent.bottom
                    anchors.horizontalCenter: parent.horizontalCenter
                    width: parent.width
                    height: 3
                    radius: 10
                    smooth: true
                    gradient:  Gradient {
                        GradientStop { position: 0.0; color: "gray" }
                        GradientStop { position: 0.33; color: "white" }
                        GradientStop { position: 1.0; color: "lightgray" }
                    }
                }
            MouseArea {
                anchors.fill: parent
                onClicked: {
                    pageStack.push(Qt.resolvedUrl("userInfoPage.qml"), {userId: account_id, clanId: clanId, claster: claster, needRequest: true, needClanRequest: false})
                }
            }
        }
    }

    Component {
        id: vechiclesHeaderDelegate
        Item {
            id: vechiclesHeaderItem
            width: clanInfoPage.width
            height: 65
            ListView {
                anchors.fill: parent
                model: vehicleNationList
                delegate: vechiclesNationsDelegate
                orientation: ListView.Horizontal
            }
            Rectangle {
                id: headerDelimiter
                anchors.bottom: parent.bottom
                anchors.bottomMargin: 2
                anchors.horizontalCenter: parent.horizontalCenter
                width: parent.width * 0.95
                height: 3
                radius: 10
                smooth: true
                gradient:  Gradient {
                    GradientStop { position: 0.0; color: "gray" }
                    GradientStop { position: 0.33; color: "white" }
                    GradientStop { position: 1.0; color: "lightgray" }
                }
            }
        }
    }

    Component {
        id: vechiclesNationsDelegate
        Rectangle {
            height: 60
//            width: parent.width * 0.3
            width: 70
            color: "transparent"
            Image {
//                anchors.left: parent.left
//                anchors.leftMargin: 5
//                anchors.verticalCenter: parent.verticalCenter
                anchors.centerIn: parent
                width: 50
                height: 50
                fillMode: Image.PreserveAspectFit
                smooth: true
                source: getVehicleNation(nation)
                MouseArea {
                    anchors.fill: parent
                    onClicked: {
                        filterByNation(nation);
                    }
                }
            }
            Rectangle {
                id: vechiclesNationsDelimeter
                color: "#000080"
                height: parent.height
                width: 1
                anchors.right: parent.right
                anchors.verticalCenter: parent.verticalCenter
            }

            function getVehicleNation(value) {
                var nations = {uk: "uk.png", usa: "usa.png", ussr: "ussr.png", germany: "germany.png", france: "france.png", china: "china.png", japan: "japan.png"};
                return nations[value];
            }
        }
    }

    Component {
        id: vehicleModelDelegate
        Rectangle {
            id: vehicleItem
            width: parent.width
            height: 60
            color: "transparent"
                Rectangle {
                    id: mainRect
                    color: "transparent"
//                    height: vehicleItem.height
                    anchors.fill: parent
                    Image {
                        id: vehicleImage
                        anchors.left: parent.left
                        anchors.leftMargin: 5
//                        anchors.top: parent.top
//                        anchors.topMargin: 5
                        height: 50
                        anchors.verticalCenter: parent.verticalCenter
                        fillMode: Image.PreserveAspectFit
                        smooth: true
                        source: tank.image

                        Rectangle {
                            id: vehiclesLevel
                            radius: 5
                            color: "transparent"
                            border.color: "lightgray"
                            border.width: 1
                            width: 25
                            height: 25
                            anchors.bottom: parent.bottom
                            anchors.bottomMargin: -5
                            anchors.right: parent.right
                            anchors.rightMargin: 2
                            Text {
                                id: vehiclesLevelText
                                text: convertToRomeNumber(tank.level)//vehicles_count
                                anchors.centerIn: parent
                                font.pointSize: 10
                                font.bold: true
                            }
                        }
                        Image {
                            id: vehicleClass
                            anchors.top: parent.top
                            anchors.topMargin: -4
                            anchors.left: parent.left
                            anchors.leftMargin: -4
                            width: 25
                            height: 25
                            fillMode: Image.PreserveAspectFit
                            smooth: true
                            source: getVehicleClass(tank.type)
                        }
                        Image {
                            id: vehicleNation
                            anchors.top: parent.top
                            anchors.topMargin: -4
//                            anchors.horizontalCenter: vehiclesLevel.horizontalCenter
                            anchors.right: parent.right
//                            anchors.rightMargin: 53
                            width: 25
                            height: 25
                            fillMode: Image.PreserveAspectFit
                            smooth: true
                            source: getVehicleNation(tank.nation)
                        }
                    }
                    Label {
                        anchors.top: parent.top
                        anchors.topMargin: 1
                        anchors.left: vehicleImage.right
                        anchors.leftMargin: 5
                        anchors.right: vehiclesCount_rec.left
                        anchors.rightMargin: 5
                        text: "<b>" + replaceChar(tank.name_i18n) + "</b>"
                        wrapMode: Text.WordWrap
                        platformStyle: LabelStyle {
                            textColor: "black"
                            fontPixelSize: 23
                        }
                    }
                    ToolIcon {
                        id: vehiclesOwnersInfo
                        width: 15
                        height: 15
                        anchors.right: parent.right
                        anchors.rightMargin: 3
                        anchors.verticalCenter: parent.verticalCenter
                        platformIconId: "toolbar-next"
                        onClicked: {
                            pageStack.push(Qt.resolvedUrl("vehicleOwners.qml"), {owners: vehicleOwnersArray[tank.tank_id], imgUrl: tank.image, vehicleLabel: replaceChar(tank.name_i18n), vehicle_level: tank.level, vehicles_count: ownersCount, claster: claster})
                        }
                    }
                    Rectangle {
                        id: vehiclesCount_rec
                        radius: 5
                        color: "#79a0c1"
                        border.color: "lightblue"
                        border.width: 1
                        width: 45
                        height: 30
                        anchors.right: vehiclesOwnersInfo.left
                        anchors.rightMargin: 10
                        anchors.verticalCenter: parent.verticalCenter
                        Text {
                            id: vehiclesCount_rec_Text
                            text: ownersCount
                            color: "white"
                            anchors.centerIn: parent
                            font.pointSize: 12
                            font.bold: true
                        }
                    }
                }
                Rectangle {
                    id: delimeter
                    width: vehicleItem.width
                    anchors.top: vehicleItem.bottom
                    anchors.horizontalCenter: vehicleItem.horizontalCenter
                    height: 3
                    radius: 10
                    smooth: true
                    gradient:  Gradient {
                        GradientStop { position: 0.0; color: "gray" }
                        GradientStop { position: 0.33; color: "white" }
                        GradientStop { position: 1.0; color: "lightgray" }
                    }
                }
//            }

            MouseArea {
                anchors.fill: parent
                onClicked: {
//                    vehicleOwnersArray[tank.tank_id]
                    console.log("owners", vehicleOwnersArray[tank.tank_id], JSON.stringify(vehicleOwnersArray[tank.tank_id]))
                    pageStack.push(Qt.resolvedUrl("vehicleOwners.qml"), {owners: vehicleOwnersArray[tank.tank_id], imgUrl: tank.image, vehicleLabel: replaceChar(tank.name_i18n), vehicle_level: tank.level, vehicles_count: ownersCount, claster: claster})
                }
            }

            function replaceChar(str) {
                return str.replace(/_/g," ");
            }

            function convertToRomeNumber(num) {
                var units = ["","I","II","III","IV","V","VI","VII","VIII","IX", "X"];
                return units[num];
            }

            function getVehicleClass(type) {
                var types = {lightTank: "lightTank.png", mediumTank: "mediumTank.png", heavyTank: "heavyTank.png", ATSPG: "atspg.png", SPG: "spg.png"};
                var tmp = type.replace(/-/g,"");
                return types[tmp];
            }

            function getVehicleNation(value) {
                var nations = {uk: "uk.png", usa: "usa.png", ussr: "ussr.png", germany: "germany.png", france: "france.png", china: "china.png", japan: "japan.png"};
                return nations[value];
            }
        }
    }

    Component {
        id: clanStatusInfoDelegate
        Rectangle {
            id: clanStatusInfoItem
            width: parent.width
            height: 40
            color: "lightgray"
            border.color: "darkgray"
            border.width: 2
            radius: 10
            Text {
                anchors.left: parent.left
                anchors.leftMargin: 10
                anchors.verticalCenter: parent.verticalCenter
                text: userName
            }
        }
    }

    Component {
        id: clanStatInfoDelegate;
        Item {
            id: clanStatElem;
            height: 40
            width: parent.width
            Text {
                id: element_title
                anchors.left: parent.left
                anchors.leftMargin: 5
                anchors.verticalCenter: parent.verticalCenter
                text: position_title
                font.pointSize: 16
            }
            Text {
                id: user_title
                anchors.horizontalCenter: parent.horizontalCenter
                anchors.verticalCenter: parent.verticalCenter
                text: user
                font.pointSize: 16
            }
            Text {
                id: user_value
                anchors.right: parent.right
                anchors.rightMargin: 5
                anchors.verticalCenter: parent.verticalCenter
                text: value
                font.pointSize: 16
            }
            Rectangle {
                anchors.bottom: parent.bottom
                width: parent.width
                height: 3
                radius: 10
                smooth: true
                gradient:  Gradient {
                    GradientStop { position: 0.0; color: "gray" }
                    GradientStop { position: 0.33; color: "white" }
                    GradientStop { position: 1.0; color: "lightgray" }
                }
            }
        }
    }

    Rectangle {
        id: pageHeader
        anchors.top: parent.top
        anchors.left: parent.left
        anchors.right: parent.right
//        anchors.margins: 5
        width: parent.width
        height: 88 // userLabel.height + 10
        color: "lightgray"
        border.color: "darkgray"
        border.width: 1
//        radius: 5

        Image {
            id: clanLogo
            width: 64
            height: 64
            anchors.top: parent.top
            anchors.topMargin: 5
            anchors.left: parent.left
            anchors.leftMargin: 10
        }
        Label {
            id: clanLabel
            anchors.top: parent.top
            anchors.topMargin: 5
            anchors.left: clanLogo.right
            anchors.leftMargin: 10
            anchors.right: parent.right
            anchors.rightMargin: 10
            text: "".substring(0, 25)
            wrapMode: Text.WordWrap

            platformStyle: LabelStyle {
                textColor: "black"
                fontPixelSize: 32
            }
        }

        Text {
            id: clanCrew
            anchors.bottom: parent.bottom
            anchors.bottomMargin: 5
            anchors.left: clanLogo.right
            anchors.leftMargin: 10
            anchors.right: parent.right
            anchors.rightMargin: 10
            font.pointSize: 12
            text: ""
        }
    }

    TabGroup {
        id: tabGroup
        anchors { left: parent.left; right: parent.right; top: pageHeader.bottom; bottom: parent.bottom }
//        anchors.margins: 1

        // define the content for tab 1
        Page {
            id: tab1content
            orientationLock: PageOrientation.LockPortrait
//            visible: false
            Rectangle {
            id: frontRect
            anchors.fill: parent
            color: "transparent"

            ButtonRow {
                id: descrRect
                anchors.bottom: parent.bottom
                anchors.horizontalCenter: parent.horizontalCenter
                width: parent.width
                checkedButton: tab01
                style: TabButtonStyle {
                    fontPixelSize: 20
                }
                TabButton {
                    id: tab01
                    tab: descriptionPage
                    text: qsTr("Description")
                    enabled: true
                    checked: true
//                    BusyIndicator {
//                        id: tab1BusyIndicator
//                        anchors.centerIn: parent
//                        running: true
//                        visible: true
//                    }
                }
                TabButton {
                    id: tab02
                    tab: provincePage
                    text: qsTr("Staff")
                    enabled: true
//                    BusyIndicator {
//                        id: tab2BusyIndicator
//                        anchors.centerIn: parent
//                        running: true
//                        visible: true
//                    }
                }
            }

            TabGroup {
                id: commonTabGroup
                anchors.top: parent.top
                anchors.left: parent.left
                anchors.right: parent.right
                anchors.bottom: descrRect.top
                currentTab: descriptionPage
                Page {
                    id: descriptionPage
                    orientationLock: PageOrientation.LockPortrait
                    Label {
                        id: mottoTitle
                        anchors.top: parent.top
                        anchors.topMargin: 5
                        anchors.left: parent.left
                        anchors.leftMargin: 5
                        text: qsTr("Slogan:")

                        platformStyle: LabelStyle {
                            textColor: "black"
                            fontPixelSize: 24
                        }
                    }
                    Rectangle {
                        id: delimeterMottoTitle
                        anchors.left: mottoTitle.right
                        anchors.leftMargin: 5
                        anchors.right: parent.right
                        anchors.rightMargin: 5
                        anchors.verticalCenter: mottoTitle.verticalCenter
                        color: "#000080"
                        height: 1
                        width: parent.width - mottoTitle.width - 10
                    }
                    Flickable {
                        id: mottoTextFlickable
                        anchors.top: mottoTitle.bottom
                        anchors.margins: 5
                        width: parent.width
                        height: parent.height * 0.11
                        contentHeight: mottoText.height
                        contentWidth: parent.width
                        flickableDirection: Flickable.VerticalFlick
                        z: 0
                        clip: true
                        Text {
                            id: mottoText
                            anchors.fill: parent
                            anchors.margins: 5
                            horizontalAlignment: Text.AlignLeft
                            verticalAlignment: Text.AlignJustify
                            font.pixelSize: 18
                            wrapMode: Text.WordWrap
                        }
                    }
                    ScrollDecorator {
                        flickableItem: mottoTextFlickable;
                    }
                    Label {
                        id: mottoDescrTitle
                        anchors.top: mottoTextFlickable.bottom
                        anchors.topMargin: 5
                        anchors.left: parent.left
                        anchors.leftMargin: 5
                        text: qsTr("Description:")

                        platformStyle: LabelStyle {
                            textColor: "black"
                            fontPixelSize: 24
                        }
                    }
                    Rectangle {
                        id: delimeterMottoDescrTitle
                        anchors.left: mottoDescrTitle.right
                        anchors.leftMargin: 5
                        anchors.right: parent.right
                        anchors.rightMargin: 5
                        anchors.verticalCenter: mottoDescrTitle.verticalCenter
                        color: "#000080"
                        height: 1
                        width: parent.width - mottoDescrTitle.width - 10
                    }
                    Flickable {
                        id: flickableTextRect
                        anchors.top: mottoDescrTitle.bottom
                        width: parent.width
                        height: parent.height * 0.27
                        contentHeight: clanInfoPage.height
                        contentWidth: parent.width
                        flickableDirection: Flickable.VerticalFlick
                        z: 0
                        clip: true
                        Text {
                            id: descrText
                            horizontalAlignment: Text.AlignLeft
                            verticalAlignment: Text.AlignJustify
                            anchors.fill: parent
                            anchors.margins: 5
                            width: parent.width - 6
                            font.pixelSize: 18
                            z: 0
                            clip: true
                            text: clanModel.description_html;
                            wrapMode: Text.WordWrap

                            onLinkActivated: {
                                Qt.openUrlExternally(link)
                            }
                        }
                    }
                    ScrollDecorator {
                        flickableItem: flickableTextRect;
                    }
                    Label {
                        id: provinceTitle
                        anchors.top: flickableTextRect.bottom
                        anchors.topMargin: 5
                        anchors.left: parent.left
                        anchors.leftMargin: 5
                        text: qsTr("Clan province (") + (clanProvince.count > 0?clanProvince.count:0) + "):"

                        platformStyle: LabelStyle {
                            textColor: "black"
                            fontPixelSize: 24
                        }
                    }
                    Rectangle {
                        id: delimeterProvinceTitle
                        anchors.left: provinceTitle.right
                        anchors.leftMargin: 5
                        anchors.right: parent.right
                        anchors.rightMargin: 5
                        anchors.verticalCenter: provinceTitle.verticalCenter
                        width: parent.width - provinceTitle.width - 10
                        height: 3
                        radius: 10
                        smooth: true
                        gradient:  Gradient {
                            GradientStop { position: 0.0; color: "gray" }
                            GradientStop { position: 0.33; color: "white" }
                            GradientStop { position: 1.0; color: "lightgray" }
                        }
                    }
                    ListView {
                        id: provinceList
                        anchors.top: provinceTitle.bottom
                        width: parent.width
                        height: parent.height * 0.17
                        visible: clanProvince.count > 0?true:false
                        clip: true
                        spacing: 5
                        model: clanProvince
                        delegate: clanProvinceDelegate
                        header: clanProvinceHeaderDelegate
                    }
                    ScrollDecorator {
                        flickableItem: provinceList;
                    }
                    Label {
                        id: battleTitle
                        anchors.top: provinceList.bottom
                        anchors.topMargin: 5
                        anchors.left: parent.left
                        anchors.leftMargin: 5
                        text: qsTr("Planned fights (") + (clanBattles.count > 0?clanBattles.count:0) + "):"

                        platformStyle: LabelStyle {
                            textColor: "black"
                            fontPixelSize: 24
                        }
                    }
                    Rectangle {
                        id: delimeterBattleTitle
                        anchors.left: battleTitle.right
                        anchors.leftMargin: 5
                        anchors.right: parent.right
                        anchors.rightMargin: 5
                        anchors.verticalCenter: battleTitle.verticalCenter
                        width: parent.width - battleTitle.width - 10
                        height: 3
                        radius: 10
                        smooth: true
                        gradient:  Gradient {
                            GradientStop { position: 0.0; color: "gray" }
                            GradientStop { position: 0.33; color: "white" }
                            GradientStop { position: 1.0; color: "lightgray" }
                        }
                    }
                    ListView {
                        id: battlesList
                        anchors.top: battleTitle.bottom
                        anchors.left: parent.left
                        anchors.leftMargin: 5
                        anchors.bottom: parent.bottom
                        width: parent.width
                        visible: clanBattles.count > 0?true:false
                        clip: true
                        spacing: 5
                        model: clanBattles
                        delegate: clanBattlesDelegate
                        header: clanBattlesHeaderDelegate
                    }
                    ScrollDecorator {
                        flickableItem: battlesList;
                    }
                }
                Page {
                    id: provincePage
                    orientationLock: PageOrientation.LockPortrait
                    Label {
                        id: staffTitle
                        anchors.top: commonTabGroup.bottom
                        anchors.left: parent.left
                        anchors.margins: 5
                        text: qsTr("Staff:")

                        platformStyle: LabelStyle {
                            textColor: "black"
                            fontPixelSize: 24
                        }
                        Rectangle {
                            id: delimeterStaffTitle
                            anchors.left: parent.right
                            anchors.leftMargin: 5
                            anchors.right: tab1content.right
                            anchors.rightMargin: 5
                            anchors.verticalCenter: parent.verticalCenter
                            width: tab1content.width - staffTitle.width - 10
                            height: 3
                            radius: 10
                            smooth: true
                            gradient:  Gradient {
                                GradientStop { position: 0.0; color: "gray" }
                                GradientStop { position: 0.33; color: "white" }
                                GradientStop { position: 1.0; color: "lightgray" }
                            }
                        }
                    }

                    ListView {
                        id: staffList
                        anchors.top: staffTitle.bottom
                        anchors.left: parent.left
                        anchors.right: parent.right
                        anchors.bottom: parent.bottom
                        anchors.margins: 5
                        height: parent.height * 0.3
                        z: 0
                        clip: true
                        spacing: 2
                        snapMode: ListView.SnapToItem
                        keyNavigationWraps: false
                        model: staffModel
                        delegate: staffDelegate
                    }
                }
            }
        }
        }

        // define the content for tab 2
        Page {
            id: tab2content
            orientationLock: PageOrientation.LockPortrait
            Rectangle {
                anchors.fill: parent
                color: "transparent"
                ListView {
                    id: vehicleList
                    anchors.fill: parent
                    z: 0
                    clip: true
                    spacing: 3
                    snapMode: ListView.SnapToItem
                    keyNavigationWraps: false
                    model: clanVehicleInfoModel
                    delegate: vehicleModelDelegate
                    header: vechiclesHeaderDelegate
                }

            }
        }

        // define the content for tab 3
        Page {
            id: tab3content
            orientationLock: PageOrientation.LockPortrait
//            visible: false
            Rectangle {
                id: clanStatsList
                anchors.fill: parent
                color: "transparent"
                function getMaxValue() {
                    var maxValue = 0;
                    var maxValUser = "";
                    var minValue = 0;
                    var minValUser = "";
                    var averageExp = 0;
                    var sniperValue = 0;
                    var sniperValueUser = "";
                    var warriorValue = 0;
                    var warriorValueUser = "";
                    var defenderValue = 0;
                    var defenderUser = "";
                    var ctfValue = 0;
                    var ctfUser = "";
                    var scoutValue = 0;
                    var scoutUser = "";
                    var battlesValue = 0;
                    var battlesUser = "";
                    var battlesValueMin = 0;
                    var battlesUserMin = "";
                    var survivedValue = 0;
                    var survivedUser = "";

                    for (var t = 0; t < clanStatusInfo.count; t++) {
                        if (maxValue < clanStatusInfo.get(t).ratings.statistics.all.battle_avg_xp) {
                            maxValue = clanStatusInfo.get(t).ratings.statistics.all.battle_avg_xp
                            maxValUser = clanStatusInfo.get(t).ratings.nickname
                        }
                        if (minValue === 0) {
                            minValue = clanStatusInfo.get(t).ratings.statistics.all.battle_avg_xp
                        }
                        if (battlesValueMin === 0) {
                            battlesValueMin = clanStatusInfo.get(t).ratings.statistics.all.battles;
                        }

                        if (minValue > clanStatusInfo.get(t).ratings.statistics.all.battle_avg_xp) {
                            minValue = clanStatusInfo.get(t).ratings.statistics.all.battle_avg_xp
                            minValUser = clanStatusInfo.get(t).ratings.nickname
                        }
                        averageExp += clanStatusInfo.get(t).ratings.statistics.all.battle_avg_xp

                        var tmpValue = clanStatusInfo.get(t).ratings.statistics.all.hits_percents;
                        if (sniperValue < tmpValue) {
                            sniperValue = tmpValue;
                            sniperValueUser = clanStatusInfo.get(t).ratings.nickname;
                        }

                        if (warriorValue < clanStatusInfo.get(t).ratings.statistics.all.frags) {
                            warriorValue = clanStatusInfo.get(t).ratings.statistics.all.frags;
                            warriorValueUser = clanStatusInfo.get(t).ratings.nickname;
                        }

                        if (defenderValue < clanStatusInfo.get(t).ratings.statistics.all.dropped_capture_points) {
                            defenderValue = clanStatusInfo.get(t).ratings.statistics.all.dropped_capture_points;
                            defenderUser = clanStatusInfo.get(t).ratings.nickname;
                        }

                        if (ctfValue < clanStatusInfo.get(t).ratings.statistics.all.capture_points) {
                            ctfValue = clanStatusInfo.get(t).ratings.statistics.all.capture_points;
                            ctfUser = clanStatusInfo.get(t).ratings.nickname;
                        }

                        if (scoutValue < clanStatusInfo.get(t).ratings.statistics.all.spotted) {
                            scoutValue = clanStatusInfo.get(t).ratings.statistics.all.spotted;
                            scoutUser = clanStatusInfo.get(t).ratings.nickname;
                        }

                        if (battlesValue < clanStatusInfo.get(t).ratings.statistics.all.battles) {
                            battlesValue = clanStatusInfo.get(t).ratings.statistics.all.battles;
                            battlesUser = clanStatusInfo.get(t).ratings.nickname;
                        }

                        if (battlesValueMin > clanStatusInfo.get(t).ratings.statistics.all.battles) {
                            battlesValueMin = clanStatusInfo.get(t).ratings.statistics.all.battles;
                            battlesUserMin = clanStatusInfo.get(t).ratings.nickname;
                        }

                        if (survivedValue < clanStatusInfo.get(t).ratings.statistics.all.survived_battles) {
                            survivedValue = clanStatusInfo.get(t).ratings.statistics.all.survived_battles;
                            survivedUser = clanStatusInfo.get(t).ratings.nickname;
                        }
                    }
                    clanStatInfo.append({position_title: qsTr("<b>Type</b>"), user: qsTr("<b>User</b>"), value: qsTr("<b>Value</b>")});
                    clanStatInfo.append({position_title: qsTr("Veteran (max)"), user: battlesUser, value: battlesValue + qsTr(" battles")});
                    clanStatInfo.append({position_title: qsTr("Veteran (min)"), user: battlesUserMin, value: battlesValueMin + qsTr(" battles")});
                    clanStatInfo.append({position_title: qsTr("Experienced (max)"), user: maxValUser, value: maxValue});
                    clanStatInfo.append({position_title: qsTr("The average experience in the clan"), user: "", value: (averageExp/clanStatusInfo.count).toFixed(2)});
                    clanStatInfo.append({position_title: qsTr("Experienced (min)"), user: minValUser, value: minValue});
                    clanStatInfo.append({position_title: qsTr("Sniper"), user: sniperValueUser, value: sniperValue + "%"});
                    clanStatInfo.append({position_title: qsTr("Warrior"), user: warriorValueUser, value: warriorValue});
                    clanStatInfo.append({position_title: qsTr("Scout"), user: scoutUser, value: scoutValue});
                    clanStatInfo.append({position_title: qsTr("Invider"), user: ctfUser, value: ctfValue});
                    clanStatInfo.append({position_title: qsTr("Defender"), user: defenderUser, value: defenderValue});
                    clanStatInfo.append({position_title: qsTr("Die hard"), user: survivedUser, value: survivedValue});

                    clanProgressBar.visible = false;
                    clanBusyIndicator.visible = false;
                    clanBusyIndicator.running = false;
                }

                ListView {
                    id: clanStatsListView
                    visible: true
                    anchors.fill: parent
                    model: clanStatInfo
                    delegate: clanStatInfoDelegate
                    z: 0
                    clip: true
                    spacing: 3
                    snapMode: ListView.SnapToItem
                }
            }
        }
    }

    Dialog {
        id: filterDialog
        title: Label {
          id: titleField
          anchors.margins: 10
          width: parent.width
          text: "Отфильтровать технику"
          color: "white"
          font.pixelSize: 24
          anchors.horizontalCenter: parent.horizontalCenter
          horizontalAlignment: Text.AlignHCenter
          Rectangle {
              width: parent.width
              height: 1
              color: "darkgray"
              anchors.top: parent.bottom
              anchors.topMargin: 2
          }
        }

        content:Item {
          id: filterContent
          height: 180
          width: parent.width
//          anchors.top: titleField.bottom
          anchors.margins: 10
          Text {
              id: sliderText
              width: parent.width
              height: 30
              anchors.top: parent.top
              anchors.horizontalCenter: parent.horizontalCenter
              anchors.margins: 10
              horizontalAlignment: Text.AlignHCenter
              text: "Показать танки от " + levelSlider.value + " до 10 уровня"
              color: "white"
              font.pixelSize: 16
          }
          Slider {
              id: levelSlider
              anchors.top: sliderText.bottom
              anchors.margins: 10
              width: parent.width
              minimumValue: 1
              maximumValue: 10
              stepSize: 1
              value: 1
//              valueIndicatorVisible: true
//              valueIndicatorText: "Показать танки от " + value + " до 10 уровня"
          }
          Rectangle {
              width: parent.width
              height: 1
              color: "transparent"
              anchors.top: parent.bottom
          }
        }

        buttons: Row {
            spacing: 5
            height: 60
            width: parent.width
//            anchors.top: filterContent.bottom
            anchors.topMargin: 30
            SheetButton {
                text: qsTr("Apply");
                platformStyle: ButtonStyle{
                    inverted: true
                    buttonHeight: 50
                    buttonWidth: parent.width * 0.30
                }
                onClicked: {
//                    var i = 0;
//                    filteredVehicleInfoModel.clear();
//                    while (i < clanVehicleInfoModel.count) {
//                        if (parseInt(levelSlider.value) <= parseInt(clanVehicleInfoModel.get(i).tank.level)) {
//                            filteredVehicleInfoModel.append(clanVehicleInfoModel.get(i));
//                        }
//                        i++;
//                    }
//                    if (filteredVehicleInfoModel.count > 0) {
//                        vehicleList.model = filteredVehicleInfoModel
//                    } else {
//                        vehicleList.model = clanVehicleInfoModel
//                    }
                    filterByLevel(levelSlider.value)
                    filterDialog.close()
                }
            }
            SheetButton {
                text: qsTr("Cancel");
                platformStyle: ButtonStyle{
                    inverted: true
                    buttonHeight: 50
                    buttonWidth: parent.width * 0.30
                }
                onClicked: {
                    filterDialog.close();
                }
            }
          }
    }

    Menu {
        id: clanMenu
//        visualParent: pageStack
        MenuLayout {
            MenuItem {
                text: qsTr("Add clan")
                enabled: showAddButton
                onClicked: {
                    if (!Settings.findClan(clanId)) {
                        enabled = false;
                        Settings.addClan(clanId, clanModel.members_count, clanLeader, clanModel.emblems.large, clanModel.name, claster)
                    } else {
                        infoBanner.text = "Clan is already present";
                        infoBanner.show();
                    }
                }
            }
            MenuItem {
                text: qsTr("Filter")
                visible: false
                enabled: false //(clanVehicleInfoModel.count > 0) ? true:false
                onClicked: {
                    filterDialog.open()
                }
            }
            MenuItem {
                text: qsTr("Compare clans")
                enabled: (clanVehicleInfoModel.count > 0) ? true:false
                onClicked: {
//                    pageStack.push(Qt.resolvedUrl("compareClans.qml"), {clan1Name: clanLabel.text, clan1ListModel: clanModel, clan1VehicleInfoModel: clanVehicleInfoModel, clan1StatInfo: clanStatInfo})
                    pageStack.push(Qt.resolvedUrl("compareClans.qml"), {clan1ListModel: clanModel, clan1VehicleInfoModel: clanVehicleInfoModel, clan1StatInfo: clanStatInfo})
                }
            }
        }
    }

    tools: ToolBarLayout {
        ToolIcon {
            platformIconId: "toolbar-back"
            onClicked: window.pageStack.pop()
        }

        ButtonRow {
            style: TabButtonStyle {
                fontPixelSize: 20
            }
            TabButton {
                id: tab1
                tab: tab1content
                text: qsTr("Clan")
                enabled: false
                BusyIndicator {
                    id: tab1BusyIndicator
                    anchors.centerIn: parent
                    running: true
                    visible: true
                }
            }
            TabButton {
                id: tab2
                tab: tab2content
                text: qsTr("Tanks")
                enabled: false
                BusyIndicator {
                    id: tab2BusyIndicator
                    anchors.centerIn: parent
                    running: true
                    visible: true
                }
            }
            TabButton {
                id: tab3
                tab: tab3content
                text: qsTr("Heroes")
                enabled: false
                BusyIndicator {
                    id: tab3BusyIndicator
                    anchors.centerIn: parent
                    running: true
                    visible: true
                }
            }
        }

        ToolIcon {
            id: addClanButton
            iconId: "toolbar-view-menu"
            onClicked: (clanMenu.status === DialogStatus.Closed) ? clanMenu.open() : clanMenu.close()//{
//                if (!Settings.findClan(clanId)) {
//                    enabled = false;
//                    Settings.addClan(clanId, clanModel.get(0).data.members_count, clanLeader, clanModel.get(0).data.emblems.large, clanModel.get(0).data.name, claster)
//                } else {
//                    infoBanner.text = "Clan is already present";
//                    infoBanner.show();
//                }
//            }
        }
    }
}
