import QtQuick 1.1
import com.nokia.meego 1.1
import com.nokia.extras 1.1     // Extras

import "HttpRequest.js" as HttpRequest
import "Database.js" as Settings

Page {
    id: compareClansPage
    orientationLock: PageOrientation.LockPortrait
    property variant clan1ListModel
    property variant clan1VehicleInfoModel
    property variant clan1StatInfo
    property string clan1Name: "Clan1"
    property string clan2Name: "??????"
    property string clan2IconSource: ""
    property int crew_count: 0
    property string clan2Id: ""
//    property int cmp_limit: 25
//    property int cmp_maxValue
//    property int cmp_offset: 0
    property string claster: "ru"

    function findClanData(data) {
        if(data !== "error") {
            var clans = [];
            for (var i in data) {
                clans.push(data[i].clan_id);
            }
            if(clans.length > 0) {
                var url = "http://api.worldoftanks." + claster + "/wot/clan/info/?application_id=demo&clan_id=" + clans.join(',');
                HttpRequest.httpRequest(url, fillClanData);
            } else {
                infoBanner.text = qsTr("Can not find clan")
                infoBanner.show()
                busyIndicator.running = false;
                busyIndicator.visible = false;
            }
        } else {
            infoBanner.text = qsTr("The error occurred during data receiving.\nResult can be incorrect.")
            infoBanner.show()
            busyIndicator.running = false;
            busyIndicator.visible = false;
        }
    }

    function fillClanData(data) {
        if(data !== "error") {
            for (var i in data) {
                searchClan.append({clan: data[i]});
            }
            busyIndicator.running = false;
            busyIndicator.visible = false;
        } else {
            infoBanner.text = qsTr("The error occurred during data receiving.\nResult can be incorrect.")
            infoBanner.show()
            busyIndicator.running = false;
            busyIndicator.visible = false;
        }
    }

    function getClanData(data) {
        if(data !== "error") {
            for(var i in data) {
                var members = [];
                clan2Name = data[clan2Id].name;
                crew_count = data[clan2Id].members_count;
                clan2IconSource = data[clan2Id].emblems.large
                for (var i in data[clan2Id].members) {
                    searchClanInfo.append(data[clan2Id].members[i])
                    members.push(data[clan2Id].members[i].account_id)
                }
                var url = "http://api.worldoftanks." + claster + "/wot/account/info/?application_id=demo&account_id=" + members.join(',');
                HttpRequest.httpRequest(url, getMaxValue);
            }
        } else {
            infoBanner.text = qsTr("The error occurred during data receiving.\nResult can be incorrect.")
            infoBanner.show()
        }
    }

    Component.onCompleted: {
        // Initialize the database
        Settings.initialize();
//        cmp_limit = Settings.getSetting("LimitFilter");
        claster = Settings.getSetting("Claster");
    }

    BusyIndicator {
        id: busyIndicator
        anchors.centerIn: parent
        running: false
        visible: false
        platformStyle: BusyIndicatorStyle { size: "large" }
    }

    InfoBanner {
        id: infoBanner
        timerShowTime: 4000
        z: 3
    }

    ListModel {
        id: compareResult
    }

    ListModel {
        id: searchClan
    }

    ListModel {
        id: clan2StatusInfo
    }

    ListModel {
        id: clan2VehicleInfoModel
    }

    ListModel {
        id: clan2StatInfo
    }

    Component {
        id: searchClanComponent
        Rectangle {
            id: infoRectangle
            height: infoColumn.height > 64?infoColumn.height:64
            width: parent.width
            color: "transparent"
            Image {
                id: clanIcon
                anchors.top: parent.top
                anchors.topMargin: 5
                anchors.left: parent.left
                anchors.leftMargin: 5

                source: clan.emblems.large
            }

            Column {
                id: infoColumn
                anchors.left: clanIcon.right
                anchors.leftMargin: 5
                spacing: 2
                Text {
                    text: clan.name.substring(0,25) + " [" + "<font color='" + clan.clan_color + "'>" + clan.abbreviation + "</font>" + "]"
                    font.bold: true
                    font.pointSize: 18
                }
                Text {
                    text: getOwner(clan)
                    font.bold: true
                    font.pointSize: 16
                    function getOwner(clan) {
                        for(var i in clan.members) {
                            if(clan.members[i].role === "leader") {
                                return qsTr("Leader: ") + clan.members[i].account_name
                            }
                        }
                    }
                }

                Text {
                    text: qsTr("Staff count: ") + clan.members_count
                    font.pointSize: 12
                }
                Text {
                    text: qsTr("Created: ") + new Date(Math.round(clan.created_at)* 1000);
                    font.pointSize: 12
                }
            }
            Rectangle {
                anchors.top: parent.bottom
                anchors.horizontalCenter: parent.horizontalCenter
                width: parent.width
                height: 3
                radius: 10
                smooth: true
                gradient:  Gradient {
                    GradientStop { position: 0.0; color: "gray" }
                    GradientStop { position: 0.33; color: "white" }
                    GradientStop { position: 1.0; color: "lightgray" }
                }
            }

            MouseArea {
                anchors.fill: parent
                onClicked: {
                    searchClanInfo.clear()
                    compareResult.clear()
                    clan2StatusInfo.clear()
                    clan2StatInfo.clear()
                    clan2VehicleInfoModel.clear()
                    var url = "http://api.worldoftanks." + claster + "/wot/clan/info/?application_id=demo&clan_id=" + clan.clan_id
                    clan2Id = clan.clan_id;
                    HttpRequest.httpRequest(url, getClanData)
                    addClanPage.visible = false
                    clanStaffInfo.visible = true
                    navBattonsRow.visible = false
                    addClanCompare.visible = true
                    switchView.visible = true
                }
            }
        }
    }

    ListModel {
        id: searchClanInfo
    }

    Component {
        id: staffDelegate
        Rectangle {
            id: userInfoRectangle
            height: role.height + name.height + 10
            width: parent.width
            color: "transparent"
//            border.color: "black"
//            border.width: 1
//            radius: 10
                Text {
                    id: role
                    anchors.top: parent.top
                    anchors.topMargin: 2
                    anchors.left: parent.left
                    anchors.leftMargin: 5
                    text: role_localised
                    font.pointSize: 16
                    font.bold: role === "leader"?true:false
                }
                Text {
                    id: name
                    anchors.top: role.bottom
                    anchors.topMargin: 5
                    anchors.left: parent.left
                    anchors.leftMargin: 5
                    text: account_name
                    font.bold: true
                    font.pointSize: 18
                }
                Rectangle {
                    anchors.top: parent.bottom
                    anchors.horizontalCenter: parent.horizontalCenter
                    width: parent.width
                    height: 3
                    radius: 10
                    smooth: true
                    gradient:  Gradient {
                        GradientStop { position: 0.0; color: "gray" }
                        GradientStop { position: 0.33; color: "white" }
                        GradientStop { position: 1.0; color: "lightgray" }
                    }
                }
            MouseArea {
                anchors.fill: parent
                onClicked: {
//                    pageStack.push(Qt.resolvedUrl("userInfoPage.qml"), {userId: account_id, clanId: clanId, claster: claster, needRequest: true, needClanRequest: false})
                }
            }
        }
    }

    Component {
        id: resultDelegate
        Rectangle {
            id: userInfoRectangle
            height: role1.height + name1.height + 10
            width: parent.width
            color: "transparent"
//            border.color: "black"
//            border.width: 1
//            radius: 10
            Label {
                id: role1
                anchors.top: parent.top
                anchors.topMargin: 2
                anchors.left: parent.left
                text: clan1CrewMemberRole
            }
                Text {
                    id: name1
                    anchors.top: role1.bottom
                    anchors.bottomMargin: 2
                    anchors.left: parent.left
                    anchors.leftMargin: 5
                    text: clan1CrewMember.substring(0, 19)
                    font.pointSize: 18
                    font.bold: clan1CrewMemberRole === qsTr("leader")?true:false
                }
                Label {
                    id: role2
                    anchors.top: parent.top
                    anchors.topMargin: 2
                    anchors.right: parent.right
                    anchors.rightMargin: 5
                    text: clan2CrewMemberRole
                }
                Text {
                    id: name2
                    anchors.top: role2.bottom
                    anchors.bottomMargin: 2
                    anchors.right: parent.right
                    anchors.rightMargin: 5
                    text: clan2CrewMember.substring(0, 19)
                    font.pointSize: 18
                    font.bold: clan2CrewMemberRole === qsTr("leader")?true:false
                }
                Rectangle {
                    anchors.top: parent.bottom
                    anchors.horizontalCenter: parent.horizontalCenter
                    width: parent.width
                    height: 3
                    radius: 10
                    smooth: true
                    gradient:  Gradient {
                        GradientStop { position: 0.0; color: "gray" }
                        GradientStop { position: 0.33; color: "white" }
                        GradientStop { position: 1.0; color: "lightgray" }
                    }
                }
            MouseArea {
                anchors.fill: parent
                onClicked: {
//                    pageStack.push(Qt.resolvedUrl("userInfoPage.qml"), {userId: account_id, clanId: clanId, claster: claster, needRequest: true, needClanRequest: false})
                }
            }
        }
    }

    Component {
        id: listViewHeader
        Rectangle {
            height: crewCount1.height + 10
            width: parent.width
            color: "lightgray"
            anchors.margins: 2
            Text {
                id: crewCount1
                anchors.top: parent.top
                anchors.left: parent.left
                anchors.leftMargin: 10
                text: clan1ListModel.members_count
                font.bold: true
                font.pointSize: 16
            }
            Text {
                id: crewCountText
                anchors.top: parent.top
                anchors.horizontalCenter: parent.horizontalCenter
                text: qsTr("Leader")
                font.pointSize: 16
            }
            Text {
                id: crewCount2
                anchors.top: parent.top
                anchors.right: parent.right
                anchors.rightMargin: 10
                text: searchClanInfo.count
                font.bold: true
                font.pointSize: 16
            }
        }
    }

    Component {
        id: compareStatInfoDelegate;
        Item {
            id: clanStatElem;
            height: 2 * element_title.height + 5
            width: parent.width
            Text {
                id: element_title
                anchors.verticalCenter: parent.verticalCenter
                anchors.horizontalCenter: parent.horizontalCenter
                text: position_title
                font.pointSize: 16
            }
            Text {
                id: user1_title
                anchors.left: parent.left
                anchors.leftMargin: 5
                anchors.top: parent.top
                anchors.topMargin: 5
                text: user1.substring(0, 20)
                font.pointSize: 16
            }
            Text {
                id: user1_value
                anchors.left: parent.left
                anchors.leftMargin: 5
                anchors.bottom: parent.bottom
                anchors.bottomMargin: 2
                color: parseInt(value1) > parseInt(value2)?"green":"red"
                text: value1
                font.pointSize: 16
            }
            Text {
                id: user2_title
                anchors.right: parent.right
                anchors.rightMargin: 5
                anchors.top: parent.top
                anchors.topMargin: 5
                text: user2.substring(0, 20)
                font.pointSize: 16
            }
            Text {
                id: user2_value
                anchors.right: parent.right
                anchors.rightMargin: 5
                anchors.bottom: parent.bottom
                anchors.bottomMargin: 2
                color: parseInt(value2) > parseInt(value1)?"green":"red"
                text: value2
                font.pointSize: 16
            }
            Rectangle {
                anchors.bottom: parent.bottom
                width: parent.width
                height: 3
                radius: 10
                smooth: true
                gradient:  Gradient {
                    GradientStop { position: 0.0; color: "gray" }
                    GradientStop { position: 0.33; color: "white" }
                    GradientStop { position: 1.0; color: "lightgray" }
                }
            }
        }
    }

    Rectangle {
        id: pageHeader
        width: parent.width
        height: 95
        color: "lightgray"
        border.color: "darkgray"
        border.width: 1
        Label {
            id: clan1Label
            anchors.top: parent.top
            anchors.left: parent.left
            anchors.leftMargin: 10
//            text: clan1Name.substring(0, 25)
            text: "<font color='" + clan1ListModel.clan_color + "'>" + clan1ListModel.name.substring(0, 25) + "</font>"
            platformStyle: LabelStyle {
                textColor: "black"
                fontPixelSize: 24
            }
        }
        Image {
            id: clan1Icon
            anchors.top: clan1Label.bottom
            anchors.left: parent.left
            anchors.leftMargin: 5
            source: clan1ListModel.emblems.large
        }
        Label {
            id: vsLabel
            anchors.centerIn: parent
            text: "VS"
            platformStyle: LabelStyle {
                textColor: "black"
                fontPixelSize: 32
            }
        }
        Label {
            id: clan2Label
            anchors.bottom: parent.bottom
            anchors.bottomMargin: 2
            anchors.right: parent.right
            anchors.rightMargin: 10
            text: clan2Name.substring(0, 25)
            platformStyle: LabelStyle {
                textColor: "black"
                fontPixelSize: 24
            }
            MouseArea {
                anchors.fill: parent
                onClicked: {
                    navBattonsRow.visible = false
                    addClanCompare.visible = false
                    addClanPage.visible = !addClanPage.visible
                    clanStaffInfo.visible = false
                }
            }
        }
        Image {
            id: clan2Icon
            anchors.top: parent.top
            anchors.topMargin: 2
            anchors.right: parent.right
            anchors.rightMargin: 5
            source: clan2IconSource
        }
    }

    Page {
        id: addClanPage
        anchors.top: pageHeader.bottom
        anchors.left: parent.left
        anchors.right: parent.right
        anchors.bottom: parent.bottom
        anchors.margins: 5
        orientationLock: PageOrientation.LockPortrait
        visible: false
        TextField {
            id: compareClanSearchField
            anchors.top: parent.top
            anchors.left: parent.left
            anchors.right: searchButton.left
            anchors.margins: 5
            placeholderText: qsTr("Place text here...")
            ToolIcon {
                id: searchIcon
                anchors.right: parent.right
                anchors.verticalCenter: parent.verticalCenter
                platformIconId: "toolbar-search"
            }
        }
        SheetButton {
            id: searchButton
            anchors.right: parent.right
            anchors.rightMargin: 5
//            anchors.top: parent.top
            anchors.verticalCenter: compareClanSearchField.verticalCenter
            width: parent.width * 0.2
            text: qsTr("Search")
            onClicked: {
                if (compareClanSearchField.text.length >= 2) {
                    searchClan.clear()
                    busyIndicator.running = true;
                    busyIndicator.visible = true;
                    var url = "http://api.worldoftanks." + claster + "/wot/clan/list/?application_id=demo&search=" + compareClanSearchField.text
                    HttpRequest.httpRequest(url, findClanData);
                }
            }
        }
        ListView {
            id: clanListView
            anchors.top: compareClanSearchField.bottom
            anchors.left: parent.left
            anchors.right: parent.right
            anchors.bottom: parent.bottom
            anchors.margins: 5
            z: 0
            clip: true
            spacing: 2
            snapMode: ListView.SnapToItem
            keyNavigationWraps: false
            model: searchClan
            delegate: searchClanComponent
        }
    }

    Page {
        id: clanStaffInfo
        anchors.top: pageHeader.bottom
        anchors.left: parent.left
        anchors.right: parent.right
        anchors.bottom: parent.bottom
        anchors.margins: 5
        orientationLock: PageOrientation.LockPortrait
        visible: false
        ListView {
            id: communInfo
            anchors.fill: parent
            visible: true
            z: 0
            clip: true
            spacing: 2
            snapMode: ListView.SnapToItem
            keyNavigationWraps: false
            header: listViewHeader
            model: clan2StatInfo
            delegate: compareStatInfoDelegate
        }

        ListView {
            id: clanStaffListView
            anchors.fill: parent
            visible: false
            z: 0
            clip: true
            spacing: 2
            snapMode: ListView.SnapToItem
            keyNavigationWraps: false
            header: listViewHeader
            model: compareResult
            delegate: resultDelegate
        }
    }

    tools: ToolBarLayout {
        ToolIcon {
            platformIconId: "toolbar-back"
            onClicked: window.pageStack.pop()
        }

        ToolButtonRow {
            id: navBattonsRow
            visible: false
            anchors.verticalCenter: parent.verticalCenter
            ToolIcon {
                id: searchPrevToolIcon
                platformIconId: "toolbar-previous"
                onClicked: {
                    cmp_offset -= cmp_limit
                    if ( cmp_offset >= 0 ) {
                        searchClan.clear()
                        HttpRequest.sendCompareClanInfoHttpRequest(compareClanSearchField.text, cmp_limit, cmp_offset)
                    }
                    if ( cmp_offset <= 0 ) {
                        searchPrevToolIcon.enabled = false;
                    }

                    if ( cmp_offset < cmp_maxValue ) {
                        searchNextToolIcon.enabled = true;
                    }
                }
            }
            ToolButton {
                id: filteredCountText
                anchors.verticalCenter: parent.verticalCenter
                text: " - NaN - "
            }
            ToolIcon {
                id: searchNextToolIcon
                platformIconId: "toolbar-next"
                onClicked: {
                    cmp_offset += cmp_limit
                    if ( cmp_offset < cmp_maxValue ) {
                        searchClan.clear()
                        HttpRequest.sendCompareClanInfoHttpRequest(compareClanSearchField.text, cmp_limit, cmp_offset)
                    }
                    if ( cmp_offset >= cmp_limit ) {
                        searchPrevToolIcon.enabled = true;
                    }
                    if ( (cmp_maxValue - cmp_offset) <= cmp_limit ) {
                        searchNextToolIcon.enabled = false;
                    }
                }
            }
        }

        ButtonRow {
            id: switchView
            anchors.top: parent.top
            width: parent.width
            visible: false
            TabButton {
                id: showCommunInfo
                text: qsTr("Heroes")
                onClicked: {
                    communInfo.visible = true
                    clanStaffListView.visible = false
                }
            }
            TabButton {
                id: showStaffInfo
                text: qsTr("Staff")
                onClicked: {
                    communInfo.visible = false
                    clanStaffListView.visible = true
                }
            }
        }

        ToolIcon {
            id: addClanCompare
            platformIconId: (searchClan.count == 0)?"toolbar-add":"toolbar-refresh"
            onClicked: {
//                resultPage.visible = false
                showCommunInfo.checked = true
                communInfo.visible = true
                clanStaffListView.visible = false
                switchView.visible = false
                navBattonsRow.visible = false
                addClanCompare.visible = false
                addClanPage.visible = !addClanPage.visible
                clanStaffInfo.visible = false
            }
        }
    }

    function compare() {
        var staffCount = 0;
        var clan1Keys = [];
        if(clan1ListModel.members_count >= searchClanInfo.count) {
            staffCount = clan1ListModel.members_count
        } else {
            staffCount = searchClanInfo.count
        }
        for(var key in clan1ListModel.members) {
            clan1Keys.push(key)
        }
        for(var i = 0; i < staffCount; i++) {
            compareResult.set(i, {clan1CrewMemberId: "", clan1CrewMember: "", clan1CrewMemberRole: "", clan2CrewMemberId: "", clan2CrewMember: "", clan2CrewMemberRole: ""});
            if(i < clan1ListModel.members_count) {
                var key = clan1Keys[i];
                compareResult.setProperty(i, "clan1CrewMemberId", clan1ListModel.members[key].account_id)
                compareResult.setProperty(i, "clan1CrewMember", clan1ListModel.members[key].account_name)
                compareResult.setProperty(i, "clan1CrewMemberRole", clan1ListModel.members[key].role_i18n)
            }
            if(i < searchClanInfo.count) {
                compareResult.setProperty(i, "clan2CrewMemberId", searchClanInfo.get(i).account_id)
                compareResult.setProperty(i, "clan2CrewMember", searchClanInfo.get(i).account_name)
                compareResult.setProperty(i, "clan2CrewMemberRole", searchClanInfo.get(i).role_i18n)
            }
        }
        busyIndicator.visible = false;
        busyIndicator.running = false;
    }

    function getMaxValue(data) {
        if(data !== "error") {
            for (var key in data) {
                clan2StatusInfo.append({ratings: data[key]})
            }
            var maxValue = 0;
            var maxValUser = "";
            var minValue = 0;
            var minValUser = "";
            var averageExp = 0;
            var sniperValue = 0;
            var sniperValueUser = "";
            var warriorValue = 0;
            var warriorValueUser = "";
            var defenderValue = 0;
            var defenderUser = "";
            var ctfValue = 0;
            var ctfUser = "";
            var scoutValue = 0;
            var scoutUser = "";
            var battlesValue = 0;
            var battlesUser = "";
            var battlesValueMin = 0;
            var battlesUserMin = "";
            var survivedValue = 0;
            var survivedUser = "";

            for (var t = 0; t < clan2StatusInfo.count; t++) {
                if (maxValue < clan2StatusInfo.get(t).ratings.statistics.all.battle_avg_xp) {
                    maxValue = clan2StatusInfo.get(t).ratings.statistics.all.battle_avg_xp
                    maxValUser = clan2StatusInfo.get(t).ratings.nickname
                }
                if (minValue === 0) {
                    minValue = clan2StatusInfo.get(t).ratings.statistics.all.battle_avg_xp
                }
                if (battlesValueMin === 0) {
                    battlesValueMin = clan2StatusInfo.get(t).ratings.statistics.all.battles;
                }

                if (minValue > clan2StatusInfo.get(t).ratings.statistics.all.battle_avg_xp) {
                    minValue = clan2StatusInfo.get(t).ratings.statistics.all.battle_avg_xp
                    minValUser = clan2StatusInfo.get(t).ratings.nickname
                }
                averageExp += clan2StatusInfo.get(t).ratings.statistics.all.battle_avg_xp

                var tmpValue = clan2StatusInfo.get(t).ratings.statistics.all.hits_percents;
                if (sniperValue < tmpValue) {
                    sniperValue = tmpValue;
                    sniperValueUser = clan2StatusInfo.get(t).ratings.nickname;
                }

                if (warriorValue < clan2StatusInfo.get(t).ratings.statistics.all.frags) {
                    warriorValue = clan2StatusInfo.get(t).ratings.statistics.all.frags;
                    warriorValueUser = clan2StatusInfo.get(t).ratings.nickname;
                }

                if (defenderValue < clan2StatusInfo.get(t).ratings.statistics.all.dropped_capture_points) {
                    defenderValue = clan2StatusInfo.get(t).ratings.statistics.all.dropped_capture_points;
                    defenderUser = clan2StatusInfo.get(t).ratings.nickname;
                }

                if (ctfValue < clan2StatusInfo.get(t).ratings.statistics.all.capture_points) {
                    ctfValue = clan2StatusInfo.get(t).ratings.statistics.all.capture_points;
                    ctfUser = clan2StatusInfo.get(t).ratings.nickname;
                }

                if (scoutValue < clan2StatusInfo.get(t).ratings.statistics.all.spotted) {
                    scoutValue = clan2StatusInfo.get(t).ratings.statistics.all.spotted;
                    scoutUser = clan2StatusInfo.get(t).ratings.nickname;
                }

                if (battlesValue < clan2StatusInfo.get(t).ratings.statistics.all.battles) {
                    battlesValue = clan2StatusInfo.get(t).ratings.statistics.all.battles;
                    battlesUser = clan2StatusInfo.get(t).ratings.nickname;
                }

                if (battlesValueMin > clan2StatusInfo.get(t).ratings.statistics.all.battles) {
                    battlesValueMin = clan2StatusInfo.get(t).ratings.statistics.all.battles;
                    battlesUserMin = clan2StatusInfo.get(t).ratings.nickname;
                }

                if (survivedValue < clan2StatusInfo.get(t).ratings.statistics.all.survived_battles) {
                    survivedValue = clan2StatusInfo.get(t).ratings.statistics.all.survived_battles;
                    survivedUser = clan2StatusInfo.get(t).ratings.nickname;
                }
            }
            clan2StatInfo.append({position_title: qsTr("Veteran (max)"), user2: battlesUser, value2: battlesValue + qsTr(" battles"), user1:  clan1StatInfo.get(1).user, value1: clan1StatInfo.get(1).value});
            clan2StatInfo.append({position_title: qsTr("Veteran (min)"), user2: battlesUserMin, value2: battlesValueMin + qsTr(" battles"), user1:  clan1StatInfo.get(2).user, value1: clan1StatInfo.get(2).value});
            clan2StatInfo.append({position_title: qsTr("Experienced (max)"), user2: maxValUser, value2: maxValue, user1:  clan1StatInfo.get(3).user, value1: clan1StatInfo.get(3).value});
            clan2StatInfo.append({position_title: qsTr("The average experience in the clan"), user2: "", value2: (averageExp/clan2StatusInfo.count).toFixed(2), user1:  clan1StatInfo.get(4).user, value1: clan1StatInfo.get(4).value});
            clan2StatInfo.append({position_title: qsTr("Experienced (min)"), user2: minValUser, value2: minValue, user1:  clan1StatInfo.get(5).user, value1: clan1StatInfo.get(5).value});
            clan2StatInfo.append({position_title: qsTr("Sniper"), user2: sniperValueUser, value2: sniperValue + "%", user1:  clan1StatInfo.get(6).user, value1: clan1StatInfo.get(6).value});
            clan2StatInfo.append({position_title: qsTr("Warrior"), user2: warriorValueUser, value2: warriorValue, user1:  clan1StatInfo.get(7).user, value1: clan1StatInfo.get(7).value});
            clan2StatInfo.append({position_title: qsTr("Scout"), user2: scoutUser, value2: scoutValue, user1:  clan1StatInfo.get(8).user, value1: clan1StatInfo.get(8).value});
            clan2StatInfo.append({position_title: qsTr("Invider"), user2: ctfUser, value2: ctfValue, user1:  clan1StatInfo.get(9).user, value1: clan1StatInfo.get(9).value});
            clan2StatInfo.append({position_title: qsTr("Defender"), user2: defenderUser, value2: defenderValue, user1:  clan1StatInfo.get(10).user, value1: clan1StatInfo.get(10).value});
            clan2StatInfo.append({position_title: qsTr("Die hard"), user2: survivedUser, value2: survivedValue, user1:  clan1StatInfo.get(11).user, value1: clan1StatInfo.get(11).value});

            compare();
        } else {
            infoBanner.text = qsTr("The error occurred during data receiving.\nResult can be incorrect.")
            infoBanner.show()
        }
    }
}
