import QtQuick 1.1
import com.nokia.meego 1.1
import com.nokia.extras 1.1     // Extras
import Qt.labs.components 1.1

import "HttpRequest.js" as HttpRequest
import "Database.js" as Settings

Page {
    id: compareUsersPage

    property variant user1ListModel
    property variant user1ClanData
    property string user1Name: "User1"
    property string user2Name: "??????"
    property string claster: "ru"
    property string user1TanksAverageLevel: ""
    property string user1Rating: ""
    property int tanksAverageLevel: 0
    property int tanksCount: 0

    orientationLock: PageOrientation.LockPortrait

    function findUsersData(data) {
        if(data !== "error") {
            var userIds = [];
            Settings.usersDict = {};
            for (var i in data) {
                userIds.push(data[i].account_id);
                Settings.usersDict[data[i].account_id] = {};
            }
            var url = "http://api.worldoftanks." + claster + "/wot/account/info/?application_id=demo&account_id=" + userIds.join(',');
            HttpRequest.httpRequest(url, fillUserData)
        } else {
            infoBanner.text = qsTr("The error occurred during data receiving.\nResult can be incorrect.")
            infoBanner.show()
        }
    }

    function fillUserData(data) {
        if(data !== "error") {
            var clansArray = [];
            Settings.usersDict = {};
            for (var i in data) {
                Settings.usersDict[i] = data[i];
                if(data[i].clan_id) {
                    Settings.usersDict[i]["in_clan"] = true;
                    Settings.usersDict[i]["clan"] = {};
                    clansArray.push(i);
                } else {
                    Settings.usersDict[i]["in_clan"] = false;
                    Settings.usersDict[i]["clan"] = {};
                }
            }
            if(clansArray.length > 0) {
                console.log(clansArray.join(','))
                var url = "http://api.worldoftanks." + claster + "/wot/clan/membersinfo/?application_id=demo&member_id=" + clansArray.join(',');
                HttpRequest.httpRequest(url, fillUserClanData);
            } else {
                for(var j in Settings.usersDict) {
                    searchUser.append(Settings.usersDict[j]);
                }
                busyIndicator.running = false;
                busyIndicator.visible = false;
            }
        } else {
            infoBanner.text = qsTr("The error occurred during data receiving.\nResult can be incorrect.")
            infoBanner.show()
        }
    }

    function fillUserClanData(data) {
        if(data !== "error") {
            console.log("Clan info:", JSON.stringify(data))
            for (var i in data) {
                Settings.usersDict[i]["clan"] = data[i];
            }
            for(var j in Settings.usersDict) {
                searchUser.append(Settings.usersDict[j]);
            }
            busyIndicator.running = false;
            busyIndicator.visible = false;
        } else {
            infoBanner.text = qsTr("The error occurred during data receiving.\nResult can be incorrect.")
            infoBanner.show()
        }
    }

    Component.onCompleted: {
        // Initialize the database
        Settings.initialize();
        claster = Settings.getSetting("Claster");
    }

    BusyIndicator {
        id: busyIndicator
        anchors.centerIn: parent
        running: false
        visible: false
        platformStyle: BusyIndicatorStyle { size: "large" }
    }

    InfoBanner {
        id: infoBanner
        timerShowTime: 4000
        z: 3
    }

    ListModel {
        id: resultCompareInfo
    }

    ListModel {
        id: searchUser
    }

    ListModel {
        id: tmpCompareInfo
    }

    Component {
        id: resultCompareInfoDelegate
        Item {
            id: userInfoColumn
            height: 40
            width: parent.width
            Text {
                anchors.left: parent.left
                anchors.leftMargin: 2
                anchors.verticalCenter: parent.verticalCenter
                horizontalAlignment: Text.AlignLeft
                text: user1
                font.pointSize: 14
                color: if(title !== qsTr("Losses")) {
                           (parseFloat(user1) > parseFloat(user2))?"green":(user1 === user2)?"black":"red"
                       } else {
                           (parseFloat(user1) > parseFloat(user2))?"red":(user1 === user2)?"black":"green"
                       }
            }
            Text {
                anchors.centerIn: parent
                horizontalAlignment: Text.AlignHCenter
                text: title
                font.pointSize: 14
            }
            Text {
                anchors.right: parent.right
                anchors.rightMargin: 2
                anchors.verticalCenter: parent.verticalCenter
                horizontalAlignment: Text.AlignRight
                text: user2
                font.pointSize: 14
                color: if(title !== qsTr("Losses")) {
                           (parseFloat(user1) < parseFloat(user2))?"green":(user1 === user2)?"black":"red"
                       } else {
                           (parseFloat(user1) < parseFloat(user2))?"red":(user1 === user2)?"black":"green"
                       }
            }
            Rectangle {
                anchors.top: parent.bottom
                anchors.horizontalCenter: parent.horizontalCenter
                width: parent.width
                height: 3
                radius: 10
                smooth: true
                gradient:  Gradient {
                    GradientStop { position: 0.0; color: "gray" }
                    GradientStop { position: 0.33; color: "white" }
                    GradientStop { position: 1.0; color: "lightgray" }
                }
            }
        }
    }

    Component {
        id: searchUserComponent
        Rectangle {
            id: infoRectangle
            height: infoColumn.height + 6
            width: parent.width
            color: "transparent"
            Column {
                id: infoColumn
                anchors.margins: 2
                spacing: 2
                Text {
                    text: nickname
                    font.bold: true
                    font.pointSize: 18
                }
                Image {
                    id: clanIcon
                    source: in_clan?clan.emblems.medium:""
                    visible: in_clan
                    height: 32
                    smooth: true
                    Text {
                        id: clanInfo
                        text: in_clan?"[<font color='" + clan.color + "'>" + clan.clan_name + "</font>]":""
                        visible: in_clan
                        font.bold: true
                        font.pointSize: 16
                        anchors.left: parent.right
                        anchors.leftMargin: 5
                        anchors.verticalCenter: parent.verticalCenter
                    }
                }
                Text {
                    text: qsTr("Battles: ") + statistics.all.battles + qsTr("(Wins: ") + statistics.all.wins + "/" + getPercent(statistics.all.battles, statistics.all.wins) + ")"
                    font.pointSize: 14
                }
                Text {
                    text: qsTr("Registered: ") + new Date(Math.round(created_at)* 1000);
                    font.pointSize: 12
                }
            }
            Rectangle {
                anchors.top: parent.bottom
                anchors.horizontalCenter: parent.horizontalCenter
                width: parent.width
                height: 3
                radius: 10
                smooth: true
                gradient:  Gradient {
                    GradientStop { position: 0.0; color: "gray" }
                    GradientStop { position: 0.33; color: "white" }
                    GradientStop { position: 1.0; color: "lightgray" }
                }
            }

            function getPercent(battle_count, win_count) {
                if (battle_count === 0) {
                    return 0;
                }
                var winPercent = ((win_count/battle_count) * 100 ).toFixed(2);
                var res = 0;
                if (winPercent > 50.50) {
                    res = "<font color='#00ff00'>" + winPercent + "</font>%"
                } else if (winPercent < 50.50 && winPercent > 48.50) {
                    res = "<font color='#aeed00'>" + winPercent + "</font>%"
                } else if (winPercent < 48.50 && winPercent > 46.50) {
                    res = "<font color='#eded00'>" + winPercent + "</font>%"
                } else {
                    res = "<font color='#f52900'>" + winPercent + "</font>%"
                }
                return res;
            }

            MouseArea {
                anchors.fill: parent
                onClicked: {
//                    resultPage.fillData()
                    user2Clan.text = in_clan?"[<font color='" + clan.color + "'>" + clan.abbreviation + "</font>]":""
                    user2Label.text = nickname
                    tmpCompareInfo.clear()
                    resultCompareInfo.clear()
                    resultPage.fillData(statistics.all)
                    addUserPage.visible = false
                    resultPage.visible = true
                    navBattonsRow.visible = false
                    addUserCompare.visible = true
                }
            }
        }
    }


    Rectangle {
        id: pageHeader
        width: parent.width
        height: 88
        color: "lightgray"
        border.color: "darkgray"
        border.width: 1
        Label {
            id: user1Clan
            anchors.top: parent.top
            anchors.topMargin: 5
            anchors.left: parent.left
            anchors.leftMargin: 20
            text: ""
            platformStyle: LabelStyle {
                fontPixelSize: 18
            }
            MouseArea {
                anchors.fill: parent
                onClicked: {
                    resultPage.visible = false
                    navBattonsRow.visible = false
                    addUserCompare.visible = false
                    addUserPage.visible = !addUserPage.visible
                }
            }
        }
        Label {
            id: user1Label
            anchors.verticalCenter: parent.verticalCenter
            anchors.verticalCenterOffset: 10
            anchors.left: parent.left
            anchors.leftMargin: 20
            text: user1ListModel.get(0).nickname
            platformStyle: LabelStyle {
                textColor: "black"
                fontPixelSize: 24
            }
        }
        Label {
            id: vsLabel
            anchors.centerIn: parent
            text: "VS"
            platformStyle: LabelStyle {
                textColor: "black"
                fontPixelSize: 32
            }
        }
        Label {
            id: user2Clan
            anchors.bottom: parent.bottom
            anchors.bottomMargin: 5
            anchors.right: parent.right
            anchors.rightMargin: 20
            text: ""
            platformStyle: LabelStyle {
                fontPixelSize: 18
            }
            MouseArea {
                anchors.fill: parent
                onClicked: {
                    resultPage.visible = false
                    navBattonsRow.visible = false
                    addUserCompare.visible = false
                    addUserPage.visible = !addUserPage.visible
                }
            }
        }
        Label {
            id: user2Label
            anchors.verticalCenter: parent.verticalCenter
            anchors.verticalCenterOffset: -10
            anchors.right: parent.right
            anchors.rightMargin: 20
            text: user2Name
            platformStyle: LabelStyle {
                textColor: "black"
                fontPixelSize: 24
            }
            MouseArea {
                anchors.fill: parent
                onClicked: {
                    resultPage.visible = false
                    navBattonsRow.visible = false
                    addUserCompare.visible = false
                    addUserPage.visible = !addUserPage.visible
                }
            }
        }
    }

    Page {
        id: addUserPage
        anchors.top: pageHeader.bottom
        anchors.left: parent.left
        anchors.right: parent.right
        anchors.bottom: parent.bottom
        anchors.margins: 5
        orientationLock: PageOrientation.LockPortrait
        visible: false
        TextField {
            id: compareSearchField
            anchors.top: parent.top
            anchors.left: parent.left
            anchors.right: searchButton.left
            anchors.margins: 5
            placeholderText: qsTr("Place text here...")
            ToolIcon {
                id: searchIcon
                anchors.right: parent.right
                anchors.verticalCenter: parent.verticalCenter
                platformIconId: "toolbar-search"
            }
        }
        SheetButton {
            id: searchButton
            anchors.right: parent.right
            anchors.rightMargin: 5
//            anchors.top: parent.top
            anchors.verticalCenter: compareSearchField.verticalCenter
            width: parent.width * 0.2
            text: qsTr("Search")
            onClicked: {
                if (compareSearchField.text.length >= 2) {
                    tmpCompareInfo.clear()
                    resultCompareInfo.clear()
                    searchUser.clear()
                    busyIndicator.running = true;
                    busyIndicator.visible = true;
                    var url = "http://api.worldoftanks." + claster + "/wot/account/list/?application_id=demo&search=" + compareSearchField.text
                    HttpRequest.httpRequest(url, findUsersData);
                } else {
                    infoBanner.text = qsTr("Search text is too short")
                    infoBanner.show()
                }
            }
        }
        ListView {
            id: userListView
            anchors.top: compareSearchField.bottom
            anchors.left: parent.left
            anchors.right: parent.right
            anchors.bottom: parent.bottom
            anchors.margins: 5
            z: 0
            clip: true
            spacing: 2
            snapMode: ListView.SnapToItem
            keyNavigationWraps: false
            model: searchUser
            delegate: searchUserComponent
        }
    }

    Page {
        id: resultPage
        anchors.top: pageHeader.bottom
        anchors.left: parent.left
        anchors.right: parent.right
        anchors.bottom: parent.bottom
        anchors.margins: 5
        orientationLock: PageOrientation.LockPortrait
        visible: false
        ListView {
            id: resultRect
            anchors.fill: parent
            z: 0
            clip: true
            model: resultCompareInfo
            delegate: resultCompareInfoDelegate
        }
        function fillData(user2Data) {
            resultCompareInfo.append({"title": qsTr("Battles"), "user1": user1ListModel.get(0).statistics.all.battles, "user2": user2Data.battles})
            resultCompareInfo.append({"title": qsTr("Wins percent"), "user1": ((user1ListModel.get(0).statistics.all.wins/user1ListModel.get(0).statistics.all.battles)*100).toFixed(2), "user2": ((user2Data.wins/user2Data.battles) * 100).toFixed(2)})
            var tie = user1ListModel.get(0).statistics.all.battles - user1ListModel.get(0).statistics.all.wins - user1ListModel.get(0).statistics.all.losses;
            var tie1 = user2Data.battles - user2Data.wins - user2Data.losses;
            resultCompareInfo.append({"title": qsTr("Wins"), "user1": user1ListModel.get(0).statistics.all.wins , "user2": user2Data.wins})
            resultCompareInfo.append({"title": qsTr("Losses"), "user1": user1ListModel.get(0).statistics.all.losses, "user2": user2Data.losses})
            resultCompareInfo.append({"title": qsTr("Tie"), "user1": tie, "user2": tie1})
            resultCompareInfo.append({"title": qsTr("Survived in battle"), "user1": user1ListModel.get(0).statistics.all.survived_battles, "user2": user2Data.survived_battles})
            resultCompareInfo.append({"title": qsTr("Spotted"), "user1": user1ListModel.get(0).statistics.all.spotted, "user2": user2Data.spotted})
            resultCompareInfo.append({"title": qsTr("Spotted (per battle)"), "user1": (user1ListModel.get(0).statistics.all.spotted/user1ListModel.get(0).statistics.all.battles).toFixed(2), "user2": (user2Data.spotted/user2Data.battles).toFixed(2)})
            resultCompareInfo.append({"title": qsTr("Frags"), "user1": user1ListModel.get(0).statistics.all.frags, "user2": user2Data.frags})
            resultCompareInfo.append({"title": qsTr("Frags (per battle)"), "user1": (user1ListModel.get(0).statistics.all.frags/user1ListModel.get(0).statistics.all.battles).toFixed(2), "user2": (user2Data.frags/user2Data.battles).toFixed(2)})
            resultCompareInfo.append({"title": qsTr("Experience"), "user1": user1ListModel.get(0).statistics.all.xp, "user2": user2Data.xp})
            resultCompareInfo.append({"title": qsTr("Experience per battle"), "user1": user1ListModel.get(0).statistics.all.battle_avg_xp, "user2": user2Data.battle_avg_xp})
            resultCompareInfo.append({"title": qsTr("Damage"), "user1": user1ListModel.get(0).statistics.all.damage_dealt, "user2": user2Data.damage_dealt})
            resultCompareInfo.append({"title": qsTr("Damage (per battle)"), "user1": (user1ListModel.get(0).statistics.all.damage_dealt/user1ListModel.get(0).statistics.all.battles).toFixed(2), "user2": (user2Data.damage_dealt/user2Data.battles).toFixed(2)})
            resultCompareInfo.append({"title": qsTr("Dropped capture points"), "user1": user1ListModel.get(0).statistics.all.dropped_capture_points, "user2": user2Data.dropped_capture_points})
            resultCompareInfo.append({"title": qsTr("Dropped capture (per battle)"), "user1": (user1ListModel.get(0).statistics.all.dropped_capture_points/user1ListModel.get(0).statistics.all.battles).toFixed(2), "user2": (user2Data.dropped_capture_points/user2Data.battles).toFixed(2)})
            resultCompareInfo.append({"title": qsTr("Capture points"), "user1": user1ListModel.get(0).statistics.all.capture_points, "user2": user2Data.capture_points})
            resultCompareInfo.append({"title": qsTr("Capture points (per battle)"), "user1": (user1ListModel.get(0).statistics.all.capture_points/user1ListModel.get(0).statistics.all.battles).toFixed(2), "user2": (user2Data.capture_points/user2Data.battles).toFixed(2)})
        }
        function raitingCalculation() {
            /*
                DAMAGE * (10 / (TIER + 2)) * (0.21 + 3*TIER / 100)
                FRAGS * 250 +
                SPOT * 150 +
                (log(CAP + 1,1.732))*150 +
                DEF * 150;
              */
            var tier = tanksAverageLevel/tanksCount;
//            var first = (userInfoModel.get(0).ratings.damage_dealt.value/userInfoModel.get(0).summary.battles_count) * (10 / (tier + 2)) * (0.21 + (3 * tier) / 100);
            var first = (tmpCompareInfo.get(0).ratings.damage_dealt.value/tmpCompareInfo.get(0).summary.battles_count) * (10 / (tier + 2)) * (0.23 + (2 * tier) / 100);
            var frags = (tmpCompareInfo.get(0).ratings.frags.value/tmpCompareInfo.get(0).summary.battles_count) * 250;
            var second = (tmpCompareInfo.get(0).ratings.spotted.value/tmpCompareInfo.get(0).summary.battles_count) * 150;
            var third = (Math.log(tmpCompareInfo.get(0).ratings.ctf_points.value/tmpCompareInfo.get(0).summary.battles_count + 1)/Math.log(1.732)) * 150;
            var forth = (tmpCompareInfo.get(0).ratings.dropped_ctf_points.value/tmpCompareInfo.get(0).summary.battles_count) * 150;
            console.log("tanksLevel", tanksAverageLevel, "count", tanksCount, "tier", tier, "first", first, "second", second, "third", third, "forth", forth);
            var raiting = first + frags + second + third + forth;
            return raiting;
        }

    }

    tools: ToolBarLayout {
        ToolIcon {
            platformIconId: "toolbar-back"
            onClicked: window.pageStack.pop()
        }
        ToolButtonRow {
            id: navBattonsRow
            visible: false
            anchors.verticalCenter: parent.verticalCenter
            ToolIcon {
                id: searchPrevToolIcon
                platformIconId: "toolbar-previous"
//                anchors.right: filteredCount.left
//                anchors.rightMargin: 10
                onClicked: {
                    cmp_offset -= cmp_limit
                    if ( cmp_offset >= 0 ) {
                        searchUser.clear()
                        HttpRequest.sendCompareHttpRequest(compareSearchField.text, cmp_limit, cmp_offset)
                    }
                    if ( cmp_offset <= 0 ) {
                        searchPrevToolIcon.enabled = false;
                    }

                    if ( cmp_offset < cmp_maxValue ) {
                        searchNextToolIcon.enabled = true;
                    }
                }
            }
            ToolButton {
                id: filteredCountText
                anchors.verticalCenter: parent.verticalCenter
                text: " - NaN - "
            }
            ToolIcon {
                id: searchNextToolIcon
                platformIconId: "toolbar-next"
                onClicked: {
                    cmp_offset += cmp_limit
                    if ( cmp_offset < cmp_maxValue ) {
                        searchUser.clear()
                        HttpRequest.sendCompareHttpRequest(compareSearchField.text, cmp_limit, cmp_offset)
                    }
                    if ( cmp_offset >= cmp_limit ) {
                        searchPrevToolIcon.enabled = true;
                    }
                    if ( (cmp_maxValue - cmp_offset) <= cmp_limit ) {
                        searchNextToolIcon.enabled = false;
                    }
                }
            }
        }

        ToolIcon {
            id: addUserCompare
            platformIconId: (resultCompareInfo.count == 0)?"toolbar-add":"toolbar-refresh"
            onClicked: {
                resultPage.visible = false
                navBattonsRow.visible = false
                addUserCompare.visible = false
                addUserPage.visible = !addUserPage.visible
            }
        }
    }
}
