import QtQuick 1.1
import com.nokia.meego 1.1

import "HttpRequest.js" as Request

Page {
    id: tancopediaPage
    orientationLock: PageOrientation.LockPortrait

    property variant tankInfo
    property string tankId: ""

    BusyIndicator {
        id: indicator
        anchors.centerIn: parent
        visible: false
        platformStyle: BusyIndicatorStyle {
            size: "large"
        }
    }

    Component.onCompleted: {
        var url = "http://api.worldoftanks.ru/wot/encyclopedia/tankinfo/?application_id=demo&tank_id=" + tankId;
        Request.httpRequest(url, fillBaseParams); //getTankInfo(tankId);
    }

    function getLevel(index) {
        var levels = ["", "I", "II", "III", "IV", "V", "VI", "VII", "VIII", "IX", "X"];
        return levels[index];
    }

    function getType(type) {
        switch(type) {
        case "AT-SPG":
            return qsTr("AT-SPG")
        case "lightTank":
            return qsTr("Light tank")
        case "heavyTank":
            return qsTr("Heavy tank")
        case "SPG":
            return qsTr("SPG")
        case "mediumTank":
            return qsTr("Medium tank")
        default:
            return type;
        }
    }

    function fillBaseParams(tankData) {
        if(tankData !== "error") {
            var data = tankData[tankId];
            tankName.text = data.name_i18n
            tankIcon.source = data.image
            var price = data.price_credit > 0?data.price_credit + qsTr(" credits"):data.price_gold + qsTr(" gold")
            baseInfo.text = qsTr("<b>Level: </b>") + getLevel(data.level) + qsTr("<br><b>Nation: </b>") + data.nation_i18n + qsTr("<br><b>Type: </b>") + getType(data.type) + qsTr("<br><b>Health: </b>") + data.max_health + "  HP" + qsTr("<br><b>Weight (min/max): </b>") + data.weight + "/" + data.limit_weight + qsTr(" t") + qsTr("<br><b>Speed: </b>") + data.speed_limit + qsTr(" km/h") + qsTr("<br><b>Price: </b>") + price

            baseTankModel.append({section: qsTr("Base parameters"), name: qsTr("Vehicle armor"), value: data.vehicle_armor_forehead + "/" + data.vehicle_armor_board + "/" + data.vehicle_armor_fedd + qsTr(" mm")});
            baseTankModel.append({section: qsTr("Base parameters"), name: qsTr("Chassis rotation speed"), value: data.chassis_rotation_speed + qsTr(" deg/sec")});
            baseTankModel.append({section: qsTr("Base parameters"), name: qsTr("Turret armor"), value: data.turret_armor_forehead + "/" + data.turret_armor_board + "/" + data.turret_armor_fedd + qsTr(" mm")});
            baseTankModel.append({section: qsTr("Base parameters"), name: qsTr("Turret rotation speed"), value: data.turret_rotation_speed + qsTr(" deg/sec")});
            baseTankModel.append({section: qsTr("Base parameters"), name: qsTr("Engine power"), value: data.engine_power + qsTr(" h.p.")});
            baseTankModel.append({section: qsTr("Base parameters"), name: qsTr("Radio"), value: data.radio_distance + qsTr(" m")});

            baseTankModel.append({section: qsTr("Gun"), name: qsTr("Name"), value: data.gun_name});
            baseTankModel.append({section: qsTr("Gun"), name: qsTr("Ammo"), value: data.gun_max_ammo});
            baseTankModel.append({section: qsTr("Gun"), name: qsTr("Rate"), value: data.gun_rate + qsTr(" round/minute")});
            baseTankModel.append({section: qsTr("Gun"), name: qsTr("Piercing power"), value: data.gun_piercing_power_min + "-" + data.gun_piercing_power_max + qsTr(" mm")});
            baseTankModel.append({section: qsTr("Gun"), name: qsTr("Damage"), value: data.gun_damage_min + "-" + data.gun_damage_max + " HP"});

            fillCrewData(data.crew);

            /*Get modules info*/

            var module_ids = [];
            var url = ""

            for(var i in data.guns) {
                module_ids.push(data.guns[i].module_id)
            }
            if(module_ids.length > 0) {
                url = "http://api.worldoftanks.ru/wot/encyclopedia/tankguns/?application_id=demo&module_id=" + module_ids.join(',');
                Request.httpRequest3Args(url, fillCustomParams, "guns");
            }

            module_ids = [];
            for(var i in data.chassis) {
                module_ids.push(data.chassis[i].module_id)
            }
            if(module_ids.length > 0) {
                url = "http://api.worldoftanks.ru/wot/encyclopedia/tankchassis/?application_id=demo&module_id=" + module_ids.join(',');
                Request.httpRequest3Args(url, fillCustomParams, "chassis");
            }

            module_ids = [];
            for(var i in data.turrets) {
                module_ids.push(data.turrets[i].module_id)
            }
            if(module_ids.length > 0) {
                url = "http://api.worldoftanks.ru/wot/encyclopedia/tankturrets/?application_id=demo&module_id=" + module_ids.join(',');
                Request.httpRequest3Args(url, fillCustomParams, "turrets");
            }

            module_ids = [];
            for(var i in data.engines) {
                module_ids.push(data.engines[i].module_id)
            }
            if(module_ids.length > 0) {
                url = "http://api.worldoftanks.ru/wot/encyclopedia/tankengines/?application_id=demo&module_id=" + module_ids.join(',');
                Request.httpRequest3Args(url, fillCustomParams, "engines");
            }

            module_ids = [];
            for(var i in data.radios) {
                module_ids.push(data.radios[i].module_id)
            }
            if(module_ids.length > 0) {
                url = "http://api.worldoftanks.ru/wot/encyclopedia/tankradios/?application_id=demo&module_id=" + module_ids.join(',');
                Request.httpRequest3Args(url, fillCustomParams, "radios");
            }
            indicator.running = false;
            indicator.visible = false;
        } else {
            infoBanner.text = qsTr("The error occurred during data receiving.\nResult can be incorrect.")
            infoBanner.show()
        }
    }

    function fillCrewData(data) {
        tankCrew.append({role: qsTr("<b>Base spetiality</b>"), sub_role: qsTr("<b>Optional spetiality</b>")});
        for(var i in data) {
            var res = data[i].role_i18n
            var resAdd = ""
            if(data[i].additional_roles_i18n.length > 0) {
                var tmp = []
                for (var j in data[i].additional_roles_i18n) {
                    tmp.push(data[i].additional_roles_i18n[j].role_i18n);
                }
                resAdd += tmp.join('<br>')
            }
            tankCrew.append({role: res, sub_role: resAdd});
        }
    }

    function fillCustomParams(customData, module) {
        if(customData !== "error") {
            for(var moduleId in customData) {
                var data = customData[moduleId]
                if(data !== null) {
                    var icon = "";
                    var moduleName = ""
                    switch(module) {
                    case "chassis":
                        icon = "http://wikicdn.wargaming.net/images/0/0c/Menu_icon_track.png";
                        moduleName = qsTr("Chassis")
                        tankComponents.append({section: moduleName + "|" + icon, name: qsTr("Name"), value: data.name_i18n});
                        tankComponents.append({section: moduleName + "|" + icon, name: qsTr("Level"), value: getLevel(data.level)});
                        tankComponents.append({section: moduleName + "|" + icon, name: qsTr("Load"), value: data.max_load + qsTr(" t")});
                        tankComponents.append({section: moduleName + "|" + icon, name: qsTr("Rotation speed"), value: data.rotation_speed + qsTr(" deg/sec")});
                        tankComponents.append({section: moduleName + "|" + icon, name: qsTr("Price"), value: data.price_credit + qsTr(" credits")});
                        tankComponents.append({section: moduleName + "|" + icon, name: "", value: ""});
                        break;
                    case "turrets":
                        icon = "http://wikicdn.wargaming.net/images/2/2a/Menu_icon_turret.png";
                        moduleName = qsTr("Turrets")
                        tankComponents.append({section: moduleName + "|" + icon, name: qsTr("Name"), value: data.name_i18n});
                        tankComponents.append({section: moduleName + "|" + icon, name: qsTr("Level"), value: getLevel(data.level)});
                        tankComponents.append({section: moduleName + "|" + icon, name: qsTr("Vision radius"), value: data.circular_vision_radius + qsTr(" m")});
                        tankComponents.append({section: moduleName + "|" + icon, name: qsTr("Rotation speed"), value: data.rotation_speed + qsTr(" deg/sec")});
                        tankComponents.append({section: moduleName + "|" + icon, name: qsTr("Armor"), value: data.armor_forehead + "/" + data.armor_board + "/" + data.armor_fedd + qsTr(" mm")});
                        tankComponents.append({section: moduleName + "|" + icon, name: qsTr("Price"), value: data.price_credit + qsTr(" credits")});
                        tankComponents.append({section: moduleName + "|" + icon, name: "", value: ""});
                        break;
                    case "guns":
                        icon = "http://wikicdn.wargaming.net/images/d/dc/Menu_icon_gun.png"
                        moduleName = qsTr("Guns")
                        tankComponents.append({section: moduleName + "|" + icon, name: qsTr("Name"), value: data.name_i18n});
                        tankComponents.append({section: moduleName + "|" + icon, name: qsTr("Level"), value: getLevel(data.level)});
                        tankComponents.append({section: moduleName + "|" + icon, name: qsTr("Rate"), value: data.rate + qsTr(" rounds/minute")});
                        tankComponents.append({section: moduleName + "|" + icon, name: qsTr("Piercing power"), value: data.piercing_power.join('/') + qsTr(" mm")});
                        tankComponents.append({section: moduleName + "|" + icon, name: qsTr("Damage"), value: data.damage.join('/') + " HP"});
                        tankComponents.append({section: moduleName + "|" + icon, name: qsTr("Price"), value: data.price_credit + qsTr(" credits")});
                        tankComponents.append({section: moduleName + "|" + icon, name: "", value: ""});
                        break;
                    case "engines":
                        icon = "http://wikicdn.wargaming.net/images/f/f5/Menu_icon_engine.png";
                        moduleName = qsTr("Engines")
                        tankComponents.append({section: moduleName + "|" + icon, name: qsTr("Name"), value: data.name_i18n});
                        tankComponents.append({section: moduleName + "|" + icon, name: qsTr("Level"), value: getLevel(data.level)});
                        tankComponents.append({section: moduleName + "|" + icon, name: qsTr("Engine power"), value: data.power + qsTr(" h.p.")});
                        tankComponents.append({section: moduleName + "|" + icon, name: qsTr("Chance of fire"), value: data.fire_starting_chance + " %"});
                        tankComponents.append({section: moduleName + "|" + icon, name: qsTr("Price"), value: data.price_credit + qsTr(" credits")});
                        tankComponents.append({section: moduleName + "|" + icon, name: "", value: ""});
                        break;
                    case "radios":
                        icon = "http://wikicdn.wargaming.net/images/1/18/Menu_icon_radio.png";
                        moduleName = qsTr("Radios")
                        tankComponents.append({section: moduleName + "|" + icon, name: qsTr("Name"), value: data.name_i18n});
                        tankComponents.append({section: moduleName + "|" + icon, name: qsTr("Level"), value: getLevel(data.level)});
                        tankComponents.append({section: moduleName + "|" + icon, name: qsTr("Communication range"), value: data.distance + qsTr(" m")});
                        tankComponents.append({section: moduleName + "|" + icon, name: qsTr("Price"), value: data.price_credit + qsTr(" credits")});
                        tankComponents.append({section: moduleName + "|" + icon, name: "", value: ""});
                        break;
                    }
                }
            }
        } else {
            infoBanner.text = qsTr("The error occurred during data receiving.\nResult can be incorrect.")
            infoBanner.show()
        }
    }

    ListModel {
        id: tankCrew
//        ListElement {
//            role: qsTr("<b>Base spetiality</b>")
//            sub_role: qsTr("<b>Optional spetiality</b>")
//        }
    }

    ListModel {
        id: tankComponents
    }

    Component {
        id: tankBaseParamsComponent
        Item {
            id: infoItem
            width: parent.width
            height: name !== ""?itemValue.height + 4:4
            Text {
                id: itemName
                text: name
                anchors.left: parent.left
                anchors.leftMargin: 5
                anchors.verticalCenter: parent.verticalCenter
                font.pointSize: 16
                font.bold: true
            }
            Text {
                id: itemValue
                text: value
//                width: parent.width - itemName.width - 5
                anchors.left: itemName.right
                anchors.leftMargin: 5
                anchors.right: parent.right
                anchors.rightMargin: 5
                anchors.verticalCenter: parent.verticalCenter
                font.pointSize: 16
                wrapMode: Text.WrapAtWordBoundaryOrAnywhere
                horizontalAlignment: Text.AlignRight
            }
            Rectangle {
                id: delimeter
                height: 1
                width: parent.width * 0.95
                anchors.top: itemName.top
                anchors.topMargin: 10
                anchors.horizontalCenter: parent.horizontalCenter
                color: "darkgray"
                border.color: "darkgray"
                border.width: 1
                visible: name === ""?true:false
            }
        }
    }

    Component {
        id: tankCrewDelegate

        Item {
            id: tankCrewItem
            height: mainRole.height > additionalRole.height?mainRole.height:additionalRole.height
            width: parent.width
            Text {
                id: mainRole
                anchors.top: parent.top
                anchors.left: parent.left
                anchors.leftMargin: 10
                font.pointSize: 16
                text: role
            }
            Text {
                id: additionalRole
                anchors.top: parent.top
                anchors.right: parent.right
                anchors.rightMargin: 10
                font.pointSize: 16
                text: sub_role
            }
            Rectangle {
                id: delimeter
                height: 1
                width: parent.width * 0.98
                anchors.bottom: parent.bottom
                anchors.horizontalCenter: parent.horizontalCenter
                color: "black"
                border.width: 1
                border.color: "black"
            }
        }
    }

    Component {
        id: tankComponentsSectionDelegate
        Rectangle {
            id: sectionHead
            width: parent.width
            height: 50
            color: "lightgray"
            Image {
                id: sectionIcon
                source: section.split('|')[1]
                width: 45
                height: 45
                fillMode: Image.PreserveAspectFit
                smooth: true
                anchors.left: parent.left
                anchors.leftMargin: 5
                anchors.verticalCenter: parent.verticalCenter
            }
            Label {
                text: section.split('|')[0]
                font.bold: true
                anchors.left: sectionIcon.right
                anchors.leftMargin: 20
                anchors.verticalCenter: parent.verticalCenter
            }
        }
    }

    ListModel {
        id: baseTankModel
    }

    Component {
        id: baseTankDelegate
        Item {
            id: tankBaseItem
            height: itemName.height + 10
            width: parent.width
            Text {
                id: itemName
                anchors.top: parent.top
                anchors.left: parent.left
                anchors.leftMargin: 10
                font.pointSize: 16
                text: name
            }
            Text {
                id: itemValue
                anchors.top: parent.top
                anchors.right: parent.right
                anchors.rightMargin: 10
                font.pointSize: 16
                text: value
            }
        }
    }

    Component {
        id: baseTankSection
        Rectangle {
            id: tankSection
            height: childrenRect.height
            width: tancopediaPage.width
            color: "lightgray"
            Text {
                anchors.left: parent.left
                anchors.leftMargin: 5
                text: section
                font.bold: true
                font.pointSize: 16
            }
        }
    }

    Label {
        id: tankName
        height: 50
        anchors.top: parent.top
        anchors.topMargin: 1
        anchors.horizontalCenter: parent.horizontalCenter
        font.pointSize: 32
        font.bold: true
        verticalAlignment: Text.AlignVCenter
    }

    Rectangle {
        id: mainViewShadow
        z: 0

        width: parent.width * 0.95
        height: parent.height * 0.35
        anchors.top: tankName.bottom
        anchors.topMargin: 14
        anchors.horizontalCenter: parent.horizontalCenter
        anchors.horizontalCenterOffset: 4
        radius: 10
        color: "black"
        opacity: 0.3
    }

    Rectangle {
        id: mainInfo
        width: parent.width * 0.95
        height: parent.height * 0.35
        anchors.top: tankName.bottom
        anchors.horizontalCenter: parent.horizontalCenter
        anchors.margins: 10
        radius: 8
        gradient: Gradient {
            GradientStop { position: 0.0; color: "lightgray" }
            GradientStop { position: 0.25; color: "#BFBFBF" }
            GradientStop { position: 0.5; color: "#BBB" }
            GradientStop { position: 1.0; color: "gray" }
        }
        border.color: "gray"
        border.width: 1
        Image {
            id: tankIcon
            anchors.left: parent.left
            anchors.leftMargin: 5
            anchors.verticalCenter: parent.verticalCenter
            width: 160
            height: 100
            fillMode: Image.PreserveAspectFit
            source: ""
        }
        Text {
            id: baseInfo
            anchors.left: tankIcon.right
            anchors.leftMargin: 5
//            anchors.top: parent.top
//            anchors.topMargin: 25
            anchors.verticalCenter: parent.verticalCenter
            font.pointSize: 14
        }
    }

    Item {
        id: delimeter
        anchors.top: mainViewShadow.bottom
        anchors.topMargin: 20
        height: 20
        width: parent.width
        Rectangle {
            id: delimeterLine
            height: 1
            color: "black"
            border.width: 1
            border.color: "black"
            radius: 10
            anchors.left: parent.left
            anchors.leftMargin: 5
            anchors.verticalCenter: parent.verticalCenter
            anchors.right: delimeterText.left
            anchors.rightMargin: 7
        }
        Text {
            id: delimeterText
            text: qsTr("Crew")
            anchors.right: parent.right
            anchors.rightMargin: 5
            anchors.verticalCenter: parent.verticalCenter
            font.pointSize: 18
        }
    }

    TabGroup {
        id: tabs
        anchors.top: delimeter.bottom
        anchors.topMargin: 10
        anchors.bottom: parent.bottom
        anchors.left: parent.left
        anchors.right: parent.right
        currentTab: tankCrewTab
        Page {
            id: tankCrewTab
            orientationLock: PageOrientation.LockPortrait
            visible: true
            ListView {
                id: crewListView
                anchors.fill: parent
                visible: true
//                anchors.horizontalCenter: parent.horizontalCenter
//                width: parent.width
//                height: parent.height * 0.35
                model: tankCrew
                delegate: tankCrewDelegate
                clip: true
            }
        }
        Page {
            id: tankBaseTab
            orientationLock: PageOrientation.LockPortrait
            visible: true
            ListView {
                id: baseListView
                anchors.fill: parent
                visible: true
                model: baseTankModel
                delegate: baseTankDelegate
                section.property: "section"
                section.criteria: ViewSection.FullString
                section.delegate: baseTankSection
                clip: true
            }
        }
        Page {
            id: tankAdvTab
            orientationLock: PageOrientation.LockPortrait
            visible: true
            ListView {
                id: advListView
                anchors.fill: parent
                model: tankComponents
                delegate: tankBaseParamsComponent
                section.property: "section"
                section.criteria: ViewSection.FullString
                section.delegate: tankComponentsSectionDelegate
                clip: true
            }
        }
    }

    tools: ToolBarLayout {
        ToolIcon {
            platformIconId: "toolbar-back"
            onClicked: window.pageStack.pop()
        }
        ButtonRow {
            style: TabButtonStyle {
                fontPixelSize: 20
            }
            TabButton {
                id: tab1
                tab: tankCrewTab
                enabled: true
                text: qsTr("Crew")
                onClicked: {
                    delimeterText.text = qsTr("Crew")
                }
            }
            TabButton {
                id: tab2
                tab: tankBaseTab
                enabled: true
                text: qsTr("Base<br>modules")
                onClicked: {
                    delimeterText.text = qsTr("Base complectation")
                }
            }
            TabButton {
                id: tab3
                tab: tankAdvTab
                enabled: true
                text: qsTr("Optional<br>modules")
                onClicked: {
                    delimeterText.text = qsTr("Optional modules")
                }

            }
        }
    }
}
