import QtQuick 1.1
import com.nokia.meego 1.1
import com.nokia.extras 1.1     // Extras
import Qt.labs.components 1.1

import "HttpRequest.js" as HttpRequest
import "Database.js" as Settings

Page {
    id: userInfoPage
    orientationLock: PageOrientation.LockPortrait

    property string userId
    property string clanId
    property string claster
    property bool needRequest: false
    property bool needClanRequest: true
    property bool showAddButton: true
    property bool useFilter: false

    property bool showBattelsInfo: true

    property int ligthTanks: 0
    property int tanksLevel: 0
    property int tanksBattles: 0

    property variant clanModel

    property string dialogTitle: ""
    property string medalIcon: ""
    property string medalText: ""

    //For filterByNation:
    property string currentNation: ""
    property bool isFiltered: false

    property variant nations_tmp
    property variant userRatingData
    property double tier: 0

    function getWinPercent(battle_count, win_count) {
        if (battle_count === 0) {
            return 0;
        }
        var winPercent = ((win_count/battle_count) * 100 ).toFixed(2);
        var res = 0;
        if (winPercent > 50.50) {
            res = "<font color='#00ff00'>" + winPercent + "</font>%"
        } else if (winPercent < 50.50 && winPercent > 48.50) {
            res = "<font color='#aeed00'>" + winPercent + "</font>%"
        } else if (winPercent < 48.50 && winPercent > 46.50) {
            res = "<font color='#eded00'>" + winPercent + "</font>%"
        } else {
            res = "<font color='#f52900'>" + winPercent + "</font>%"
        }
        return res;
    }

    function getSurvivedPercent(battle_count, win_count) {
        if (battle_count === 0) {
            return 0;
        }
        var winPercent = ((win_count/battle_count) * 100 ).toFixed(2);
        var res = 0;
        if (winPercent > 40.50) {
            res = "<font color='#00ff00'>" + winPercent + "</font>%"
        } else if (winPercent < 40.50 && winPercent > 30.50) {
            res = "<font color='#aeed00'>" + winPercent + "</font>%"
        } else if (winPercent < 30.50 && winPercent > 25.50) {
            res = "<font color='#eded00'>" + winPercent + "</font>%"
        } else {
            res = "<font color='#f52900'>" + winPercent + "</font>%"
        }
        return res;
    }

    function getDefeatePercent(battle_count, losses) {
        if (battle_count === 0) {
            return 0;
        }
        var loosePercent = ((losses/battle_count) * 100 ).toFixed(2);
        var res = 0;
        if (loosePercent > 50.50) {
            res = "<font color='#f52900'>" + loosePercent + "</font>%"
        } else if (loosePercent < 50.50 && loosePercent > 48.50) {
            res = "<font color='#eded00'>" + loosePercent + "</font>%"
        } else if (loosePercent < 48.50 && loosePercent > 46.50) {
            res = "<font color='#aeed00'>" + loosePercent + "</font>%"
        } else {
            res = "<font color='#00ff00'>" + loosePercent + "</font>%"
        }
        return res;
    }

    function updateUserData(clanData) {
        clanModel = clanData[clanId];
        clanLabel.text = " [<font color='" + clanModel.color + "'>" + clanModel.abbreviation.toString() + "</font>]";
        clanLabel.visible = true;
        buttonClanInfo.iconSource = clanModel.emblems.large;
        clanMember.text = clanMember.text + clanModel.members[userId].role_i18n;
        buttonClanInfo.visible = true;
        clanMember.visible = true;
    }

    function updateUserRating(data) {
        var ratingData = userRatingData = data[userId];
//        console.log("\n\nRating:", JSON.stringify(ratingData))
        var tie = userInfoModel.get(0).statistics.all.battles - userInfoModel.get(0).statistics.all.wins - userInfoModel.get(0).statistics.all.losses;
        var tie_percent = ((userInfoModel.get(0).statistics.all.battles - userInfoModel.get(0).statistics.all.wins - userInfoModel.get(0).statistics.all.losses)/userInfoModel.get(0).statistics.all.battles)*100;
        statusInfo.append({"title": qsTr("Battles"), "percent": userInfoModel.get(0).statistics.all.battles, "place": ratingData.battles_count.rank})
        statusInfo.append({"title": qsTr("Wins"), "percent": userInfoModel.get(0).statistics.all.wins + " (" + getWinPercent(ratingData.battles_count.value, userInfoModel.get(0).statistics.all.wins) + ")", "place": ratingData.wins_ratio.place})
        statusInfo.append({"title": qsTr("Losses"), "percent": userInfoModel.get(0).statistics.all.losses + " (" + getDefeatePercent(userInfoModel.get(0).statistics.all.battles, userInfoModel.get(0).statistics.all.losses) + ")", "place": ""})
        statusInfo.append({"title": qsTr("Tie"), "percent": tie + " (" + tie_percent.toFixed(2) + "%)", "place": ""})
        statusInfo.append({"title": qsTr("Survived in battle"), "percent": userInfoModel.get(0).statistics.all.survived_battles + " (" + getSurvivedPercent(userInfoModel.get(0).statistics.all.battles, userInfoModel.get(0).statistics.all.survived_battles) + ")", "place": ""})
        statusInfo.append({"title": qsTr("Damage"), "percent": ratingData.damage_dealt.value, "place": ratingData.damage_dealt.rank})
        statusInfo.append({"title": qsTr("Damage (per battle)"), "percent": (ratingData.damage_dealt.value/ratingData.battles_count.value).toFixed(2), "place": ""})
        statusInfo.append({"title": qsTr("Accuracy"), "percent": ratingData.hits_ratio.value + "%", "place": ratingData.hits_ratio.rank})
        statusInfo.append({"title": qsTr("Frags"), "percent": ratingData.frags_count.value, "place": ratingData.frags_count.rank})
        statusInfo.append({"title": qsTr("Frags (per battle)"), "percent": (ratingData.frags_count.value/ratingData.battles_count.value).toFixed(2), "place": ""})
        statusInfo.append({"title": qsTr("Experience"), "percent": userInfoModel.get(0).statistics.all.xp, "place": ratingData.xp_amount.rank})
        statusInfo.append({"title": qsTr("Experience per battle"), "percent": ratingData.xp_avg.value, "place": ratingData.xp_avg.rank})
        statusInfo.append({"title": qsTr("Maximum experience"), "percent": ratingData.xp_max.value, "place": ratingData.xp_max.rank})
        statusInfo.append({"title": qsTr("Spotted"), "percent": userInfoModel.get(0).statistics.all.spotted, "place": ratingData.spotted_count.rank})
        statusInfo.append({"title": qsTr("Spotted (per battle)"), "percent": (userInfoModel.get(0).statistics.all.spotted/userInfoModel.get(0).statistics.all.battles).toFixed(2), "place": ""})
        statusInfo.append({"title": qsTr("Shots"), "percent": userInfoModel.get(0).statistics.all.shots, "place": ""})
        statusInfo.append({"title": qsTr("Dropped capture points"), "percent": userInfoModel.get(0).statistics.all.dropped_capture_points, "place": ""})
        statusInfo.append({"title": qsTr("Dropped capture (per battle)"), "percent": (userInfoModel.get(0).statistics.all.dropped_capture_points/userInfoModel.get(0).statistics.all.battles).toFixed(2), "place": ""})
        statusInfo.append({"title": qsTr("Capture points"), "percent": userInfoModel.get(0).statistics.all.capture_points, "place": ""})
        statusInfo.append({"title": qsTr("Capture points (per battle)"), "percent": (userInfoModel.get(0).statistics.all.capture_points/userInfoModel.get(0).statistics.all.battles).toFixed(2), "place": ""})
        tab1BusyIndicator.running = false;
        tab1BusyIndicator.visible = false;
        tab1.enabled = true;

        var url = "http://api.worldoftanks." + claster + "/wot/account/tanks/?application_id=demo&fields=tank_id,mark_of_mastery,statistics.battles,statistics.wins&account_id=" + userId;
        HttpRequest.httpRequest(url, updateUserTanks)
    }

    function updateUserTanks(data) {
        if(data !== "error") {
//            console.log("Data:", JSON.stringify(data[userId]))
            var tanksCount = Object.keys(data[userId]).length;
            var tanksIdArray = [];
            var vehicleData = {};
            for (var i in data[userId]) {
                var tmpDict = { tankInfo: "", statistic: data[userId][i]};
                vehicleData[data[userId][i].tank_id] = tmpDict;
                tanksIdArray.push(data[userId][i].tank_id);
            }

            var tanksIdList = tanksIdArray.join(',');
//            getUserTankInfo(tanksIdList, vehicleData, userId, claster);
            var url = "http://api.worldoftanks." + claster + "/wot/encyclopedia/tankinfo/?application_id=demo&fields=name_i18n,image,tank_id,nation_i18n,nation,level,type&tank_id=" + tanksIdList;
            HttpRequest.httpRequest3Args(url, getUserTankInfo, vehicleData)
        } else {
            infoBanner.text = qsTr("The error occurred during data receiving.\nResult can be incorrect.")
            infoBanner.show()
        }
    }

    function getUserTankInfo(data, vehicleData) {
        if(data !== "error") {
//            console.log("getUserTankInfo:", JSON.stringify(data))
//            console.log("getUserTankInfo:")
            var tanks_nation = {};
            var nations_tmp = {};
            for (var i in data) {
                vehicleData[data[i].tank_id].tankInfo = data[i]
                if(tanks_nation.hasOwnProperty(data[i].nation)) {
                    var nation_count = vechiclesNations.get(nations_tmp[data[i].nation]).count + 1;
//                    console.log("nation_count", nation_count, data[i].nation)
                    vechiclesNations.setProperty(nations_tmp[data[i].nation], "count", nation_count);
                } else {
                    tanks_nation[data[i].nation] = 1;
//                    console.log("nation_count equal 1", data[i].nation)
                    vechiclesNations.append({"nation": data[i].nation, "count": 1});
                    nations_tmp[data[i].nation] = vechiclesNations.count - 1;
                }
            }

            var url = "http://api.worldoftanks." + claster + "/wot/tanks/stats/?application_id=demo&fields=all,max_xp,max_frags,in_garage,tank_id&account_id=" + userId;
            HttpRequest.httpRequest3Args(url, getUserTankStats, vehicleData);
//            getUserTankStats(user_Id, vehicleData, claster);
        } else {
            infoBanner.text = qsTr("The error occurred during data receiving.\nResult can be incorrect.")
            infoBanner.show()
        }
    }

    function getUserTankStats(data, vehicleData) {
        if(data !== "error") {
//            console.log("Data:", JSON.stringify(data[userId]))

            for (var i in data[userId]) {
                if(vehicleData[data[userId][i].tank_id]) {
                    vehicleData[data[userId][i].tank_id].tankStats = data[userId][i]
                }
            }
            for (var j in vehicleData) {
                vehicleInfoModel.append(vehicleData[j]);
            }
            calculateTIER();
            tab2BusyIndicator.running = false;
            tab2BusyIndicator.visible = false;
            tab2.enabled = true;
        } else {
            infoBanner.text = qsTr("The error occurred during data receiving.\nResult can be incorrect.")
            infoBanner.show()
        }
    }

    function calculateTIER() {
        var allTanks = 0.00
        for (var i = 0; i < vehicleInfoModel.count; ++i) {
            allTanks += parseFloat(vehicleInfoModel.get(i).statistic.statistics.battles) * parseFloat(vehicleInfoModel.get(i).tankInfo.level);
        }
        tier = allTanks/parseFloat(userInfoModel.get(0).statistics.all.battles);
//        console.log("TIER", tier)
        statusInfo.insert(0, {"title": qsTr("Average tanks<br>level"), "percent": tier.toFixed(2), "place": ""})
        raitingCalculation() ;
    }

    function raitingCalculation() {
        /*
            DAMAGE * (10 / (TIER + 2)) * (0.23 + 3*TIER / 100)
            FRAGS * 250 +
            SPOT * 150 +
            (log(CAP + 1,1.732))*150 +
            DEF * 150;
          */
//            var tier = tanksLevel/tanksBattles;
        var cap = userInfoModel.get(0).statistics.all.capture_points/userRatingData.battles_count.value;
//            var first = (userInfoModel.get(0).ratings.damage_dealt.value/userInfoModel.get(0).summary.battles_count) * (10 / (tier + 2)) * (0.21 + (3 * tier) / 100);
        var first = (userRatingData.damage_dealt.value/userRatingData.battles_count.value) * (10 / (tier + 2)) * (0.23 + (2 * tier) / 100);
        var frags = (userRatingData.frags_count.value/userRatingData.battles_count.value) * 250;
        var second = (userInfoModel.get(0).statistics.all.spotted/userRatingData.battles_count.value) * 150;
        var third = (Math.log(cap + 1)/Math.log(1.732)) * 150;
        var forth = (userInfoModel.get(0).statistics.all.dropped_capture_points/userRatingData.battles_count.value) * 150;
//        console.log("cap", cap, "tier", tier, "cap", cap, "first", first, "frags", frags, "second", second, "third", third, "forth", forth);
        var raiting = first + frags + second + third + forth;
        statusInfo.insert(0, {"title": qsTr("Rating"), "percent": raiting.toFixed(2), "place": ""})
        raitingWN6Calculation();
    }

    function raitingWN6Calculation() {
        /*
            (1240-1040/(MIN(TIER,6))^0.164)*FRAGS
            +DAMAGE*530/(184*e^(0.24*TIER)+130)
            +SPOT*125
            +MIN(DEF,2.2)*100
            +((185/(0.17+exp((WINRATE-35)*-0.134)))-500)*0.45
            +(6-MIN(TIER,6))*-60
          */
        var frags = (1240-1040/Math.pow(Math.min(tier,6), 0.164)) * (userRatingData.frags_count.value/userRatingData.battles_count.value);
        var damage = (userRatingData.damage_dealt.value/userRatingData.battles_count.value) * 530/(184*Math.exp((0.24*tier))+130);
        var spot = (userInfoModel.get(0).statistics.all.spotted/userRatingData.battles_count.value) * 125;
        var defence = Math.min((userInfoModel.get(0).statistics.all.dropped_capture_points/userRatingData.battles_count.value), 2.2)*100;
        var winrate = ((185/(0.17 + Math.exp((userRatingData.wins_ratio.value - 35) * -0.134))) - 500) * 0.45;
        var raiting = frags + damage + spot + defence + winrate
//        console.log("raiting", raiting, "frags", frags, "damage", damage, "spot" , spot, "defence", defence, "winrate", winrate);
        statusInfo.insert(0, {"title": qsTr("WN6 rating"), "percent": raiting.toFixed(2), "place": ""})
        raitingWN7Calculation();
    }

    function raitingWN7Calculation() {
        /*
            (1240-1040/(min(TIER,6)^0.164))*FRAGS
            + DAMAGE * 530/(184*exp(0.24*TIER)+130)
            + SPOT * 125*min(TIER,3)/3
            + min(DEF,2.2)*100
            + ((185/(0.17+exp(((WINRATE)-35)*-0.134)))-500)*0.45
            + (-1*(((5 - min(TIER,5))*125)/(1 + exp((TIER-(TOTAL/220^(3/TIER)))*1.5))))
          */
        var frags = (1240-1040/Math.pow(Math.min(tier,6), 0.164)) * (userRatingData.frags_count.value/userRatingData.battles_count.value);
        var damage = (userRatingData.damage_dealt.value/userRatingData.battles_count.value) * 530/(184*Math.exp((0.24*tier))+130);
        var spot = (userInfoModel.get(0).statistics.all.spotted/userRatingData.battles_count.value) * 125;
        var defence = Math.min((userInfoModel.get(0).statistics.all.dropped_capture_points/userRatingData.battles_count.value), 2.2)*100;
        var winrate = ((185/(0.17 + Math.exp((userRatingData.wins_ratio.value - 35) * -0.134))) - 500) * 0.45;
        var total = (-1*(((5 - Math.min(tier,5))*125)/(1 + Math.exp((tier-(userRatingData.battles_count.value/Math.pow(220, (3/tier))))*1.5))));
        var raiting = frags + damage + spot + defence + winrate + total;
//        console.log("raiting", raiting, "frags", frags, "damage", damage, "spot" , spot, "defence", defence, "winrate", winrate, "total", total);
        console.log("last_battle_time", userInfoModel.get(0).last_battle_time, "logout_at", userInfoModel.get(0).logout_at)
        var lastBattle = new Date(userInfoModel.get(0).last_battle_time*1000);
        var wasOnline = new Date(userInfoModel.get(0).logout_at*1000);
        statusInfo.insert(0, {"title": qsTr("WN7 rating"), "percent": raiting.toFixed(2), "place": ""})
        statusInfo.insert(0, {"title": qsTr("Global<br>rating"), "percent": userInfoModel.get(0).global_rating, "place": ""})
        statusInfo.insert(0, {"title": qsTr("Last battle"), "percent": "", "place": lastBattle.toLocaleString("en-GB")})
        statusInfo.insert(0, {"title": qsTr("Last online"), "percent": "", "place": wasOnline.toLocaleString("ru-RU")})
    }

    function fillData(data) {
        if(data !== "error") {
//            console.log("Data:", JSON.stringify(data[userId]))
            userLabel.text = data[userId].nickname
            userInfoModel.append(data[userId]);
            if(data[userId].clan_id) {
                clanId = data[userId].clan_id
                var checkClan = "http://api.worldoftanks." + claster + "/wot/clan/info/?application_id=demo&clan_id=" + clanId;
                HttpRequest.httpRequest(checkClan, updateUserData)
            }

            var url = "http://api.worldoftanks." + claster + "/wot/ratings/accounts/?application_id=demo&account_id=" + userId + "&type=all";
            HttpRequest.httpRequest(url, updateUserRating)
        } else {
            infoBanner.text = qsTr("The error occurred during data receiving.\nResult can be incorrect.")
            infoBanner.show()
        }
    }

    function getMasterMark(mark_of_mastery) {
        var marks = ["", "class-3.png", "class-2.png", "class-1.png", "class-ace.png"];
        if (marks[mark_of_mastery]) {
            return "http://worldoftanks.ru/static/3.13.1.3/common/img/classes/" + marks[mark_of_mastery];
        } else {
            return "";
        }
    }

    function fillAchivData(data) {
        if(data !== "error") {
            var url = "http://api.worldoftanks." + claster + "/wot/encyclopedia/achievements/?application_id=demo";
            HttpRequest.httpRequest3Args(url, fillMedalsData, data[userId].achievements);
        } else {
            infoBanner.text = qsTr("The error occurred during data receiving.\nResult can be incorrect.")
            infoBanner.show()
        }
    }

    function fillMedalsData(data, achievements) {
        if(data !== "error") {
            var obj = {};
            for(var i in achievements) {
//                console.log("Info:", i, achievements[i], JSON.stringify(data[i]))
                if(data[i].type === "class") {
                    var image = data[i].options[(achievements[i] - 1)].image;
                    achievementsModel.append({name_i18n: data[i].options[(achievements[i] - 1)].name_i18n, count: "", image: image, condition: data[i].description, description: data[i].hero_info});
                } else if(data[i].type === "custom" || data[i].type === "single") {
                    achievementsModel.append({name_i18n: data[i].name_i18n, count: "", image: data[i].image, condition: "", description: data[i].description});
                } else {
                    achievementsModel.append({name_i18n: data[i].name_i18n, count: achievements[i], image: data[i].image, condition: data[i].condition, description: data[i].description});
                }
            }
//            console.log("TMP Data:", JSON.stringify(obj))
//            achievementsModel.append(obj);
            tab3BusyIndicator.running = false;
            tab3BusyIndicator.visible = false;
            tab3.enabled = true;
        } else {
            infoBanner.text = qsTr("The error occurred during data receiving.\nResult can be incorrect.")
            infoBanner.show()
        }
    }

    Component.onCompleted: {
        tabGroup.currentTab = tab1content
    }

    onStatusChanged: {
        if (status === PageStatus.Active) {
            // Initialize the database
            Settings.initialize();
            if (needRequest) {
                needRequest = false;
                var url = "http://api.worldoftanks." + claster + "/wot/account/info/?application_id=demo&account_id=" + userId;
                HttpRequest.httpRequest(url, fillData);
                tab1content.visible = true;
                var achivUrl = "http://api.worldoftanks." + claster + "/wot/account/achievements/?application_id=demo&account_id=" + userId;
                HttpRequest.httpRequest(achivUrl, fillAchivData);
            }
        }
    }

    InfoBanner {
        id: infoBanner
        timerShowTime: 4000
        z: 3
    }

    ListModel {
        id: vechiclesNations
    }

    ListModel {
        id: userInfoModel
    }

    ListModel {
        id: tmpAchievementsModel
    }

    ListModel {
        id: achievementsModel
    }

    ListModel {
        id: statusInfo
    }

    Component {
        id: statusHeader
        Item {
            id: sHead
            height: 50
            width: parent.width
            Label {
                anchors.left: parent.left
                anchors.leftMargin: 2
                anchors.verticalCenter: parent.verticalCenter
                horizontalAlignment: Text.AlignLeft
                text: qsTr("<b>Description</b>")
//                font.pointSize: 18
            }
            Label {
                anchors.centerIn: parent
                horizontalAlignment: Text.AlignHCenter
                text: qsTr("<b>Value</b>")
//                font.pointSize: 18
            }
            Label {
                anchors.right: parent.right
                anchors.rightMargin: 2
                anchors.verticalCenter: parent.verticalCenter
                horizontalAlignment: Text.AlignRight
                text: qsTr("<b>Place</b>")
//                font.pointSize: 18
            }
            Rectangle {
                anchors.top: parent.bottom
                anchors.horizontalCenter: parent.horizontalCenter
                width: parent.width
                height: 3
                radius: 10
                smooth: true
                gradient:  Gradient {
                    GradientStop { position: 0.0; color: "gray" }
                    GradientStop { position: 0.33; color: "white" }
                    GradientStop { position: 1.0; color: "lightgray" }
                }
            }
        }
    }

    Component {
        id: statusInfoDelegate
        Item {
            id: userInfoColumn
            height: 40
            width: parent.width
            Text {
                anchors.left: parent.left
                anchors.leftMargin: 2
                anchors.verticalCenter: parent.verticalCenter
                horizontalAlignment: Text.AlignLeft
                text: title
//                font.pointSize: 14
            }
            Label {
                anchors.centerIn: parent
                horizontalAlignment: Text.AlignHCenter
                text: percent
//                font.pointSize: 14
            }
            Text {
                anchors.right: parent.right
                anchors.rightMargin: 2
                anchors.verticalCenter: parent.verticalCenter
                horizontalAlignment: Text.AlignRight
                text: place
//                font.pointSize: 14
            }
            Rectangle {
                anchors.top: parent.bottom
                anchors.horizontalCenter: parent.horizontalCenter
                width: parent.width
                height: 3
                radius: 10
                smooth: true
                gradient:  Gradient {
                    GradientStop { position: 0.0; color: "gray" }
                    GradientStop { position: 0.33; color: "white" }
                    GradientStop { position: 1.0; color: "lightgray" }
                }
            }
        }
    }

    Component {
        id: userInfoModelDelegate
        Rectangle {
            id: userInfoRectangle
            height: userInfoColumn.height + 6
            width: parent.width
            color: "transparent"
            border.color: "black"
            border.width: 2
            radius: 10
            Column {
                id: userInfoColumn
                anchors.margins: 2
                spacing: 2
                Text {
                    text: name
                    font.bold: true
                }
                Text {
                    text: summary.battles_count + qsTr(" Wins (") + "<font color='#00ff00'>" + summary.wins + "</font>" + ")"
                }
            }
        }
    }

    Component {
        id: achievementsModelDelegate
        Rectangle {
            id: userAchievementsRectangle
            height: userAchievementsColumn.height + 6
            width: parent.width
            color: "transparent"
            border.color: "black"
            border.width: 2
            radius: 10
            Row {
                id: userAchievementsColumn
                spacing: 2
                Text {
                    anchors.verticalCenter: parent.verticalCenter
                    anchors.left: parent.left
                    anchors.leftMargin: 5
                    width: userInfoPage.width * 0.8
                    text: title
                    font.bold: true
//                    font.pointSize: 18
                }
                Text {
                    anchors.verticalCenter: parent.verticalCenter
                    anchors.right: parent.right
                    width: userInfoPage.width * 0.2
                    text: count
                    font.bold: true
//                    font.pointSize: 18
                }
            }
        }
    }

    ListModel {
        id: vehicleInfoModel
    }

    ListModel {
        id: filteredVehicleInfoModel
    }

    Component {
        id: vehicleModelDelegate

        Rectangle {
            id: vehicleItem
            width: parent.width
            height: 95
            color: "transparent"

            property bool expanded: false
                Rectangle {
                    color: "transparent"
//                    height: 60
                    anchors.fill: parent
                    Image {
                        id: vehicleImage
                        anchors.left: parent.left
                        anchors.leftMargin: 5
                        anchors.top: parent.top
                        anchors.topMargin: 1
//                        anchors.verticalCenter: parent.verticalCenter
//                        anchors.verticalCenterOffset: -15
                        width: 130;
                        height: 80;
                        fillMode: Image.PreserveAspectFit
                        smooth: true
                        source: tankInfo.image
//                        source: "http://worldoftanks." + claster + image_url
                        MouseArea {
                            anchors.fill: parent
                            onClicked: {
                                pageStack.push(Qt.resolvedUrl("tankopedia.qml"), {tankId: tankInfo.tank_id})
                            }
                        }

                        Rectangle {
                            id: vehiclesLevel
                            radius: 5
                            color: "transparent"
                            border.color: "lightgray"
                            border.width: 1
                            width: 25
                            height: 25
                            anchors.bottom: parent.bottom
                            anchors.bottomMargin: -5
                            anchors.right: parent.right
                            anchors.rightMargin: 5
                            Text {
                                id: vehiclesLevelText
                                text: convertToRomeNumber(tankInfo.level)
                                anchors.centerIn: parent
//                                font.pointSize: 10
                                font.bold: true
                            }
                        }
                        Image {
                            id: vehicleClass
                            anchors.top: parent.top
                            anchors.topMargin: -2
                            anchors.left: parent.left
                            anchors.leftMargin: 2
                            width: 25
                            height: 25
                            fillMode: Image.PreserveAspectFit
                            smooth: true
                            source: getVehicleClass(tankInfo["type"])
                        }
                        Image {
                            id: vehicleNation
                            anchors.top: parent.top
                            anchors.topMargin: -2
                            anchors.right: parent.right
                            anchors.rightMargin: 5
//                            anchors.horizontalCenter: vehiclesLevel.horizontalCenter
                            width: 25
                            height: 25
                            fillMode: Image.PreserveAspectFit
                            smooth: true
                            source: getVehicleNation(tankInfo.nation)
                        }
                        Image {
                            id: masterMark
                            source: getMasterMark(statistic.mark_of_mastery)
                            anchors.bottom: parent.bottom
                            anchors.left: parent.left
                            fillMode: Image.PreserveAspectFit
                            smooth: true
                        }
                    }

                    Rectangle {
                        id: verticalDelimeter
                        anchors.top: parent.top
                        anchors.topMargin: 5
                        anchors.left: vehicleImage.right
                        anchors.bottom: parent.bottom
                        anchors.bottomMargin: 5
                        width: 1
                        color: "black"
//                        anchors.bottom: vehicleImage.right
//                        anchors.horizontalCenter: parent.verticalCenter
//                        rotation: 90
//                        width: parent.height * 0.95 //3
//                        height: 3 //parent.height * 0.95
//                        radius: 10
//                        smooth: true
//                        gradient:  Gradient {
//                            GradientStop { position: 0.0; color: "gray" }
//                            GradientStop { position: 0.33; color: "white" }
//                            GradientStop { position: 1.0; color: "lightgray" }
//                        }
                    }

                    Rectangle {
                        id: info
                        anchors.top: parent.top
                        anchors.left: vehicleImage.right
                        anchors.right: parent.right
                        anchors.bottom: parent.bottom
                        color: "transparent"
                        MouseArea {
                            anchors.fill: parent
                            onClicked: {
                                expanded = !expanded
                                if (expanded) {
                                    vehicleItem.height = 150
                                } else {
                                    vehicleItem.height = 95
                                }
                            }
                        }
                    }

                    Label {
                        id: tank_name
                        anchors.top: parent.top
                        anchors.topMargin: 1
                        anchors.left: verticalDelimeter.right
                        anchors.leftMargin: 5
                        text: "<b>" + tankInfo.name_i18n.replace(/_/g," ") + "</b>"
                    }
                    Label {
                        id: battles_field
                        anchors.top: tank_name.bottom
                        anchors.left: verticalDelimeter.right
                        anchors.leftMargin: 5
                        text: qsTr("Battles: ") + statistic.statistics.battles
                    }
                    Label {
                        anchors.top: tank_name.bottom
                        anchors.right: parent.right
                        anchors.rightMargin: 2
                        text: "(" + statistic.statistics.wins + "/" + getPercent(statistic.statistics.battles, statistic.statistics.wins) + ")"
                    }

                    Item {
                        visible: expanded
                        anchors.bottom: parent.bottom
                        anchors.left: parent.left
                        width: parent.width
                        height: 55
                    Image {
                        anchors.bottom: parent.bottom
                        anchors.bottomMargin: 6
                        anchors.left: parent.left
                        anchors.leftMargin: 10
                        height: 15
                        fillMode: Image.PreserveAspectFit
                        smooth: true
                        source: "spotted.png"
                        Label {
                            anchors.left: parent.right
                            anchors.leftMargin: 5
                            anchors.verticalCenter: parent.verticalCenter
                            text: ": " + tankStats.all.spotted + "/" + "<b>" + (tankStats.all.spotted/tankStats.all.battles).toFixed(2) + "</b>"
                            platformStyle: LabelStyle {
                                fontPixelSize: 16
                            }
                        }
                    }

                    Image {
                        anchors.bottom: parent.bottom
                        anchors.bottomMargin: 1
//                        anchors.left: vehicleImage.right
//                        anchors.leftMargin: -60
                        anchors.horizontalCenter: parent.horizontalCenter
                        anchors.horizontalCenterOffset: -60
                        height: 20
                        fillMode: Image.PreserveAspectFit
                        smooth: true
                        source: "frags.png"
                        Label {
                            anchors.left: parent.right
                            anchors.leftMargin: 5
                            anchors.verticalCenter: parent.verticalCenter
                            text: ": " + tankStats.all.frags + "/" + "<b>" + (tankStats.all.frags/tankStats.all.battles).toFixed(2) + "</b>"
                            platformStyle: LabelStyle {
                                fontPixelSize: 16
                            }
                        }
                    }
                    Image {
                        anchors.bottom: parent.bottom
                        anchors.bottomMargin: 1
                        anchors.right: parent.right
                        anchors.rightMargin: damageValue.width + 6
                        height: 20
                        fillMode: Image.PreserveAspectFit
                        smooth: true
                        source: "damage.png"
                        Label {
                            id: damageValue
                            anchors.left: parent.right
                            anchors.leftMargin: 5
                            anchors.verticalCenter: parent.verticalCenter
                            text: ": " + tankStats.all.damage_dealt + "/<b>" + (tankStats.all.damage_dealt/tankStats.all.battles).toFixed(2) + "</b>"
                            platformStyle: LabelStyle {
                                fontPixelSize: 16
                            }
                        }
                    }
                }
                }
//            }
                Rectangle {
                    id: delimeter
                    anchors.top: vehicleItem.bottom
                    anchors.horizontalCenter: vehicleItem.horizontalCenter
                    width: vehicleItem.width * 0.95
                    height: 3
                    radius: 10
                    smooth: true
                    gradient:  Gradient {
                        GradientStop { position: 0.0; color: "gray" }
                        GradientStop { position: 0.33; color: "white" }
                        GradientStop { position: 1.0; color: "lightgray" }
                    }
                }

            function getPercent(battle_count, win_count) {
                if (battle_count === 0) {
                    return 0;
                }
                var winPercent = ((win_count/battle_count) * 100 ).toFixed(2);
                var res = 0;
                if (winPercent > 50.50) {
                    res = "<font color='#00ff00'>" + winPercent + "</font>%"
                } else if (winPercent < 50.50 && winPercent > 48.50) {
                    res = "<font color='#aeed00'>" + winPercent + "</font>%"
                } else if (winPercent < 48.50 && winPercent > 46.50) {
                    res = "<font color='#eded00'>" + winPercent + "</font>%"
                } else {
                    res = "<font color='#f52900'>" + winPercent + "</font>%"
                }
                return res;
            }

            function convertToRomeNumber(num) {
                var units = ["","I","II","III","IV","V","VI","VII","VIII","IX", "X"];
                return units[num];
            }

            function getVehicleClass(tankType) {
                var types = {lightTank: "lightTank.png", mediumTank: "mediumTank.png", heavyTank: "heavyTank.png", ATSPG: "atspg.png", SPG: "spg.png"};
                var tmp = tankType.replace(/-/g,"");
                return types[tmp];
            }

            function getVehicleNation(value) {
                    var nations = {uk: "uk.png", usa: "usa.png", ussr: "ussr.png", germany: "germany.png", france: "france.png", china: "china.png", japan: "japan.png"};
                return nations[value];
            }
        }
    }

    QueryDialog {
        id: vechicleInfo
        QueryDialogStyle {
            centered: false
        }
    }

    Component {
        id: vechiclesNationsDelegate
        Rectangle {
            height: 60
//            width: parent.width * 0.3
            width: 100
            color: "transparent"
            Image {
                anchors.left: parent.left
                anchors.leftMargin: 5
                anchors.verticalCenter: parent.verticalCenter
                width: 50
                height: 50
                fillMode: Image.PreserveAspectFit
                smooth: true
                source: getVehicleNation(nation)
//                font.pointSize: 18
//                font.bold: true
//                text: nation
            }
            Label {
                anchors.right: parent.right
                anchors.rightMargin: 5
                anchors.verticalCenter: parent.verticalCenter
//                font.pointSize: 18
                font.bold: true
                text: count
            }
            MouseArea {
                anchors.fill: parent
                onClicked: {
                    filterByNation(nation);
                }
            }

            Rectangle {
                id: vechiclesNationsDelimeter
                height: parent.height
                anchors.right: parent.right
                anchors.verticalCenter: parent.verticalCenter
                width: 1
                color: "black"
//                radius: 10
//                smooth: true
//                gradient:  Gradient {
//                    GradientStop { position: 0.0; color: "gray" }
//                    GradientStop { position: 0.33; color: "white" }
//                    GradientStop { position: 1.0; color: "lightgray" }
//                }
            }

            function getVehicleNation(value) {
                var nations = {uk: "uk.png", usa: "usa.png", ussr: "ussr.png", germany: "germany.png", france: "france.png", china: "china.png", japan: "japan.png"};
                return nations[value];
            }
        }
    }

    Item {
        id: pageHeaderItem
        anchors.top: parent.top
        anchors.left: parent.left
        anchors.right: parent.right
//        anchors.margins: 5
        width: parent.width
        height: 88
        Rectangle {
            id: pageHeader
            anchors.fill: parent
            color: "lightgray"
            border.color: "darkgray"
            border.width: 1
            Label {
                id: userLabel
                anchors.verticalCenter: parent.verticalCenter
                anchors.left: parent.left
                anchors.leftMargin: 20
                platformStyle: LabelStyle {
                    textColor: "black"
                    fontPixelSize: 32
                }
            }
            Label {
                id: clanLabel
                anchors.verticalCenter: parent.verticalCenter
                anchors.left: userLabel.right
                anchors.leftMargin: 5
                visible: false

                platformStyle: LabelStyle {
                    textColor: "black"
                    fontPixelSize: 32
                }
            }
            Label {
                id: clanMember
                anchors.left: parent.left
                anchors.leftMargin: 30
                anchors.bottom: parent.bottom
                anchors.bottomMargin: 5
                visible: false
                text: qsTr("Rank: ")
                platformStyle: LabelStyle {
                    textColor: "black"
                    fontPixelSize: 18
                }
            }
            Button {
                id: buttonClanInfo
                width: 78
                height: 78
                anchors.top: parent.top
                anchors.topMargin: 5
                anchors.right: parent.right
                anchors.rightMargin: 10
                visible: false
                onClicked: {
                    if (needClanRequest) {
                        needClanRequest = false;
                        pageStack.push(Qt.resolvedUrl("clanInfoPage.qml"), {clanModel: clanModel, claster: claster})
                        //pageStack.push(Qt.resolvedUrl("clanInfoPage.qml"), {clanId: clanId, claster: claster, needRequest: true})
                    }
                }
            }
        }
    }

    TabGroup {
    id: tabGroup
    anchors { left: parent.left; right: parent.right; top: pageHeaderItem.bottom; bottom: parent.bottom }
    anchors.margins: 5

    // define the content for tab 1
    Page {
        id: tab1content
        orientationLock: PageOrientation.LockPortrait
        visible: false

        Rectangle {
        id: frontData
        anchors.fill: parent
        color: "transparent"

        function fillData() {
//            battlesInfoTitle.visible = true;
            HttpRequest.getUserRateInfo(userInfoModel.get(0).account_id, claster)
            userLabel.text = userInfoModel.get(0).nickname;
            HttpRequest.checkClan(userInfoModel.get(0).account_id, claster);
            vehicleInfoModel.clear();
            HttpRequest.getUserTanks(userId, claster);

            clanLabel.visible = false;
            buttonClanInfo.visible = false;

            tab1BusyIndicator.running = false
            tab1BusyIndicator.visible = false
            tab1.enabled = true
        }

        function raitingCalculation() {
            /*
                DAMAGE * (10 / (TIER + 2)) * (0.21 + 3*TIER / 100)
                FRAGS * 250 +
                SPOT * 150 +
                (log(CAP + 1,1.732))*150 +
                DEF * 150;
              */
            var tier = tanksLevel/tanksBattles;
            var cap = userInfoModel.get(0).ratings.ctf_points.value/userInfoModel.get(0).summary.battles_count;
//            var first = (userInfoModel.get(0).ratings.damage_dealt.value/userInfoModel.get(0).summary.battles_count) * (10 / (tier + 2)) * (0.21 + (3 * tier) / 100);
            var first = (userInfoModel.get(0).ratings.damage_dealt.value/userInfoModel.get(0).summary.battles_count) * (10 / (tier + 2)) * (0.23 + (2 * tier) / 100);
            var frags = (userInfoModel.get(0).ratings.frags.value/userInfoModel.get(0).summary.battles_count) * 250;
            var second = (userInfoModel.get(0).ratings.spotted.value/userInfoModel.get(0).summary.battles_count) * 150;
            var third = (Math.log(cap + 1)/Math.log(1.732)) * 150;
            var forth = (userInfoModel.get(0).ratings.dropped_ctf_points.value/userInfoModel.get(0).summary.battles_count) * 150;
//            console.log("tier", tier, "cap", cap, "first", first, "frags", frags, "second", second, "third", third, "forth", forth);
            var raiting = first + frags + second + third + forth;
            return raiting;
        }

            ListView {
                id: battlesRect
                anchors.fill: parent
                z: 0
                clip: true
                header: statusHeader
                model: statusInfo
                delegate: statusInfoDelegate
            }

        states: [
            State {
                name: "show"
                PropertyChanges { target: battlesRect; opacity: 1 }
                PropertyChanges { target: battlesRect; height: userInfoPage.height  * 0.5 }
                when: showBattelsInfo
            },
            State {
                name: "hide"
                PropertyChanges { target: battlesRect; opacity: 0 }
                PropertyChanges { target: battlesRect; height: 0 }
                when: !showBattelsInfo
            }
        ]

        transitions: Transition {
            NumberAnimation { target: battlesRect; property: "opacity"; duration: 300 }
            NumberAnimation { target: battlesRect; property: "height"; duration: 300 }
        }
    }
    }

    // define the content for tab 2
    Page {
        id: tab2content
        orientationLock: PageOrientation.LockPortrait

        Rectangle {
        anchors.fill: parent
        color: "transparent"
        Rectangle {
            id: vechickesStatInfo
            anchors.top: parent.top
            anchors.left: parent.left
            anchors.right: parent.right
            color: "transparent"
            height: 100
            Text {
                id: nationsSummary
//                font.pointSize: 18
                text: qsTr("Tanks count: ") + vehicleInfoModel.count
            }
            ListView {
                id: nationsList
                anchors.top: nationsSummary.bottom
                anchors.left: parent.left
                anchors.right: parent.right
                anchors.bottom: parent.bottom
                orientation: ListView.Horizontal
                z: 0
                clip: true
                spacing: 2
                snapMode: ListView.SnapToItem
                keyNavigationWraps: false
                model: vechiclesNations
                delegate: vechiclesNationsDelegate
            }
        }
        Rectangle {
            id: delimeter
            height: 3
            width: vechickesStatInfo.width
            anchors.top: vechickesStatInfo.bottom
            anchors.horizontalCenter: vechickesStatInfo.horizontalCenter
            radius: 10
            smooth: true
            gradient:  Gradient {
                GradientStop { position: 0.0; color: "gray" }
                GradientStop { position: 0.33; color: "white" }
                GradientStop { position: 1.0; color: "lightgray" }
            }
        }

        ListView {
            id: vehicleList
            anchors.top: delimeter.bottom
            anchors.topMargin: 5
            anchors.left: parent.left
            anchors.right: parent.right
            anchors.bottom: parent.bottom
            z: 0
            clip: true
            spacing: 5
            snapMode: ListView.SnapToItem
            keyNavigationWraps: false
            model: vehicleInfoModel
            delegate: vehicleModelDelegate
        }
    }
    }

    // define the content for tab 3
    Page {
        id: tab3content
        orientationLock: PageOrientation.LockPortrait
        visible: false
        Flickable {
            id: achievementsPage
            anchors.fill: parent
            contentHeight: achievementsList.height
            contentWidth: parent.width
            flickableDirection: Flickable.VerticalFlick
            z: 0
            clip: true
            Grid {
                id: achievementsList
                columns: 3
                spacing: 1
                Repeater {
                    model: achievementsModel
                    Rectangle {
                        id: recHead
                        width: userInfoPage.width * 0.325
                        height: userInfoPage.width * 0.4
                        color: "lightgray"
                        border.width: 1
                        border.color: "darkgray"
                        radius: 2

                        Text {
                            id: head
                            anchors.top: parent.top
                            anchors.topMargin: 5
                            anchors.left: parent.left
                            anchors.leftMargin: 2
                            anchors.right: parent.right
                            anchors.rightMargin: 2
                            wrapMode: Text.WordWrap
                            horizontalAlignment: Text.AlignHCenter
                            font.bold: true
                            text: name_i18n
//                            font.pointSize: 15
                        }
                        Image {
                            id: icon
                            anchors.centerIn: parent
                            anchors.verticalCenterOffset: 15
                            width: parent.width * 0.75
                            height: parent.width * 0.75
                            fillMode: Image.PreserveAspectFit
                            smooth: true
                            source: image
                        }
                        Label {
                            id: achiv_count
//                            anchors.top: head.bottom
//                            anchors.topMargin: 15
                            anchors.bottom: parent.bottom
                            anchors.bottomMargin: 5
                            anchors.horizontalCenter: parent.horizontalCenter
                            text: count
//                            font.pointSize: 14
                            font.bold: true
                        }

                        MouseArea {
                            anchors.fill: parent
                            onClicked: {
                                dialogTitle = name_i18n
                                medalIcon = image
                                medalText = description + "\n" + condition
                                medalDescription.open()
                            }
                        }
                    }
                    onItemAdded: {
                        if(achievementsModel.get(index).count === 0) {
                            item.color = "red"
                            item.visible = false
                        } else {
                            item.color = "transparent"
                            item.visible = true
                        }
                    }
                }
            }
        }
        function getImage(name) {
            var icons = ['defender', 'invader', 'sniper']
            var res = icons.filter(function(value) {
                return value === name
            });
            return res;
        }
    }
}

    Dialog {
        id: medalDescription
        title: Label {
            id: medalTitle
            anchors.margins: 10
            width: parent.width
            color: "white"
//            font.pixelSize: 24
            anchors.horizontalCenter: parent.horizontalCenter
//            anchors.leftMargin: 60
            horizontalAlignment: Text.AlignHCenter
            text: dialogTitle
            Image {
                id: medalImage
                source: medalIcon
                anchors.left: parent.left
                anchors.bottom: parent.top
                anchors.bottomMargin: 10
//                width: parent.width * 0.25
//                height: parent.width * 0.25
                fillMode: Image.PreserveAspectFit
                smooth: true
            }
        }
        content: Item {
            id: medalContent
            height: 400
//            height: medalDescription.height
            width: medalDescription.width
            Label {
                id: description
                text: medalText
                width: parent.width
                anchors.centerIn: parent
                anchors.margins: 5
                color: "white"
                wrapMode: Text.WrapAtWordBoundaryOrAnywhere
            }
        }
    }

    Dialog {
        id: filterDialog
        title: Label {
          id: titleField
          anchors.margins: 10
          width: parent.width
          text: "Отфильтровать технику"
          color: "white"
//          font.pixelSize: 24
          anchors.horizontalCenter: parent.horizontalCenter
          horizontalAlignment: Text.AlignHCenter
          Rectangle {
              width: parent.width
              height: 1
              color: "darkgray"
              anchors.top: parent.bottom
              anchors.topMargin: 2
          }
        }

        content: Item {
          id: filterContent
          height: 360
          width: parent.width
//          anchors.top: titleField.bottom
          anchors.margins: 10
          Text {
              id: sliderText
              width: parent.width
              height: 30
              anchors.top: parent.top
              anchors.horizontalCenter: parent.horizontalCenter
              anchors.margins: 10
              horizontalAlignment: Text.AlignHCenter
              text: "Показать танки от " + levelSlider.value + " до 10 уровня"
              color: "white"
//              font.pixelSize: 20
          }
          Slider {
              id: levelSlider
              anchors.top: sliderText.bottom
              anchors.margins: 10
              width: parent.width
              minimumValue: 1
              maximumValue: 10
              stepSize: 1
              value: 1
          }
          Text {
              id: battlesText
              width: parent.width
              anchors.top: levelSlider.bottom
              anchors.horizontalCenter: parent.horizontalCenter
              anchors.margins: 10
              horizontalAlignment: Text.AlignHCenter
              text: "Показать танки с количеством боёв от " + battlesSlider.value
              color: "white"
//              font.pixelSize: 20
          }
          Slider {
              id: battlesSlider
              anchors.top: battlesText.bottom
              anchors.margins: 10
              width: parent.width
              minimumValue: 1
              maximumValue: 1000
              stepSize: 100
              value: 1
//              valueIndicatorVisible: true
//              valueIndicatorText: "show from " + value + " to 10"
          }
        }

        buttons: Column {
            spacing: 5
//            height: 60
            width: parent.width
//            anchors.top: filterContent.bottom
            anchors.topMargin: 30
            anchors.horizontalCenter: parent.horizontalCenter
            SheetButton {
                text: qsTr("Apply");
                width: parent.width
                platformStyle: ButtonStyle{
                    inverted: true
                    buttonHeight: 50
                    buttonWidth: parent.width * 0.30
                }
                onClicked: {
                    var i = 0;
                    filteredVehicleInfoModel.clear();
                    while (i < vehicleInfoModel.count) {
                        if (parseInt(levelSlider.value) <= parseInt(vehicleInfoModel.get(i).tankInfo.level)) {
                            if (parseInt(battlesSlider.value) <= parseInt(vehicleInfoModel.get(i).statistic.statistics.battles)) {
                                filteredVehicleInfoModel.append(vehicleInfoModel.get(i));
                            }
                        }
                        i++;
                    }
//                    if (filteredVehicleInfoModel.count > 0) {
                        vehicleList.model = filteredVehicleInfoModel
//                    } else {
//                        vehicleList.model = vehicleInfoModel
//                    }
                    filterDialog.close()
                }
            }
            SheetButton {
                text: qsTr("Cancel");
                width: parent.width
                platformStyle: ButtonStyle{
                    inverted: true
                    buttonHeight: 50
                    buttonWidth: parent.width * 0.30
                }
                onClicked: {
                    filterDialog.close();
                }
            }
          }
    }

    BusyIndicator {
        id: infoBusyIndicator
        anchors.centerIn: parent
        running: false
        visible: false
        platformStyle: BusyIndicatorStyle { size: "large" }
    }

    Menu {
        id: userMenu
//        visualParent: pageStack
        MenuLayout {
            MenuItem {
                text: qsTr("Add player")
                enabled: showAddButton
                onClicked: {
                    if (!Settings.findUser(userId)) {
//                        console.log("Add new user")
                        enabled = false;
                        if (clanLabel.visible) {
                            Settings.addUser(userInfoModel.get(0).nickname, userId, clanModel.abbreviation, clanId, clanModel.clan_color, claster);
                        } else {
                            Settings.addUser(userInfoModel.get(0).nickname, userId, "", "", "", claster);
                        }
                    } else {
//                        console.log("User is already present")
                        infoBanner.text = "User is already present";
                        infoBanner.show();
                    }
                }
            }
//            MenuItem {
//                text: "Фильтровать"
//                enabled: userInfoModel.count > 0?true:false
//                onClicked: {
//                    filterDialog.open()
//                }
//            }
            MenuItem {
                text: qsTr("Compare players")
                enabled: userInfoModel.count > 0?true:false
                onClicked: {
                    pageStack.push(Qt.resolvedUrl("compareUsers.qml"), {user1ListModel: userInfoModel, user1ClanData: clanModel})
                }
            }
        }
    }

    tools: ToolBarLayout {
        ToolIcon {
            platformIconId: "toolbar-back"
            onClicked: window.pageStack.pop()
        }

//        ToolButton {
//            id: flipButton
//            text: flipable.flipped?"Info":"Tanks"
//            onClicked: flipable.flipped = !flipable.flipped;
//        }
        ButtonRow {
            style: TabButtonStyle {
                fontPixelSize: 20
            }
            TabButton {
                id: tab1
                tab: tab1content
                enabled: false

                BusyIndicator {
                    id: tab1BusyIndicator
                    anchors.centerIn: parent
//                    anchors.left: parent.left
//                    anchors.leftMargin: 3
//                    anchors.horizontalCenter: parent.horizontalCenter
                    running: true
                    visible: true
                }

                text: qsTr("Info")
            }
            TabButton {
                id: tab2
                tab: tab2content
                enabled: false

                BusyIndicator {
                    id: tab2BusyIndicator
                    anchors.centerIn: parent
//                    anchors.left: parent.left
//                    anchors.leftMargin: 3
//                    anchors.horizontalCenter: parent.horizontalCenter
                    running: true
                    visible: true
                }
                text: qsTr("Tanks")
            }
            TabButton {
                id: tab3
                tab: tab3content
                enabled: false

                BusyIndicator {
                    id: tab3BusyIndicator
                    anchors.centerIn: parent
//                    anchors.left: parent.left
//                    anchors.leftMargin: 3
//                    anchors.horizontalCenter: parent.horizontalCenter
                    running: true
                    visible: true
                }
                text: qsTr("Medals")

            }
        }
        ToolIcon {
            platformIconId: "toolbar-view-menu"
            anchors.right: (parent === undefined) ? undefined : parent.right
            onClicked: (userMenu.status === DialogStatus.Closed) ? userMenu.open() : userMenu.close()
//            id: addUserButton
//            platformIconId: showAddButton?"toolbar-add":""
//            enabled: showAddButton
//            onClicked: {
//                if (!Settings.findUser(userId)) {
//                    console.log("Add new user")
//                    enabled = false;
//                    platformIconId = "";
//                    if (clanLabel.visible) {
//                        Settings.addUser(userInfoModel.get(0).name, userId, userInfoModel.get(0).clan.clan.abbreviation, clanId, userInfoModel.get(0).clan.clan.color, claster);
//                    } else {
//                        Settings.addUser(userInfoModel.get(0).name, userId, "", "", "", claster);
//                    }
//                } else {
//                    console.log("User is already present")
//                    platformIconId = "";
//                    infoBanner.text = "User is already present";
//                    infoBanner.show();
//                }
//            }
        }
    }

    function filterByNation(nation) {
        if (nation !== currentNation) {
            currentNation = nation
            var i = 0;
            filteredVehicleInfoModel.clear();
            while (i < vehicleInfoModel.count) {
                if (nation === vehicleInfoModel.get(i).tankInfo.nation) {
                    filteredVehicleInfoModel.append(vehicleInfoModel.get(i));
                }
                i++;
            }
            isFiltered = true
            vehicleList.model = filteredVehicleInfoModel
        } else if (nation === currentNation) {
            isFiltered = false
            currentNation = ""
            vehicleList.model = vehicleInfoModel
        }
    }
}
