import QtQuick 1.1
import com.nokia.meego 1.1
import com.nokia.extras 1.1     // Extras

import "HttpRequest.js" as HttpRequest
import "Database.js" as Settings

Page {
    id: ownersPage
    orientationLock: PageOrientation.LockPortrait

    property variant owners
    property string claster: "ru"
    property string imgUrl: ""
    property alias vehicleLabel: vehicleLabel.text
    property string vehicle_level: ""
    property string vehicles_count: ""

    Component.onCompleted: {
        // Initialize the database
        Settings.initialize();

        console.log("owners", owners, "\nowners", JSON.stringify(owners))
        var url = "http://api.worldoftanks." + claster + "/wot/account/info/?application_id=demo&account_id=" + owners;
        HttpRequest.httpRequest(url, fillData);
    }

    InfoBanner {
        id: infoBanner
        timerShowTime: 4000
        z: 3
    }

    function fillData(ownersDict) {
        for(var i in ownersDict) {
            ownersInfo.append(ownersDict[i])
        }
    }

    ListModel {
        id: ownersInfo
    }

    Component {
        id: ownersModelDelegate
        Rectangle {
            id: vehicleItem
            width: parent.width
            height: 60
            color: "transparent"
            Text {
                id: _userName
                anchors.left: parent.left
                anchors.leftMargin: 5
                anchors.verticalCenter: parent.verticalCenter
                text: nickname
                font.bold: true
                font.pointSize: 18
            }
            Text {
                id: _battle
                anchors.right: parent.right
                anchors.rightMargin: 5
                anchors.verticalCenter: parent.verticalCenter
                text: statistics.all.battles + " (" + statistics.all.wins + "/" + getPercent(statistics.all.battles, statistics.all.wins) + ")"
                font.bold: false
                font.pointSize: 14
            }

            Rectangle {
                anchors.bottom: parent.bottom
                width: parent.width
                color: "#000080"
                height: 1
            }


            function replaceChar(str) {
                return str.replace(/_/g," ");
            }

            function getPercent(battle_count, win_count) {
                if (battle_count === 0) {
                    return 0;
                }
                var winPercent = ((win_count/battle_count) * 100 ).toFixed(2);
                var res = 0;
                if (winPercent > 50.50) {
                    res = "<font color='#00ff00'>" + winPercent + "</font>%"
                } else if (winPercent < 50.50 && winPercent > 48.50) {
                    res = "<font color='#aeed00'>" + winPercent + "</font>%"
                } else if (winPercent < 48.50 && winPercent > 46.50) {
                    res = "<font color='#eded00'>" + winPercent + "</font>%"
                } else {
                    res = "<font color='#f52900'>" + winPercent + "</font>%"
                }
                return res;
            }
            MouseArea {
                anchors.fill: parent
                onClicked: {
                    pageStack.push(Qt.resolvedUrl("userInfoPage.qml"), {userId: account_id, claster: claster, needRequest: true, needClanRequest: false})
                }
            }
        }
    }

    Rectangle {
        id: pageHeader
        anchors.top: parent.top
        anchors.left: parent.left
        anchors.right: parent.right
        width: parent.width
        height: 100 // userLabel.height + 10
        color: "lightgray"
        border.width: 1
        border.color: "darkgray"

        Image {
            id: vehicleIcon
            anchors.left: parent.left
            anchors.leftMargin: 5
            anchors.verticalCenter: parent.verticalCenter
            fillMode: Image.PreserveAspectFit
            smooth: true
            source: imgUrl
        }
        Label {
            id: vehicleLabel
            anchors.top: parent.top
            anchors.topMargin: 5
            anchors.left: vehicleIcon.right
            anchors.leftMargin: 5
            anchors.right: parent.right
            anchors.rightMargin: 5
            text: ""
            wrapMode: Text.WordWrap

            platformStyle: LabelStyle {
                textColor: "black"
                fontPixelSize: 28
            }
        }

        Text {
            id: vehiclesCount
            anchors.bottom: parent.bottom
            anchors.bottomMargin: 5
            anchors.right: parent.right
            anchors.rightMargin: 10
            font.pointSize: 12
            text: qsTr("Tanks count: ") + vehicles_count
        }
    }

    ListView {
        anchors.top: pageHeader.bottom
        anchors.topMargin: 5
        anchors.bottom: parent.bottom
        anchors.left: parent.left
        anchors.right: parent.right
        z: 0
        clip: true
        spacing: 2
        snapMode: ListView.SnapToItem
        keyNavigationWraps: false
//        model: owners
        model: ownersInfo
        delegate: ownersModelDelegate
    }

    tools: ToolBarLayout {
        ToolIcon {
            platformIconId: "toolbar-back"
            onClicked: window.pageStack.pop()
        }
    }
}
